@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/appmesh/AppMesh_EXPORTS.h>
@@ -35,7 +25,7 @@ namespace Model
 {
 
   /**
-   * <p><h3>See Also:</h3>   <a
+   * <zonbook></zonbook><xhtml></xhtml><p><h3>See Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/appmesh-2019-01-25/CreateVirtualServiceInput">AWS
    * API Reference</a></p>
    */
@@ -57,64 +47,56 @@ namespace Model
 
     /**
      * <p>Unique, case-sensitive identifier that you provide to ensure the idempotency
-     * of the
-request. Up to 36 letters, numbers, hyphens, and underscores are
+     * of the request. Up to 36 letters, numbers, hyphens, and underscores are
      * allowed.</p>
      */
     inline const Aws::String& GetClientToken() const{ return m_clientToken; }
 
     /**
      * <p>Unique, case-sensitive identifier that you provide to ensure the idempotency
-     * of the
-request. Up to 36 letters, numbers, hyphens, and underscores are
+     * of the request. Up to 36 letters, numbers, hyphens, and underscores are
      * allowed.</p>
      */
     inline bool ClientTokenHasBeenSet() const { return m_clientTokenHasBeenSet; }
 
     /**
      * <p>Unique, case-sensitive identifier that you provide to ensure the idempotency
-     * of the
-request. Up to 36 letters, numbers, hyphens, and underscores are
+     * of the request. Up to 36 letters, numbers, hyphens, and underscores are
      * allowed.</p>
      */
     inline void SetClientToken(const Aws::String& value) { m_clientTokenHasBeenSet = true; m_clientToken = value; }
 
     /**
      * <p>Unique, case-sensitive identifier that you provide to ensure the idempotency
-     * of the
-request. Up to 36 letters, numbers, hyphens, and underscores are
+     * of the request. Up to 36 letters, numbers, hyphens, and underscores are
      * allowed.</p>
      */
     inline void SetClientToken(Aws::String&& value) { m_clientTokenHasBeenSet = true; m_clientToken = std::move(value); }
 
     /**
      * <p>Unique, case-sensitive identifier that you provide to ensure the idempotency
-     * of the
-request. Up to 36 letters, numbers, hyphens, and underscores are
+     * of the request. Up to 36 letters, numbers, hyphens, and underscores are
      * allowed.</p>
      */
     inline void SetClientToken(const char* value) { m_clientTokenHasBeenSet = true; m_clientToken.assign(value); }
 
     /**
      * <p>Unique, case-sensitive identifier that you provide to ensure the idempotency
-     * of the
-request. Up to 36 letters, numbers, hyphens, and underscores are
+     * of the request. Up to 36 letters, numbers, hyphens, and underscores are
      * allowed.</p>
      */
     inline CreateVirtualServiceRequest& WithClientToken(const Aws::String& value) { SetClientToken(value); return *this;}
 
     /**
      * <p>Unique, case-sensitive identifier that you provide to ensure the idempotency
-     * of the
-request. Up to 36 letters, numbers, hyphens, and underscores are
+     * of the request. Up to 36 letters, numbers, hyphens, and underscores are
      * allowed.</p>
      */
     inline CreateVirtualServiceRequest& WithClientToken(Aws::String&& value) { SetClientToken(std::move(value)); return *this;}
 
     /**
      * <p>Unique, case-sensitive identifier that you provide to ensure the idempotency
-     * of the
-request. Up to 36 letters, numbers, hyphens, and underscores are
+     * of the request. Up to 36 letters, numbers, hyphens, and underscores are
      * allowed.</p>
      */
     inline CreateVirtualServiceRequest& WithClientToken(const char* value) { SetClientToken(value); return *this;}
@@ -163,97 +145,81 @@ request. Up to 36 letters, numbers, hyphens, and underscores are
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then
-               the account that you specify must share the mesh
-     * with your account before you can create 
-             the resource in the
-     * service mesh. For more information about mesh sharing, see <a
+     * your own, then the account that you specify must share the mesh with your
+     * account before you can create the resource in the service mesh. For more
+     * information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline const Aws::String& GetMeshOwner() const{ return m_meshOwner; }
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then
-               the account that you specify must share the mesh
-     * with your account before you can create 
-             the resource in the
-     * service mesh. For more information about mesh sharing, see <a
+     * your own, then the account that you specify must share the mesh with your
+     * account before you can create the resource in the service mesh. For more
+     * information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline bool MeshOwnerHasBeenSet() const { return m_meshOwnerHasBeenSet; }
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then
-               the account that you specify must share the mesh
-     * with your account before you can create 
-             the resource in the
-     * service mesh. For more information about mesh sharing, see <a
+     * your own, then the account that you specify must share the mesh with your
+     * account before you can create the resource in the service mesh. For more
+     * information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline void SetMeshOwner(const Aws::String& value) { m_meshOwnerHasBeenSet = true; m_meshOwner = value; }
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then
-               the account that you specify must share the mesh
-     * with your account before you can create 
-             the resource in the
-     * service mesh. For more information about mesh sharing, see <a
+     * your own, then the account that you specify must share the mesh with your
+     * account before you can create the resource in the service mesh. For more
+     * information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline void SetMeshOwner(Aws::String&& value) { m_meshOwnerHasBeenSet = true; m_meshOwner = std::move(value); }
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then
-               the account that you specify must share the mesh
-     * with your account before you can create 
-             the resource in the
-     * service mesh. For more information about mesh sharing, see <a
+     * your own, then the account that you specify must share the mesh with your
+     * account before you can create the resource in the service mesh. For more
+     * information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline void SetMeshOwner(const char* value) { m_meshOwnerHasBeenSet = true; m_meshOwner.assign(value); }
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then
-               the account that you specify must share the mesh
-     * with your account before you can create 
-             the resource in the
-     * service mesh. For more information about mesh sharing, see <a
+     * your own, then the account that you specify must share the mesh with your
+     * account before you can create the resource in the service mesh. For more
+     * information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline CreateVirtualServiceRequest& WithMeshOwner(const Aws::String& value) { SetMeshOwner(value); return *this;}
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then
-               the account that you specify must share the mesh
-     * with your account before you can create 
-             the resource in the
-     * service mesh. For more information about mesh sharing, see <a
+     * your own, then the account that you specify must share the mesh with your
+     * account before you can create the resource in the service mesh. For more
+     * information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline CreateVirtualServiceRequest& WithMeshOwner(Aws::String&& value) { SetMeshOwner(std::move(value)); return *this;}
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then
-               the account that you specify must share the mesh
-     * with your account before you can create 
-             the resource in the
-     * service mesh. For more information about mesh sharing, see <a
+     * your own, then the account that you specify must share the mesh with your
+     * account before you can create the resource in the service mesh. For more
+     * information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline CreateVirtualServiceRequest& WithMeshOwner(const char* value) { SetMeshOwner(value); return *this;}
 
@@ -291,97 +257,65 @@ request. Up to 36 letters, numbers, hyphens, and underscores are
 
     /**
      * <p>Optional metadata that you can apply to the virtual service to assist with
-  
      * categorization and organization. Each tag consists of a key and an optional
-     * value, both of
-         which you define. Tag keys can have a maximum character
-     * length of 128 characters, and tag values can have
-            a maximum length
-     * of 256 characters.</p>
+     * value, both of which you define. Tag keys can have a maximum character length of
+     * 128 characters, and tag values can have a maximum length of 256 characters.</p>
      */
     inline const Aws::Vector<TagRef>& GetTags() const{ return m_tags; }
 
     /**
      * <p>Optional metadata that you can apply to the virtual service to assist with
-  
      * categorization and organization. Each tag consists of a key and an optional
-     * value, both of
-         which you define. Tag keys can have a maximum character
-     * length of 128 characters, and tag values can have
-            a maximum length
-     * of 256 characters.</p>
+     * value, both of which you define. Tag keys can have a maximum character length of
+     * 128 characters, and tag values can have a maximum length of 256 characters.</p>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
     /**
      * <p>Optional metadata that you can apply to the virtual service to assist with
-  
      * categorization and organization. Each tag consists of a key and an optional
-     * value, both of
-         which you define. Tag keys can have a maximum character
-     * length of 128 characters, and tag values can have
-            a maximum length
-     * of 256 characters.</p>
+     * value, both of which you define. Tag keys can have a maximum character length of
+     * 128 characters, and tag values can have a maximum length of 256 characters.</p>
      */
     inline void SetTags(const Aws::Vector<TagRef>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
     /**
      * <p>Optional metadata that you can apply to the virtual service to assist with
-  
      * categorization and organization. Each tag consists of a key and an optional
-     * value, both of
-         which you define. Tag keys can have a maximum character
-     * length of 128 characters, and tag values can have
-            a maximum length
-     * of 256 characters.</p>
+     * value, both of which you define. Tag keys can have a maximum character length of
+     * 128 characters, and tag values can have a maximum length of 256 characters.</p>
      */
     inline void SetTags(Aws::Vector<TagRef>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
     /**
      * <p>Optional metadata that you can apply to the virtual service to assist with
-  
      * categorization and organization. Each tag consists of a key and an optional
-     * value, both of
-         which you define. Tag keys can have a maximum character
-     * length of 128 characters, and tag values can have
-            a maximum length
-     * of 256 characters.</p>
+     * value, both of which you define. Tag keys can have a maximum character length of
+     * 128 characters, and tag values can have a maximum length of 256 characters.</p>
      */
     inline CreateVirtualServiceRequest& WithTags(const Aws::Vector<TagRef>& value) { SetTags(value); return *this;}
 
     /**
      * <p>Optional metadata that you can apply to the virtual service to assist with
-  
      * categorization and organization. Each tag consists of a key and an optional
-     * value, both of
-         which you define. Tag keys can have a maximum character
-     * length of 128 characters, and tag values can have
-            a maximum length
-     * of 256 characters.</p>
+     * value, both of which you define. Tag keys can have a maximum character length of
+     * 128 characters, and tag values can have a maximum length of 256 characters.</p>
      */
     inline CreateVirtualServiceRequest& WithTags(Aws::Vector<TagRef>&& value) { SetTags(std::move(value)); return *this;}
 
     /**
      * <p>Optional metadata that you can apply to the virtual service to assist with
-  
      * categorization and organization. Each tag consists of a key and an optional
-     * value, both of
-         which you define. Tag keys can have a maximum character
-     * length of 128 characters, and tag values can have
-            a maximum length
-     * of 256 characters.</p>
+     * value, both of which you define. Tag keys can have a maximum character length of
+     * 128 characters, and tag values can have a maximum length of 256 characters.</p>
      */
     inline CreateVirtualServiceRequest& AddTags(const TagRef& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
 
     /**
      * <p>Optional metadata that you can apply to the virtual service to assist with
-  
      * categorization and organization. Each tag consists of a key and an optional
-     * value, both of
-         which you define. Tag keys can have a maximum character
-     * length of 128 characters, and tag values can have
-            a maximum length
-     * of 256 characters.</p>
+     * value, both of which you define. Tag keys can have a maximum character length of
+     * 128 characters, and tag values can have a maximum length of 256 characters.</p>
      */
     inline CreateVirtualServiceRequest& AddTags(TagRef&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
