@@ -1,21 +1,12 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/appmesh/AppMesh_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/core/utils/DateTime.h>
 #include <utility>
 
 namespace Aws
@@ -89,6 +80,74 @@ namespace Model
     inline MeshRef& WithArn(const char* value) { SetArn(value); return *this;}
 
 
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was created.</p>
+     */
+    inline const Aws::Utils::DateTime& GetCreatedAt() const{ return m_createdAt; }
+
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was created.</p>
+     */
+    inline bool CreatedAtHasBeenSet() const { return m_createdAtHasBeenSet; }
+
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was created.</p>
+     */
+    inline void SetCreatedAt(const Aws::Utils::DateTime& value) { m_createdAtHasBeenSet = true; m_createdAt = value; }
+
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was created.</p>
+     */
+    inline void SetCreatedAt(Aws::Utils::DateTime&& value) { m_createdAtHasBeenSet = true; m_createdAt = std::move(value); }
+
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was created.</p>
+     */
+    inline MeshRef& WithCreatedAt(const Aws::Utils::DateTime& value) { SetCreatedAt(value); return *this;}
+
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was created.</p>
+     */
+    inline MeshRef& WithCreatedAt(Aws::Utils::DateTime&& value) { SetCreatedAt(std::move(value)); return *this;}
+
+
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was last
+     * updated.</p>
+     */
+    inline const Aws::Utils::DateTime& GetLastUpdatedAt() const{ return m_lastUpdatedAt; }
+
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was last
+     * updated.</p>
+     */
+    inline bool LastUpdatedAtHasBeenSet() const { return m_lastUpdatedAtHasBeenSet; }
+
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was last
+     * updated.</p>
+     */
+    inline void SetLastUpdatedAt(const Aws::Utils::DateTime& value) { m_lastUpdatedAtHasBeenSet = true; m_lastUpdatedAt = value; }
+
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was last
+     * updated.</p>
+     */
+    inline void SetLastUpdatedAt(Aws::Utils::DateTime&& value) { m_lastUpdatedAtHasBeenSet = true; m_lastUpdatedAt = std::move(value); }
+
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was last
+     * updated.</p>
+     */
+    inline MeshRef& WithLastUpdatedAt(const Aws::Utils::DateTime& value) { SetLastUpdatedAt(value); return *this;}
+
+    /**
+     * <p>The Unix epoch timestamp in seconds for when the resource was last
+     * updated.</p>
+     */
+    inline MeshRef& WithLastUpdatedAt(Aws::Utils::DateTime&& value) { SetLastUpdatedAt(std::move(value)); return *this;}
+
+
     /**
      * <p>The name of the service mesh.</p>
      */
@@ -132,170 +191,185 @@ namespace Model
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then it's
-               the ID of the account that shared the mesh
-     * with your account. For more information about mesh sharing, see <a
+     * your own, then it's the ID of the account that shared the mesh with your
+     * account. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline const Aws::String& GetMeshOwner() const{ return m_meshOwner; }
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then it's
-               the ID of the account that shared the mesh
-     * with your account. For more information about mesh sharing, see <a
+     * your own, then it's the ID of the account that shared the mesh with your
+     * account. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline bool MeshOwnerHasBeenSet() const { return m_meshOwnerHasBeenSet; }
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then it's
-               the ID of the account that shared the mesh
-     * with your account. For more information about mesh sharing, see <a
+     * your own, then it's the ID of the account that shared the mesh with your
+     * account. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline void SetMeshOwner(const Aws::String& value) { m_meshOwnerHasBeenSet = true; m_meshOwner = value; }
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then it's
-               the ID of the account that shared the mesh
-     * with your account. For more information about mesh sharing, see <a
+     * your own, then it's the ID of the account that shared the mesh with your
+     * account. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline void SetMeshOwner(Aws::String&& value) { m_meshOwnerHasBeenSet = true; m_meshOwner = std::move(value); }
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then it's
-               the ID of the account that shared the mesh
-     * with your account. For more information about mesh sharing, see <a
+     * your own, then it's the ID of the account that shared the mesh with your
+     * account. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline void SetMeshOwner(const char* value) { m_meshOwnerHasBeenSet = true; m_meshOwner.assign(value); }
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then it's
-               the ID of the account that shared the mesh
-     * with your account. For more information about mesh sharing, see <a
+     * your own, then it's the ID of the account that shared the mesh with your
+     * account. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline MeshRef& WithMeshOwner(const Aws::String& value) { SetMeshOwner(value); return *this;}
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then it's
-               the ID of the account that shared the mesh
-     * with your account. For more information about mesh sharing, see <a
+     * your own, then it's the ID of the account that shared the mesh with your
+     * account. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline MeshRef& WithMeshOwner(Aws::String&& value) { SetMeshOwner(std::move(value)); return *this;}
 
     /**
      * <p>The AWS IAM account ID of the service mesh owner. If the account ID is not
-     * your own, then it's
-               the ID of the account that shared the mesh
-     * with your account. For more information about mesh sharing, see <a
+     * your own, then it's the ID of the account that shared the mesh with your
+     * account. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline MeshRef& WithMeshOwner(const char* value) { SetMeshOwner(value); return *this;}
 
 
     /**
      * <p>The AWS IAM account ID of the resource owner. If the account ID is not your
-     * own, then it's
-               the ID of the mesh owner, or another account that
-     * the mesh is shared with. For more information about mesh sharing, see <a
+     * own, then it's the ID of the mesh owner or of another account that the mesh is
+     * shared with. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline const Aws::String& GetResourceOwner() const{ return m_resourceOwner; }
 
     /**
      * <p>The AWS IAM account ID of the resource owner. If the account ID is not your
-     * own, then it's
-               the ID of the mesh owner, or another account that
-     * the mesh is shared with. For more information about mesh sharing, see <a
+     * own, then it's the ID of the mesh owner or of another account that the mesh is
+     * shared with. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline bool ResourceOwnerHasBeenSet() const { return m_resourceOwnerHasBeenSet; }
 
     /**
      * <p>The AWS IAM account ID of the resource owner. If the account ID is not your
-     * own, then it's
-               the ID of the mesh owner, or another account that
-     * the mesh is shared with. For more information about mesh sharing, see <a
+     * own, then it's the ID of the mesh owner or of another account that the mesh is
+     * shared with. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline void SetResourceOwner(const Aws::String& value) { m_resourceOwnerHasBeenSet = true; m_resourceOwner = value; }
 
     /**
      * <p>The AWS IAM account ID of the resource owner. If the account ID is not your
-     * own, then it's
-               the ID of the mesh owner, or another account that
-     * the mesh is shared with. For more information about mesh sharing, see <a
+     * own, then it's the ID of the mesh owner or of another account that the mesh is
+     * shared with. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline void SetResourceOwner(Aws::String&& value) { m_resourceOwnerHasBeenSet = true; m_resourceOwner = std::move(value); }
 
     /**
      * <p>The AWS IAM account ID of the resource owner. If the account ID is not your
-     * own, then it's
-               the ID of the mesh owner, or another account that
-     * the mesh is shared with. For more information about mesh sharing, see <a
+     * own, then it's the ID of the mesh owner or of another account that the mesh is
+     * shared with. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline void SetResourceOwner(const char* value) { m_resourceOwnerHasBeenSet = true; m_resourceOwner.assign(value); }
 
     /**
      * <p>The AWS IAM account ID of the resource owner. If the account ID is not your
-     * own, then it's
-               the ID of the mesh owner, or another account that
-     * the mesh is shared with. For more information about mesh sharing, see <a
+     * own, then it's the ID of the mesh owner or of another account that the mesh is
+     * shared with. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline MeshRef& WithResourceOwner(const Aws::String& value) { SetResourceOwner(value); return *this;}
 
     /**
      * <p>The AWS IAM account ID of the resource owner. If the account ID is not your
-     * own, then it's
-               the ID of the mesh owner, or another account that
-     * the mesh is shared with. For more information about mesh sharing, see <a
+     * own, then it's the ID of the mesh owner or of another account that the mesh is
+     * shared with. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline MeshRef& WithResourceOwner(Aws::String&& value) { SetResourceOwner(std::move(value)); return *this;}
 
     /**
      * <p>The AWS IAM account ID of the resource owner. If the account ID is not your
-     * own, then it's
-               the ID of the mesh owner, or another account that
-     * the mesh is shared with. For more information about mesh sharing, see <a
+     * own, then it's the ID of the mesh owner or of another account that the mesh is
+     * shared with. For more information about mesh sharing, see <a
      * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
-     * with Shared Meshes</a>.</p>
+     * with shared meshes</a>.</p>
      */
     inline MeshRef& WithResourceOwner(const char* value) { SetResourceOwner(value); return *this;}
 
+
+    /**
+     * <p>The version of the resource. Resources are created at version 1, and this
+     * version is incremented each time that they're updated.</p>
+     */
+    inline long long GetVersion() const{ return m_version; }
+
+    /**
+     * <p>The version of the resource. Resources are created at version 1, and this
+     * version is incremented each time that they're updated.</p>
+     */
+    inline bool VersionHasBeenSet() const { return m_versionHasBeenSet; }
+
+    /**
+     * <p>The version of the resource. Resources are created at version 1, and this
+     * version is incremented each time that they're updated.</p>
+     */
+    inline void SetVersion(long long value) { m_versionHasBeenSet = true; m_version = value; }
+
+    /**
+     * <p>The version of the resource. Resources are created at version 1, and this
+     * version is incremented each time that they're updated.</p>
+     */
+    inline MeshRef& WithVersion(long long value) { SetVersion(value); return *this;}
+
   private:
 
     Aws::String m_arn;
     bool m_arnHasBeenSet;
 
+    Aws::Utils::DateTime m_createdAt;
+    bool m_createdAtHasBeenSet;
+
+    Aws::Utils::DateTime m_lastUpdatedAt;
+    bool m_lastUpdatedAtHasBeenSet;
+
     Aws::String m_meshName;
     bool m_meshNameHasBeenSet;
 
@@ -304,6 +378,9 @@ namespace Model
 
     Aws::String m_resourceOwner;
     bool m_resourceOwnerHasBeenSet;
+
+    long long m_version;
+    bool m_versionHasBeenSet;
   };
 
 } // namespace Model
