@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/autoscaling/AutoScaling_EXPORTS.h>
@@ -35,8 +25,7 @@ namespace Model
 {
 
   /**
-   * <p>Describes a scheduled scaling action. Used in response to
-   * <a>DescribeScheduledActions</a>.</p><p><h3>See Also:</h3>   <a
+   * <p>Describes a scheduled scaling action.</p><p><h3>See Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/autoscaling-2011-01-01/ScheduledUpdateGroupAction">AWS
    * API Reference</a></p>
    */
@@ -345,67 +334,112 @@ namespace Model
 
 
     /**
-     * <p>The minimum number of instances in the Auto Scaling group.</p>
+     * <p>The minimum size of the Auto Scaling group.</p>
      */
     inline int GetMinSize() const{ return m_minSize; }
 
     /**
-     * <p>The minimum number of instances in the Auto Scaling group.</p>
+     * <p>The minimum size of the Auto Scaling group.</p>
      */
     inline bool MinSizeHasBeenSet() const { return m_minSizeHasBeenSet; }
 
     /**
-     * <p>The minimum number of instances in the Auto Scaling group.</p>
+     * <p>The minimum size of the Auto Scaling group.</p>
      */
     inline void SetMinSize(int value) { m_minSizeHasBeenSet = true; m_minSize = value; }
 
     /**
-     * <p>The minimum number of instances in the Auto Scaling group.</p>
+     * <p>The minimum size of the Auto Scaling group.</p>
      */
     inline ScheduledUpdateGroupAction& WithMinSize(int value) { SetMinSize(value); return *this;}
 
 
     /**
-     * <p>The maximum number of instances in the Auto Scaling group.</p>
+     * <p>The maximum size of the Auto Scaling group.</p>
      */
     inline int GetMaxSize() const{ return m_maxSize; }
 
     /**
-     * <p>The maximum number of instances in the Auto Scaling group.</p>
+     * <p>The maximum size of the Auto Scaling group.</p>
      */
     inline bool MaxSizeHasBeenSet() const { return m_maxSizeHasBeenSet; }
 
     /**
-     * <p>The maximum number of instances in the Auto Scaling group.</p>
+     * <p>The maximum size of the Auto Scaling group.</p>
      */
     inline void SetMaxSize(int value) { m_maxSizeHasBeenSet = true; m_maxSize = value; }
 
     /**
-     * <p>The maximum number of instances in the Auto Scaling group.</p>
+     * <p>The maximum size of the Auto Scaling group.</p>
      */
     inline ScheduledUpdateGroupAction& WithMaxSize(int value) { SetMaxSize(value); return *this;}
 
 
     /**
-     * <p>The number of instances you prefer to maintain in the group.</p>
+     * <p>The desired capacity is the initial capacity of the Auto Scaling group after
+     * the scheduled action runs and the capacity it attempts to maintain.</p>
      */
     inline int GetDesiredCapacity() const{ return m_desiredCapacity; }
 
     /**
-     * <p>The number of instances you prefer to maintain in the group.</p>
+     * <p>The desired capacity is the initial capacity of the Auto Scaling group after
+     * the scheduled action runs and the capacity it attempts to maintain.</p>
      */
     inline bool DesiredCapacityHasBeenSet() const { return m_desiredCapacityHasBeenSet; }
 
     /**
-     * <p>The number of instances you prefer to maintain in the group.</p>
+     * <p>The desired capacity is the initial capacity of the Auto Scaling group after
+     * the scheduled action runs and the capacity it attempts to maintain.</p>
      */
     inline void SetDesiredCapacity(int value) { m_desiredCapacityHasBeenSet = true; m_desiredCapacity = value; }
 
     /**
-     * <p>The number of instances you prefer to maintain in the group.</p>
+     * <p>The desired capacity is the initial capacity of the Auto Scaling group after
+     * the scheduled action runs and the capacity it attempts to maintain.</p>
      */
     inline ScheduledUpdateGroupAction& WithDesiredCapacity(int value) { SetDesiredCapacity(value); return *this;}
 
+
+    /**
+     * <p>The time zone for the cron expression.</p>
+     */
+    inline const Aws::String& GetTimeZone() const{ return m_timeZone; }
+
+    /**
+     * <p>The time zone for the cron expression.</p>
+     */
+    inline bool TimeZoneHasBeenSet() const { return m_timeZoneHasBeenSet; }
+
+    /**
+     * <p>The time zone for the cron expression.</p>
+     */
+    inline void SetTimeZone(const Aws::String& value) { m_timeZoneHasBeenSet = true; m_timeZone = value; }
+
+    /**
+     * <p>The time zone for the cron expression.</p>
+     */
+    inline void SetTimeZone(Aws::String&& value) { m_timeZoneHasBeenSet = true; m_timeZone = std::move(value); }
+
+    /**
+     * <p>The time zone for the cron expression.</p>
+     */
+    inline void SetTimeZone(const char* value) { m_timeZoneHasBeenSet = true; m_timeZone.assign(value); }
+
+    /**
+     * <p>The time zone for the cron expression.</p>
+     */
+    inline ScheduledUpdateGroupAction& WithTimeZone(const Aws::String& value) { SetTimeZone(value); return *this;}
+
+    /**
+     * <p>The time zone for the cron expression.</p>
+     */
+    inline ScheduledUpdateGroupAction& WithTimeZone(Aws::String&& value) { SetTimeZone(std::move(value)); return *this;}
+
+    /**
+     * <p>The time zone for the cron expression.</p>
+     */
+    inline ScheduledUpdateGroupAction& WithTimeZone(const char* value) { SetTimeZone(value); return *this;}
+
   private:
 
     Aws::String m_autoScalingGroupName;
@@ -437,6 +471,9 @@ namespace Model
 
     int m_desiredCapacity;
     bool m_desiredCapacityHasBeenSet;
+
+    Aws::String m_timeZone;
+    bool m_timeZoneHasBeenSet;
   };
 
 } // namespace Model
