@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/ce/CostExplorer_EXPORTS.h>
@@ -108,85 +98,94 @@ namespace Model
 
 
     /**
-     * <p> <code>UpdateCostCategoryDefinition</code> supports dimensions, Tags, and
-     * nested expressions. Currently the only dimensions supported is
-     * <code>LINKED_ACCOUNT</code>.</p> <p>Root level <code>OR</code> is not supported.
-     * We recommend you create a separate rule instead.</p> <p>Rules are processed in
-     * order. If there are multiple rules that match the line item, then the first rule
-     * to match is used to determine that Cost Category value. </p>
+     * <p>The <code>Expression</code> object used to categorize costs. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CostCategoryRule.html">CostCategoryRule
+     * </a>. </p>
      */
     inline const Aws::Vector<CostCategoryRule>& GetRules() const{ return m_rules; }
 
     /**
-     * <p> <code>UpdateCostCategoryDefinition</code> supports dimensions, Tags, and
-     * nested expressions. Currently the only dimensions supported is
-     * <code>LINKED_ACCOUNT</code>.</p> <p>Root level <code>OR</code> is not supported.
-     * We recommend you create a separate rule instead.</p> <p>Rules are processed in
-     * order. If there are multiple rules that match the line item, then the first rule
-     * to match is used to determine that Cost Category value. </p>
+     * <p>The <code>Expression</code> object used to categorize costs. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CostCategoryRule.html">CostCategoryRule
+     * </a>. </p>
      */
     inline bool RulesHasBeenSet() const { return m_rulesHasBeenSet; }
 
     /**
-     * <p> <code>UpdateCostCategoryDefinition</code> supports dimensions, Tags, and
-     * nested expressions. Currently the only dimensions supported is
-     * <code>LINKED_ACCOUNT</code>.</p> <p>Root level <code>OR</code> is not supported.
-     * We recommend you create a separate rule instead.</p> <p>Rules are processed in
-     * order. If there are multiple rules that match the line item, then the first rule
-     * to match is used to determine that Cost Category value. </p>
+     * <p>The <code>Expression</code> object used to categorize costs. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CostCategoryRule.html">CostCategoryRule
+     * </a>. </p>
      */
     inline void SetRules(const Aws::Vector<CostCategoryRule>& value) { m_rulesHasBeenSet = true; m_rules = value; }
 
     /**
-     * <p> <code>UpdateCostCategoryDefinition</code> supports dimensions, Tags, and
-     * nested expressions. Currently the only dimensions supported is
-     * <code>LINKED_ACCOUNT</code>.</p> <p>Root level <code>OR</code> is not supported.
-     * We recommend you create a separate rule instead.</p> <p>Rules are processed in
-     * order. If there are multiple rules that match the line item, then the first rule
-     * to match is used to determine that Cost Category value. </p>
+     * <p>The <code>Expression</code> object used to categorize costs. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CostCategoryRule.html">CostCategoryRule
+     * </a>. </p>
      */
     inline void SetRules(Aws::Vector<CostCategoryRule>&& value) { m_rulesHasBeenSet = true; m_rules = std::move(value); }
 
     /**
-     * <p> <code>UpdateCostCategoryDefinition</code> supports dimensions, Tags, and
-     * nested expressions. Currently the only dimensions supported is
-     * <code>LINKED_ACCOUNT</code>.</p> <p>Root level <code>OR</code> is not supported.
-     * We recommend you create a separate rule instead.</p> <p>Rules are processed in
-     * order. If there are multiple rules that match the line item, then the first rule
-     * to match is used to determine that Cost Category value. </p>
+     * <p>The <code>Expression</code> object used to categorize costs. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CostCategoryRule.html">CostCategoryRule
+     * </a>. </p>
      */
     inline UpdateCostCategoryDefinitionRequest& WithRules(const Aws::Vector<CostCategoryRule>& value) { SetRules(value); return *this;}
 
     /**
-     * <p> <code>UpdateCostCategoryDefinition</code> supports dimensions, Tags, and
-     * nested expressions. Currently the only dimensions supported is
-     * <code>LINKED_ACCOUNT</code>.</p> <p>Root level <code>OR</code> is not supported.
-     * We recommend you create a separate rule instead.</p> <p>Rules are processed in
-     * order. If there are multiple rules that match the line item, then the first rule
-     * to match is used to determine that Cost Category value. </p>
+     * <p>The <code>Expression</code> object used to categorize costs. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CostCategoryRule.html">CostCategoryRule
+     * </a>. </p>
      */
     inline UpdateCostCategoryDefinitionRequest& WithRules(Aws::Vector<CostCategoryRule>&& value) { SetRules(std::move(value)); return *this;}
 
     /**
-     * <p> <code>UpdateCostCategoryDefinition</code> supports dimensions, Tags, and
-     * nested expressions. Currently the only dimensions supported is
-     * <code>LINKED_ACCOUNT</code>.</p> <p>Root level <code>OR</code> is not supported.
-     * We recommend you create a separate rule instead.</p> <p>Rules are processed in
-     * order. If there are multiple rules that match the line item, then the first rule
-     * to match is used to determine that Cost Category value. </p>
+     * <p>The <code>Expression</code> object used to categorize costs. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CostCategoryRule.html">CostCategoryRule
+     * </a>. </p>
      */
     inline UpdateCostCategoryDefinitionRequest& AddRules(const CostCategoryRule& value) { m_rulesHasBeenSet = true; m_rules.push_back(value); return *this; }
 
     /**
-     * <p> <code>UpdateCostCategoryDefinition</code> supports dimensions, Tags, and
-     * nested expressions. Currently the only dimensions supported is
-     * <code>LINKED_ACCOUNT</code>.</p> <p>Root level <code>OR</code> is not supported.
-     * We recommend you create a separate rule instead.</p> <p>Rules are processed in
-     * order. If there are multiple rules that match the line item, then the first rule
-     * to match is used to determine that Cost Category value. </p>
+     * <p>The <code>Expression</code> object used to categorize costs. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CostCategoryRule.html">CostCategoryRule
+     * </a>. </p>
      */
     inline UpdateCostCategoryDefinitionRequest& AddRules(CostCategoryRule&& value) { m_rulesHasBeenSet = true; m_rules.push_back(std::move(value)); return *this; }
 
+
+    
+    inline const Aws::String& GetDefaultValue() const{ return m_defaultValue; }
+
+    
+    inline bool DefaultValueHasBeenSet() const { return m_defaultValueHasBeenSet; }
+
+    
+    inline void SetDefaultValue(const Aws::String& value) { m_defaultValueHasBeenSet = true; m_defaultValue = value; }
+
+    
+    inline void SetDefaultValue(Aws::String&& value) { m_defaultValueHasBeenSet = true; m_defaultValue = std::move(value); }
+
+    
+    inline void SetDefaultValue(const char* value) { m_defaultValueHasBeenSet = true; m_defaultValue.assign(value); }
+
+    
+    inline UpdateCostCategoryDefinitionRequest& WithDefaultValue(const Aws::String& value) { SetDefaultValue(value); return *this;}
+
+    
+    inline UpdateCostCategoryDefinitionRequest& WithDefaultValue(Aws::String&& value) { SetDefaultValue(std::move(value)); return *this;}
+
+    
+    inline UpdateCostCategoryDefinitionRequest& WithDefaultValue(const char* value) { SetDefaultValue(value); return *this;}
+
   private:
 
     Aws::String m_costCategoryArn;
@@ -197,6 +196,9 @@ namespace Model
 
     Aws::Vector<CostCategoryRule> m_rules;
     bool m_rulesHasBeenSet;
+
+    Aws::String m_defaultValue;
+    bool m_defaultValueHasBeenSet;
   };
 
 } // namespace Model
