@@ -1,24 +1,16 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/cloudformation/CloudFormation_EXPORTS.h>
 #include <aws/cloudformation/CloudFormationRequest.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/cloudformation/model/DeploymentTargets.h>
 #include <aws/cloudformation/model/StackSetOperationPreferences.h>
+#include <aws/cloudformation/model/CallAs.h>
 #include <aws/cloudformation/model/Parameter.h>
 #include <utility>
 #include <aws/core/utils/UUID.h>
@@ -100,110 +92,171 @@ namespace Model
 
 
     /**
-     * <p>The names of one or more AWS accounts that you want to create stack instances
-     * in the specified region(s) for.</p>
+     * <p>[Self-managed permissions] The names of one or more AWS accounts that you
+     * want to create stack instances in the specified Region(s) for.</p> <p>You can
+     * specify <code>Accounts</code> or <code>DeploymentTargets</code>, but not
+     * both.</p>
      */
     inline const Aws::Vector<Aws::String>& GetAccounts() const{ return m_accounts; }
 
     /**
-     * <p>The names of one or more AWS accounts that you want to create stack instances
-     * in the specified region(s) for.</p>
+     * <p>[Self-managed permissions] The names of one or more AWS accounts that you
+     * want to create stack instances in the specified Region(s) for.</p> <p>You can
+     * specify <code>Accounts</code> or <code>DeploymentTargets</code>, but not
+     * both.</p>
      */
     inline bool AccountsHasBeenSet() const { return m_accountsHasBeenSet; }
 
     /**
-     * <p>The names of one or more AWS accounts that you want to create stack instances
-     * in the specified region(s) for.</p>
+     * <p>[Self-managed permissions] The names of one or more AWS accounts that you
+     * want to create stack instances in the specified Region(s) for.</p> <p>You can
+     * specify <code>Accounts</code> or <code>DeploymentTargets</code>, but not
+     * both.</p>
      */
     inline void SetAccounts(const Aws::Vector<Aws::String>& value) { m_accountsHasBeenSet = true; m_accounts = value; }
 
     /**
-     * <p>The names of one or more AWS accounts that you want to create stack instances
-     * in the specified region(s) for.</p>
+     * <p>[Self-managed permissions] The names of one or more AWS accounts that you
+     * want to create stack instances in the specified Region(s) for.</p> <p>You can
+     * specify <code>Accounts</code> or <code>DeploymentTargets</code>, but not
+     * both.</p>
      */
     inline void SetAccounts(Aws::Vector<Aws::String>&& value) { m_accountsHasBeenSet = true; m_accounts = std::move(value); }
 
     /**
-     * <p>The names of one or more AWS accounts that you want to create stack instances
-     * in the specified region(s) for.</p>
+     * <p>[Self-managed permissions] The names of one or more AWS accounts that you
+     * want to create stack instances in the specified Region(s) for.</p> <p>You can
+     * specify <code>Accounts</code> or <code>DeploymentTargets</code>, but not
+     * both.</p>
      */
     inline CreateStackInstancesRequest& WithAccounts(const Aws::Vector<Aws::String>& value) { SetAccounts(value); return *this;}
 
     /**
-     * <p>The names of one or more AWS accounts that you want to create stack instances
-     * in the specified region(s) for.</p>
+     * <p>[Self-managed permissions] The names of one or more AWS accounts that you
+     * want to create stack instances in the specified Region(s) for.</p> <p>You can
+     * specify <code>Accounts</code> or <code>DeploymentTargets</code>, but not
+     * both.</p>
      */
     inline CreateStackInstancesRequest& WithAccounts(Aws::Vector<Aws::String>&& value) { SetAccounts(std::move(value)); return *this;}
 
     /**
-     * <p>The names of one or more AWS accounts that you want to create stack instances
-     * in the specified region(s) for.</p>
+     * <p>[Self-managed permissions] The names of one or more AWS accounts that you
+     * want to create stack instances in the specified Region(s) for.</p> <p>You can
+     * specify <code>Accounts</code> or <code>DeploymentTargets</code>, but not
+     * both.</p>
      */
     inline CreateStackInstancesRequest& AddAccounts(const Aws::String& value) { m_accountsHasBeenSet = true; m_accounts.push_back(value); return *this; }
 
     /**
-     * <p>The names of one or more AWS accounts that you want to create stack instances
-     * in the specified region(s) for.</p>
+     * <p>[Self-managed permissions] The names of one or more AWS accounts that you
+     * want to create stack instances in the specified Region(s) for.</p> <p>You can
+     * specify <code>Accounts</code> or <code>DeploymentTargets</code>, but not
+     * both.</p>
      */
     inline CreateStackInstancesRequest& AddAccounts(Aws::String&& value) { m_accountsHasBeenSet = true; m_accounts.push_back(std::move(value)); return *this; }
 
     /**
-     * <p>The names of one or more AWS accounts that you want to create stack instances
-     * in the specified region(s) for.</p>
+     * <p>[Self-managed permissions] The names of one or more AWS accounts that you
+     * want to create stack instances in the specified Region(s) for.</p> <p>You can
+     * specify <code>Accounts</code> or <code>DeploymentTargets</code>, but not
+     * both.</p>
      */
     inline CreateStackInstancesRequest& AddAccounts(const char* value) { m_accountsHasBeenSet = true; m_accounts.push_back(value); return *this; }
 
 
     /**
-     * <p>The names of one or more regions where you want to create stack instances
+     * <p>[Service-managed permissions] The AWS Organizations accounts for which to
+     * create stack instances in the specified Regions.</p> <p>You can specify
+     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     */
+    inline const DeploymentTargets& GetDeploymentTargets() const{ return m_deploymentTargets; }
+
+    /**
+     * <p>[Service-managed permissions] The AWS Organizations accounts for which to
+     * create stack instances in the specified Regions.</p> <p>You can specify
+     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     */
+    inline bool DeploymentTargetsHasBeenSet() const { return m_deploymentTargetsHasBeenSet; }
+
+    /**
+     * <p>[Service-managed permissions] The AWS Organizations accounts for which to
+     * create stack instances in the specified Regions.</p> <p>You can specify
+     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     */
+    inline void SetDeploymentTargets(const DeploymentTargets& value) { m_deploymentTargetsHasBeenSet = true; m_deploymentTargets = value; }
+
+    /**
+     * <p>[Service-managed permissions] The AWS Organizations accounts for which to
+     * create stack instances in the specified Regions.</p> <p>You can specify
+     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     */
+    inline void SetDeploymentTargets(DeploymentTargets&& value) { m_deploymentTargetsHasBeenSet = true; m_deploymentTargets = std::move(value); }
+
+    /**
+     * <p>[Service-managed permissions] The AWS Organizations accounts for which to
+     * create stack instances in the specified Regions.</p> <p>You can specify
+     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     */
+    inline CreateStackInstancesRequest& WithDeploymentTargets(const DeploymentTargets& value) { SetDeploymentTargets(value); return *this;}
+
+    /**
+     * <p>[Service-managed permissions] The AWS Organizations accounts for which to
+     * create stack instances in the specified Regions.</p> <p>You can specify
+     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     */
+    inline CreateStackInstancesRequest& WithDeploymentTargets(DeploymentTargets&& value) { SetDeploymentTargets(std::move(value)); return *this;}
+
+
+    /**
+     * <p>The names of one or more Regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline const Aws::Vector<Aws::String>& GetRegions() const{ return m_regions; }
 
     /**
-     * <p>The names of one or more regions where you want to create stack instances
+     * <p>The names of one or more Regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline bool RegionsHasBeenSet() const { return m_regionsHasBeenSet; }
 
     /**
-     * <p>The names of one or more regions where you want to create stack instances
+     * <p>The names of one or more Regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline void SetRegions(const Aws::Vector<Aws::String>& value) { m_regionsHasBeenSet = true; m_regions = value; }
 
     /**
-     * <p>The names of one or more regions where you want to create stack instances
+     * <p>The names of one or more Regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline void SetRegions(Aws::Vector<Aws::String>&& value) { m_regionsHasBeenSet = true; m_regions = std::move(value); }
 
     /**
-     * <p>The names of one or more regions where you want to create stack instances
+     * <p>The names of one or more Regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline CreateStackInstancesRequest& WithRegions(const Aws::Vector<Aws::String>& value) { SetRegions(value); return *this;}
 
     /**
-     * <p>The names of one or more regions where you want to create stack instances
+     * <p>The names of one or more Regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline CreateStackInstancesRequest& WithRegions(Aws::Vector<Aws::String>&& value) { SetRegions(std::move(value)); return *this;}
 
     /**
-     * <p>The names of one or more regions where you want to create stack instances
+     * <p>The names of one or more Regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline CreateStackInstancesRequest& AddRegions(const Aws::String& value) { m_regionsHasBeenSet = true; m_regions.push_back(value); return *this; }
 
     /**
-     * <p>The names of one or more regions where you want to create stack instances
+     * <p>The names of one or more Regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline CreateStackInstancesRequest& AddRegions(Aws::String&& value) { m_regionsHasBeenSet = true; m_regions.push_back(std::move(value)); return *this; }
 
     /**
-     * <p>The names of one or more regions where you want to create stack instances
+     * <p>The names of one or more Regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline CreateStackInstancesRequest& AddRegions(const char* value) { m_regionsHasBeenSet = true; m_regions.push_back(value); return *this; }
@@ -212,7 +265,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and regions. When specifying
+     * to all stack instances in the specified accounts and Regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -236,7 +289,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and regions. When specifying
+     * to all stack instances in the specified accounts and Regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -260,7 +313,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and regions. When specifying
+     * to all stack instances in the specified accounts and Regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -284,7 +337,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and regions. When specifying
+     * to all stack instances in the specified accounts and Regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -308,7 +361,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and regions. When specifying
+     * to all stack instances in the specified accounts and Regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -332,7 +385,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and regions. When specifying
+     * to all stack instances in the specified accounts and Regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -356,7 +409,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and regions. When specifying
+     * to all stack instances in the specified accounts and Regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -380,7 +433,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and regions. When specifying
+     * to all stack instances in the specified accounts and Regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -529,6 +582,103 @@ namespace Model
      */
     inline CreateStackInstancesRequest& WithOperationId(const char* value) { SetOperationId(value); return *this;}
 
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline const CallAs& GetCallAs() const{ return m_callAs; }
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline bool CallAsHasBeenSet() const { return m_callAsHasBeenSet; }
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline void SetCallAs(const CallAs& value) { m_callAsHasBeenSet = true; m_callAs = value; }
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline void SetCallAs(CallAs&& value) { m_callAsHasBeenSet = true; m_callAs = std::move(value); }
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline CreateStackInstancesRequest& WithCallAs(const CallAs& value) { SetCallAs(value); return *this;}
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline CreateStackInstancesRequest& WithCallAs(CallAs&& value) { SetCallAs(std::move(value)); return *this;}
+
   private:
 
     Aws::String m_stackSetName;
@@ -537,6 +687,9 @@ namespace Model
     Aws::Vector<Aws::String> m_accounts;
     bool m_accountsHasBeenSet;
 
+    DeploymentTargets m_deploymentTargets;
+    bool m_deploymentTargetsHasBeenSet;
+
     Aws::Vector<Aws::String> m_regions;
     bool m_regionsHasBeenSet;
 
@@ -548,6 +701,9 @@ namespace Model
 
     Aws::String m_operationId;
     bool m_operationIdHasBeenSet;
+
+    CallAs m_callAs;
+    bool m_callAsHasBeenSet;
   };
 
 } // namespace Model
