@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/cloudformation/CloudFormation_EXPORTS.h>
@@ -20,6 +10,7 @@
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/cloudformation/model/DeploymentTargets.h>
 #include <aws/cloudformation/model/StackSetOperationPreferences.h>
+#include <aws/cloudformation/model/CallAs.h>
 #include <utility>
 #include <aws/core/utils/UUID.h>
 
@@ -164,90 +155,90 @@ namespace Model
 
 
     /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts
-     * from which to delete stack instances.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     * <p>[Service-managed permissions] The AWS Organizations accounts from which to
+     * delete stack instances.</p> <p>You can specify <code>Accounts</code> or
+     * <code>DeploymentTargets</code>, but not both.</p>
      */
     inline const DeploymentTargets& GetDeploymentTargets() const{ return m_deploymentTargets; }
 
     /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts
-     * from which to delete stack instances.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     * <p>[Service-managed permissions] The AWS Organizations accounts from which to
+     * delete stack instances.</p> <p>You can specify <code>Accounts</code> or
+     * <code>DeploymentTargets</code>, but not both.</p>
      */
     inline bool DeploymentTargetsHasBeenSet() const { return m_deploymentTargetsHasBeenSet; }
 
     /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts
-     * from which to delete stack instances.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     * <p>[Service-managed permissions] The AWS Organizations accounts from which to
+     * delete stack instances.</p> <p>You can specify <code>Accounts</code> or
+     * <code>DeploymentTargets</code>, but not both.</p>
      */
     inline void SetDeploymentTargets(const DeploymentTargets& value) { m_deploymentTargetsHasBeenSet = true; m_deploymentTargets = value; }
 
     /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts
-     * from which to delete stack instances.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     * <p>[Service-managed permissions] The AWS Organizations accounts from which to
+     * delete stack instances.</p> <p>You can specify <code>Accounts</code> or
+     * <code>DeploymentTargets</code>, but not both.</p>
      */
     inline void SetDeploymentTargets(DeploymentTargets&& value) { m_deploymentTargetsHasBeenSet = true; m_deploymentTargets = std::move(value); }
 
     /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts
-     * from which to delete stack instances.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     * <p>[Service-managed permissions] The AWS Organizations accounts from which to
+     * delete stack instances.</p> <p>You can specify <code>Accounts</code> or
+     * <code>DeploymentTargets</code>, but not both.</p>
      */
     inline DeleteStackInstancesRequest& WithDeploymentTargets(const DeploymentTargets& value) { SetDeploymentTargets(value); return *this;}
 
     /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts
-     * from which to delete stack instances.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
+     * <p>[Service-managed permissions] The AWS Organizations accounts from which to
+     * delete stack instances.</p> <p>You can specify <code>Accounts</code> or
+     * <code>DeploymentTargets</code>, but not both.</p>
      */
     inline DeleteStackInstancesRequest& WithDeploymentTargets(DeploymentTargets&& value) { SetDeploymentTargets(std::move(value)); return *this;}
 
 
     /**
-     * <p>The regions where you want to delete stack set instances. </p>
+     * <p>The Regions where you want to delete stack set instances. </p>
      */
     inline const Aws::Vector<Aws::String>& GetRegions() const{ return m_regions; }
 
     /**
-     * <p>The regions where you want to delete stack set instances. </p>
+     * <p>The Regions where you want to delete stack set instances. </p>
      */
     inline bool RegionsHasBeenSet() const { return m_regionsHasBeenSet; }
 
     /**
-     * <p>The regions where you want to delete stack set instances. </p>
+     * <p>The Regions where you want to delete stack set instances. </p>
      */
     inline void SetRegions(const Aws::Vector<Aws::String>& value) { m_regionsHasBeenSet = true; m_regions = value; }
 
     /**
-     * <p>The regions where you want to delete stack set instances. </p>
+     * <p>The Regions where you want to delete stack set instances. </p>
      */
     inline void SetRegions(Aws::Vector<Aws::String>&& value) { m_regionsHasBeenSet = true; m_regions = std::move(value); }
 
     /**
-     * <p>The regions where you want to delete stack set instances. </p>
+     * <p>The Regions where you want to delete stack set instances. </p>
      */
     inline DeleteStackInstancesRequest& WithRegions(const Aws::Vector<Aws::String>& value) { SetRegions(value); return *this;}
 
     /**
-     * <p>The regions where you want to delete stack set instances. </p>
+     * <p>The Regions where you want to delete stack set instances. </p>
      */
     inline DeleteStackInstancesRequest& WithRegions(Aws::Vector<Aws::String>&& value) { SetRegions(std::move(value)); return *this;}
 
     /**
-     * <p>The regions where you want to delete stack set instances. </p>
+     * <p>The Regions where you want to delete stack set instances. </p>
      */
     inline DeleteStackInstancesRequest& AddRegions(const Aws::String& value) { m_regionsHasBeenSet = true; m_regions.push_back(value); return *this; }
 
     /**
-     * <p>The regions where you want to delete stack set instances. </p>
+     * <p>The Regions where you want to delete stack set instances. </p>
      */
     inline DeleteStackInstancesRequest& AddRegions(Aws::String&& value) { m_regionsHasBeenSet = true; m_regions.push_back(std::move(value)); return *this; }
 
     /**
-     * <p>The regions where you want to delete stack set instances. </p>
+     * <p>The Regions where you want to delete stack set instances. </p>
      */
     inline DeleteStackInstancesRequest& AddRegions(const char* value) { m_regionsHasBeenSet = true; m_regions.push_back(value); return *this; }
 
@@ -416,6 +407,103 @@ namespace Model
      */
     inline DeleteStackInstancesRequest& WithOperationId(const char* value) { SetOperationId(value); return *this;}
 
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline const CallAs& GetCallAs() const{ return m_callAs; }
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline bool CallAsHasBeenSet() const { return m_callAsHasBeenSet; }
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline void SetCallAs(const CallAs& value) { m_callAsHasBeenSet = true; m_callAs = value; }
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline void SetCallAs(CallAs&& value) { m_callAsHasBeenSet = true; m_callAs = std::move(value); }
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline DeleteStackInstancesRequest& WithCallAs(const CallAs& value) { SetCallAs(value); return *this;}
+
+    /**
+     * <p>[Service-managed permissions] Specifies whether you are acting as an account
+     * administrator in the organization's management account or as a delegated
+     * administrator in a member account.</p> <p>By default, <code>SELF</code> is
+     * specified. Use <code>SELF</code> for stack sets with self-managed
+     * permissions.</p> <ul> <li> <p>If you are signed in to the management account,
+     * specify <code>SELF</code>.</p> </li> <li> <p>If you are signed in to a delegated
+     * administrator account, specify <code>DELEGATED_ADMIN</code>.</p> <p>Your AWS
+     * account must be registered as a delegated administrator in the management
+     * account. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html">Register
+     * a delegated administrator</a> in the <i>AWS CloudFormation User Guide</i>.</p>
+     * </li> </ul>
+     */
+    inline DeleteStackInstancesRequest& WithCallAs(CallAs&& value) { SetCallAs(std::move(value)); return *this;}
+
   private:
 
     Aws::String m_stackSetName;
@@ -438,6 +526,9 @@ namespace Model
 
     Aws::String m_operationId;
     bool m_operationIdHasBeenSet;
+
+    CallAs m_callAs;
+    bool m_callAsHasBeenSet;
   };
 
 } // namespace Model
