@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/codebuild/CodeBuild_EXPORTS.h>
@@ -26,6 +16,7 @@
 #include <aws/codebuild/model/VpcConfig.h>
 #include <aws/codebuild/model/ProjectBadge.h>
 #include <aws/codebuild/model/LogsConfig.h>
+#include <aws/codebuild/model/ProjectBuildBatchConfig.h>
 #include <aws/codebuild/model/ProjectSourceVersion.h>
 #include <aws/codebuild/model/Tag.h>
 #include <aws/codebuild/model/ProjectFileSystemLocation.h>
@@ -215,42 +206,42 @@ namespace Model
 
 
     /**
-     * <p> An array of <code>ProjectSource</code> objects. </p>
+     * <p>An array of <code>ProjectSource</code> objects. </p>
      */
     inline const Aws::Vector<ProjectSource>& GetSecondarySources() const{ return m_secondarySources; }
 
     /**
-     * <p> An array of <code>ProjectSource</code> objects. </p>
+     * <p>An array of <code>ProjectSource</code> objects. </p>
      */
     inline bool SecondarySourcesHasBeenSet() const { return m_secondarySourcesHasBeenSet; }
 
     /**
-     * <p> An array of <code>ProjectSource</code> objects. </p>
+     * <p>An array of <code>ProjectSource</code> objects. </p>
      */
     inline void SetSecondarySources(const Aws::Vector<ProjectSource>& value) { m_secondarySourcesHasBeenSet = true; m_secondarySources = value; }
 
     /**
-     * <p> An array of <code>ProjectSource</code> objects. </p>
+     * <p>An array of <code>ProjectSource</code> objects. </p>
      */
     inline void SetSecondarySources(Aws::Vector<ProjectSource>&& value) { m_secondarySourcesHasBeenSet = true; m_secondarySources = std::move(value); }
 
     /**
-     * <p> An array of <code>ProjectSource</code> objects. </p>
+     * <p>An array of <code>ProjectSource</code> objects. </p>
      */
     inline Project& WithSecondarySources(const Aws::Vector<ProjectSource>& value) { SetSecondarySources(value); return *this;}
 
     /**
-     * <p> An array of <code>ProjectSource</code> objects. </p>
+     * <p>An array of <code>ProjectSource</code> objects. </p>
      */
     inline Project& WithSecondarySources(Aws::Vector<ProjectSource>&& value) { SetSecondarySources(std::move(value)); return *this;}
 
     /**
-     * <p> An array of <code>ProjectSource</code> objects. </p>
+     * <p>An array of <code>ProjectSource</code> objects. </p>
      */
     inline Project& AddSecondarySources(const ProjectSource& value) { m_secondarySourcesHasBeenSet = true; m_secondarySources.push_back(value); return *this; }
 
     /**
-     * <p> An array of <code>ProjectSource</code> objects. </p>
+     * <p>An array of <code>ProjectSource</code> objects. </p>
      */
     inline Project& AddSecondarySources(ProjectSource&& value) { m_secondarySourcesHasBeenSet = true; m_secondarySources.push_back(std::move(value)); return *this; }
 
@@ -267,12 +258,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p>If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p>For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -290,12 +280,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p>If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p>For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -313,12 +302,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p>If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p>For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -336,12 +324,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p>If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p>For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -359,12 +346,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p>If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p>For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -382,12 +368,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p>If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p>For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -405,12 +390,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p>If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p>For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -428,12 +412,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p>If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p>For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -441,7 +424,7 @@ namespace Model
 
 
     /**
-     * <p> An array of <code>ProjectSourceVersion</code> objects. If
+     * <p>An array of <code>ProjectSourceVersion</code> objects. If
      * <code>secondarySourceVersions</code> is specified at the build level, then they
      * take over these <code>secondarySourceVersions</code> (at the project level).
      * </p>
@@ -449,7 +432,7 @@ namespace Model
     inline const Aws::Vector<ProjectSourceVersion>& GetSecondarySourceVersions() const{ return m_secondarySourceVersions; }
 
     /**
-     * <p> An array of <code>ProjectSourceVersion</code> objects. If
+     * <p>An array of <code>ProjectSourceVersion</code> objects. If
      * <code>secondarySourceVersions</code> is specified at the build level, then they
      * take over these <code>secondarySourceVersions</code> (at the project level).
      * </p>
@@ -457,7 +440,7 @@ namespace Model
     inline bool SecondarySourceVersionsHasBeenSet() const { return m_secondarySourceVersionsHasBeenSet; }
 
     /**
-     * <p> An array of <code>ProjectSourceVersion</code> objects. If
+     * <p>An array of <code>ProjectSourceVersion</code> objects. If
      * <code>secondarySourceVersions</code> is specified at the build level, then they
      * take over these <code>secondarySourceVersions</code> (at the project level).
      * </p>
@@ -465,7 +448,7 @@ namespace Model
     inline void SetSecondarySourceVersions(const Aws::Vector<ProjectSourceVersion>& value) { m_secondarySourceVersionsHasBeenSet = true; m_secondarySourceVersions = value; }
 
     /**
-     * <p> An array of <code>ProjectSourceVersion</code> objects. If
+     * <p>An array of <code>ProjectSourceVersion</code> objects. If
      * <code>secondarySourceVersions</code> is specified at the build level, then they
      * take over these <code>secondarySourceVersions</code> (at the project level).
      * </p>
@@ -473,7 +456,7 @@ namespace Model
     inline void SetSecondarySourceVersions(Aws::Vector<ProjectSourceVersion>&& value) { m_secondarySourceVersionsHasBeenSet = true; m_secondarySourceVersions = std::move(value); }
 
     /**
-     * <p> An array of <code>ProjectSourceVersion</code> objects. If
+     * <p>An array of <code>ProjectSourceVersion</code> objects. If
      * <code>secondarySourceVersions</code> is specified at the build level, then they
      * take over these <code>secondarySourceVersions</code> (at the project level).
      * </p>
@@ -481,7 +464,7 @@ namespace Model
     inline Project& WithSecondarySourceVersions(const Aws::Vector<ProjectSourceVersion>& value) { SetSecondarySourceVersions(value); return *this;}
 
     /**
-     * <p> An array of <code>ProjectSourceVersion</code> objects. If
+     * <p>An array of <code>ProjectSourceVersion</code> objects. If
      * <code>secondarySourceVersions</code> is specified at the build level, then they
      * take over these <code>secondarySourceVersions</code> (at the project level).
      * </p>
@@ -489,7 +472,7 @@ namespace Model
     inline Project& WithSecondarySourceVersions(Aws::Vector<ProjectSourceVersion>&& value) { SetSecondarySourceVersions(std::move(value)); return *this;}
 
     /**
-     * <p> An array of <code>ProjectSourceVersion</code> objects. If
+     * <p>An array of <code>ProjectSourceVersion</code> objects. If
      * <code>secondarySourceVersions</code> is specified at the build level, then they
      * take over these <code>secondarySourceVersions</code> (at the project level).
      * </p>
@@ -497,7 +480,7 @@ namespace Model
     inline Project& AddSecondarySourceVersions(const ProjectSourceVersion& value) { m_secondarySourceVersionsHasBeenSet = true; m_secondarySourceVersions.push_back(value); return *this; }
 
     /**
-     * <p> An array of <code>ProjectSourceVersion</code> objects. If
+     * <p>An array of <code>ProjectSourceVersion</code> objects. If
      * <code>secondarySourceVersions</code> is specified at the build level, then they
      * take over these <code>secondarySourceVersions</code> (at the project level).
      * </p>
@@ -537,42 +520,42 @@ namespace Model
 
 
     /**
-     * <p> An array of <code>ProjectArtifacts</code> objects. </p>
+     * <p>An array of <code>ProjectArtifacts</code> objects. </p>
      */
     inline const Aws::Vector<ProjectArtifacts>& GetSecondaryArtifacts() const{ return m_secondaryArtifacts; }
 
     /**
-     * <p> An array of <code>ProjectArtifacts</code> objects. </p>
+     * <p>An array of <code>ProjectArtifacts</code> objects. </p>
      */
     inline bool SecondaryArtifactsHasBeenSet() const { return m_secondaryArtifactsHasBeenSet; }
 
     /**
-     * <p> An array of <code>ProjectArtifacts</code> objects. </p>
+     * <p>An array of <code>ProjectArtifacts</code> objects. </p>
      */
     inline void SetSecondaryArtifacts(const Aws::Vector<ProjectArtifacts>& value) { m_secondaryArtifactsHasBeenSet = true; m_secondaryArtifacts = value; }
 
     /**
-     * <p> An array of <code>ProjectArtifacts</code> objects. </p>
+     * <p>An array of <code>ProjectArtifacts</code> objects. </p>
      */
     inline void SetSecondaryArtifacts(Aws::Vector<ProjectArtifacts>&& value) { m_secondaryArtifactsHasBeenSet = true; m_secondaryArtifacts = std::move(value); }
 
     /**
-     * <p> An array of <code>ProjectArtifacts</code> objects. </p>
+     * <p>An array of <code>ProjectArtifacts</code> objects. </p>
      */
     inline Project& WithSecondaryArtifacts(const Aws::Vector<ProjectArtifacts>& value) { SetSecondaryArtifacts(value); return *this;}
 
     /**
-     * <p> An array of <code>ProjectArtifacts</code> objects. </p>
+     * <p>An array of <code>ProjectArtifacts</code> objects. </p>
      */
     inline Project& WithSecondaryArtifacts(Aws::Vector<ProjectArtifacts>&& value) { SetSecondaryArtifacts(std::move(value)); return *this;}
 
     /**
-     * <p> An array of <code>ProjectArtifacts</code> objects. </p>
+     * <p>An array of <code>ProjectArtifacts</code> objects. </p>
      */
     inline Project& AddSecondaryArtifacts(const ProjectArtifacts& value) { m_secondaryArtifactsHasBeenSet = true; m_secondaryArtifacts.push_back(value); return *this; }
 
     /**
-     * <p> An array of <code>ProjectArtifacts</code> objects. </p>
+     * <p>An array of <code>ProjectArtifacts</code> objects. </p>
      */
     inline Project& AddSecondaryArtifacts(ProjectArtifacts&& value) { m_secondaryArtifactsHasBeenSet = true; m_secondaryArtifacts.push_back(std::move(value)); return *this; }
 
@@ -726,25 +709,25 @@ namespace Model
 
 
     /**
-     * <p> The number of minutes a build is allowed to be queued before it times out.
+     * <p>The number of minutes a build is allowed to be queued before it times out.
      * </p>
      */
     inline int GetQueuedTimeoutInMinutes() const{ return m_queuedTimeoutInMinutes; }
 
     /**
-     * <p> The number of minutes a build is allowed to be queued before it times out.
+     * <p>The number of minutes a build is allowed to be queued before it times out.
      * </p>
      */
     inline bool QueuedTimeoutInMinutesHasBeenSet() const { return m_queuedTimeoutInMinutesHasBeenSet; }
 
     /**
-     * <p> The number of minutes a build is allowed to be queued before it times out.
+     * <p>The number of minutes a build is allowed to be queued before it times out.
      * </p>
      */
     inline void SetQueuedTimeoutInMinutes(int value) { m_queuedTimeoutInMinutesHasBeenSet = true; m_queuedTimeoutInMinutes = value; }
 
     /**
-     * <p> The number of minutes a build is allowed to be queued before it times out.
+     * <p>The number of minutes a build is allowed to be queued before it times out.
      * </p>
      */
     inline Project& WithQueuedTimeoutInMinutes(int value) { SetQueuedTimeoutInMinutes(value); return *this;}
@@ -752,130 +735,138 @@ namespace Model
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p>You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline const Aws::String& GetEncryptionKey() const{ return m_encryptionKey; }
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p>You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline bool EncryptionKeyHasBeenSet() const { return m_encryptionKeyHasBeenSet; }
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p>You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline void SetEncryptionKey(const Aws::String& value) { m_encryptionKeyHasBeenSet = true; m_encryptionKey = value; }
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p>You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline void SetEncryptionKey(Aws::String&& value) { m_encryptionKeyHasBeenSet = true; m_encryptionKey = std::move(value); }
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p>You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline void SetEncryptionKey(const char* value) { m_encryptionKeyHasBeenSet = true; m_encryptionKey.assign(value); }
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p>You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline Project& WithEncryptionKey(const Aws::String& value) { SetEncryptionKey(value); return *this;}
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p>You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline Project& WithEncryptionKey(Aws::String&& value) { SetEncryptionKey(std::move(value)); return *this;}
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p>You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline Project& WithEncryptionKey(const char* value) { SetEncryptionKey(value); return *this;}
 
 
     /**
-     * <p>The tags for this build project.</p> <p>These tags are available for use by
-     * AWS services that support AWS CodeBuild build project tags.</p>
+     * <p>A list of tag key and value pairs associated with this build project.</p>
+     * <p>These tags are available for use by AWS services that support AWS CodeBuild
+     * build project tags.</p>
      */
     inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
 
     /**
-     * <p>The tags for this build project.</p> <p>These tags are available for use by
-     * AWS services that support AWS CodeBuild build project tags.</p>
+     * <p>A list of tag key and value pairs associated with this build project.</p>
+     * <p>These tags are available for use by AWS services that support AWS CodeBuild
+     * build project tags.</p>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
     /**
-     * <p>The tags for this build project.</p> <p>These tags are available for use by
-     * AWS services that support AWS CodeBuild build project tags.</p>
+     * <p>A list of tag key and value pairs associated with this build project.</p>
+     * <p>These tags are available for use by AWS services that support AWS CodeBuild
+     * build project tags.</p>
      */
     inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
     /**
-     * <p>The tags for this build project.</p> <p>These tags are available for use by
-     * AWS services that support AWS CodeBuild build project tags.</p>
+     * <p>A list of tag key and value pairs associated with this build project.</p>
+     * <p>These tags are available for use by AWS services that support AWS CodeBuild
+     * build project tags.</p>
      */
     inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
     /**
-     * <p>The tags for this build project.</p> <p>These tags are available for use by
-     * AWS services that support AWS CodeBuild build project tags.</p>
+     * <p>A list of tag key and value pairs associated with this build project.</p>
+     * <p>These tags are available for use by AWS services that support AWS CodeBuild
+     * build project tags.</p>
      */
     inline Project& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
 
     /**
-     * <p>The tags for this build project.</p> <p>These tags are available for use by
-     * AWS services that support AWS CodeBuild build project tags.</p>
+     * <p>A list of tag key and value pairs associated with this build project.</p>
+     * <p>These tags are available for use by AWS services that support AWS CodeBuild
+     * build project tags.</p>
      */
     inline Project& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
 
     /**
-     * <p>The tags for this build project.</p> <p>These tags are available for use by
-     * AWS services that support AWS CodeBuild build project tags.</p>
+     * <p>A list of tag key and value pairs associated with this build project.</p>
+     * <p>These tags are available for use by AWS services that support AWS CodeBuild
+     * build project tags.</p>
      */
     inline Project& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
 
     /**
-     * <p>The tags for this build project.</p> <p>These tags are available for use by
-     * AWS services that support AWS CodeBuild build project tags.</p>
+     * <p>A list of tag key and value pairs associated with this build project.</p>
+     * <p>These tags are available for use by AWS services that support AWS CodeBuild
+     * build project tags.</p>
      */
     inline Project& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
@@ -1048,37 +1039,37 @@ namespace Model
 
 
     /**
-     * <p> Information about logs for the build project. A project can create logs in
+     * <p>Information about logs for the build project. A project can create logs in
      * Amazon CloudWatch Logs, an S3 bucket, or both. </p>
      */
     inline const LogsConfig& GetLogsConfig() const{ return m_logsConfig; }
 
     /**
-     * <p> Information about logs for the build project. A project can create logs in
+     * <p>Information about logs for the build project. A project can create logs in
      * Amazon CloudWatch Logs, an S3 bucket, or both. </p>
      */
     inline bool LogsConfigHasBeenSet() const { return m_logsConfigHasBeenSet; }
 
     /**
-     * <p> Information about logs for the build project. A project can create logs in
+     * <p>Information about logs for the build project. A project can create logs in
      * Amazon CloudWatch Logs, an S3 bucket, or both. </p>
      */
     inline void SetLogsConfig(const LogsConfig& value) { m_logsConfigHasBeenSet = true; m_logsConfig = value; }
 
     /**
-     * <p> Information about logs for the build project. A project can create logs in
+     * <p>Information about logs for the build project. A project can create logs in
      * Amazon CloudWatch Logs, an S3 bucket, or both. </p>
      */
     inline void SetLogsConfig(LogsConfig&& value) { m_logsConfigHasBeenSet = true; m_logsConfig = std::move(value); }
 
     /**
-     * <p> Information about logs for the build project. A project can create logs in
+     * <p>Information about logs for the build project. A project can create logs in
      * Amazon CloudWatch Logs, an S3 bucket, or both. </p>
      */
     inline Project& WithLogsConfig(const LogsConfig& value) { SetLogsConfig(value); return *this;}
 
     /**
-     * <p> Information about logs for the build project. A project can create logs in
+     * <p>Information about logs for the build project. A project can create logs in
      * Amazon CloudWatch Logs, an S3 bucket, or both. </p>
      */
     inline Project& WithLogsConfig(LogsConfig&& value) { SetLogsConfig(std::move(value)); return *this;}
@@ -1156,6 +1147,76 @@ namespace Model
      */
     inline Project& AddFileSystemLocations(ProjectFileSystemLocation&& value) { m_fileSystemLocationsHasBeenSet = true; m_fileSystemLocations.push_back(std::move(value)); return *this; }
 
+
+    /**
+     * <p>A <a>ProjectBuildBatchConfig</a> object that defines the batch build options
+     * for the project.</p>
+     */
+    inline const ProjectBuildBatchConfig& GetBuildBatchConfig() const{ return m_buildBatchConfig; }
+
+    /**
+     * <p>A <a>ProjectBuildBatchConfig</a> object that defines the batch build options
+     * for the project.</p>
+     */
+    inline bool BuildBatchConfigHasBeenSet() const { return m_buildBatchConfigHasBeenSet; }
+
+    /**
+     * <p>A <a>ProjectBuildBatchConfig</a> object that defines the batch build options
+     * for the project.</p>
+     */
+    inline void SetBuildBatchConfig(const ProjectBuildBatchConfig& value) { m_buildBatchConfigHasBeenSet = true; m_buildBatchConfig = value; }
+
+    /**
+     * <p>A <a>ProjectBuildBatchConfig</a> object that defines the batch build options
+     * for the project.</p>
+     */
+    inline void SetBuildBatchConfig(ProjectBuildBatchConfig&& value) { m_buildBatchConfigHasBeenSet = true; m_buildBatchConfig = std::move(value); }
+
+    /**
+     * <p>A <a>ProjectBuildBatchConfig</a> object that defines the batch build options
+     * for the project.</p>
+     */
+    inline Project& WithBuildBatchConfig(const ProjectBuildBatchConfig& value) { SetBuildBatchConfig(value); return *this;}
+
+    /**
+     * <p>A <a>ProjectBuildBatchConfig</a> object that defines the batch build options
+     * for the project.</p>
+     */
+    inline Project& WithBuildBatchConfig(ProjectBuildBatchConfig&& value) { SetBuildBatchConfig(std::move(value)); return *this;}
+
+
+    /**
+     * <p>The maximum number of concurrent builds that are allowed for this
+     * project.</p> <p>New builds are only started if the current number of builds is
+     * less than or equal to this limit. If the current build count meets this limit,
+     * new builds are throttled and are not run.</p>
+     */
+    inline int GetConcurrentBuildLimit() const{ return m_concurrentBuildLimit; }
+
+    /**
+     * <p>The maximum number of concurrent builds that are allowed for this
+     * project.</p> <p>New builds are only started if the current number of builds is
+     * less than or equal to this limit. If the current build count meets this limit,
+     * new builds are throttled and are not run.</p>
+     */
+    inline bool ConcurrentBuildLimitHasBeenSet() const { return m_concurrentBuildLimitHasBeenSet; }
+
+    /**
+     * <p>The maximum number of concurrent builds that are allowed for this
+     * project.</p> <p>New builds are only started if the current number of builds is
+     * less than or equal to this limit. If the current build count meets this limit,
+     * new builds are throttled and are not run.</p>
+     */
+    inline void SetConcurrentBuildLimit(int value) { m_concurrentBuildLimitHasBeenSet = true; m_concurrentBuildLimit = value; }
+
+    /**
+     * <p>The maximum number of concurrent builds that are allowed for this
+     * project.</p> <p>New builds are only started if the current number of builds is
+     * less than or equal to this limit. If the current build count meets this limit,
+     * new builds are throttled and are not run.</p>
+     */
+    inline Project& WithConcurrentBuildLimit(int value) { SetConcurrentBuildLimit(value); return *this;}
+
   private:
 
     Aws::String m_name;
@@ -1226,6 +1287,12 @@ namespace Model
 
     Aws::Vector<ProjectFileSystemLocation> m_fileSystemLocations;
     bool m_fileSystemLocationsHasBeenSet;
+
+    ProjectBuildBatchConfig m_buildBatchConfig;
+    bool m_buildBatchConfigHasBeenSet;
+
+    int m_concurrentBuildLimit;
+    bool m_concurrentBuildLimitHasBeenSet;
   };
 
 } // namespace Model
