@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/codebuild/CodeBuild_EXPORTS.h>
@@ -24,8 +14,10 @@
 #include <aws/codebuild/model/ProjectEnvironment.h>
 #include <aws/codebuild/model/VpcConfig.h>
 #include <aws/codebuild/model/LogsConfig.h>
+#include <aws/codebuild/model/ProjectBuildBatchConfig.h>
 #include <aws/codebuild/model/ProjectSourceVersion.h>
 #include <aws/codebuild/model/Tag.h>
+#include <aws/codebuild/model/ProjectFileSystemLocation.h>
 #include <utility>
 
 namespace Aws
@@ -54,50 +46,50 @@ namespace Model
 
 
     /**
-     * <p>The name of the build project.</p> <note> <p>You cannot change a build
-     * project's name.</p> </note>
+     * <p>The name of the build project.</p>  <p>You cannot change a build
+     * project's name.</p> 
      */
     inline const Aws::String& GetName() const{ return m_name; }
 
     /**
-     * <p>The name of the build project.</p> <note> <p>You cannot change a build
-     * project's name.</p> </note>
+     * <p>The name of the build project.</p>  <p>You cannot change a build
+     * project's name.</p> 
      */
     inline bool NameHasBeenSet() const { return m_nameHasBeenSet; }
 
     /**
-     * <p>The name of the build project.</p> <note> <p>You cannot change a build
-     * project's name.</p> </note>
+     * <p>The name of the build project.</p>  <p>You cannot change a build
+     * project's name.</p> 
      */
     inline void SetName(const Aws::String& value) { m_nameHasBeenSet = true; m_name = value; }
 
     /**
-     * <p>The name of the build project.</p> <note> <p>You cannot change a build
-     * project's name.</p> </note>
+     * <p>The name of the build project.</p>  <p>You cannot change a build
+     * project's name.</p> 
      */
     inline void SetName(Aws::String&& value) { m_nameHasBeenSet = true; m_name = std::move(value); }
 
     /**
-     * <p>The name of the build project.</p> <note> <p>You cannot change a build
-     * project's name.</p> </note>
+     * <p>The name of the build project.</p>  <p>You cannot change a build
+     * project's name.</p> 
      */
     inline void SetName(const char* value) { m_nameHasBeenSet = true; m_name.assign(value); }
 
     /**
-     * <p>The name of the build project.</p> <note> <p>You cannot change a build
-     * project's name.</p> </note>
+     * <p>The name of the build project.</p>  <p>You cannot change a build
+     * project's name.</p> 
      */
     inline UpdateProjectRequest& WithName(const Aws::String& value) { SetName(value); return *this;}
 
     /**
-     * <p>The name of the build project.</p> <note> <p>You cannot change a build
-     * project's name.</p> </note>
+     * <p>The name of the build project.</p>  <p>You cannot change a build
+     * project's name.</p> 
      */
     inline UpdateProjectRequest& WithName(Aws::String&& value) { SetName(std::move(value)); return *this;}
 
     /**
-     * <p>The name of the build project.</p> <note> <p>You cannot change a build
-     * project's name.</p> </note>
+     * <p>The name of the build project.</p>  <p>You cannot change a build
+     * project's name.</p> 
      */
     inline UpdateProjectRequest& WithName(const char* value) { SetName(value); return *this;}
 
@@ -233,12 +225,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p> If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p> For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -256,12 +247,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p> If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p> For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -279,12 +269,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p> If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p> For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -302,12 +291,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p> If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p> For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -325,12 +313,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p> If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p> For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -348,12 +335,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p> If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p> For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -371,12 +357,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p> If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p> For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -394,12 +379,11 @@ namespace Model
      * used.</p> </li> <li> <p>For Bitbucket: the commit ID, branch name, or tag name
      * that corresponds to the version of the source code you want to build. If a
      * branch name is specified, the branch's HEAD commit ID is used. If not specified,
-     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon Simple
-     * Storage Service (Amazon S3): the version ID of the object that represents the
-     * build input ZIP file to use.</p> </li> </ul> <p> If <code>sourceVersion</code>
-     * is specified at the build level, then that version takes precedence over this
-     * <code>sourceVersion</code> (at the project level). </p> <p> For more
-     * information, see <a
+     * the default branch's HEAD commit ID is used.</p> </li> <li> <p>For Amazon S3:
+     * the version ID of the object that represents the build input ZIP file to
+     * use.</p> </li> </ul> <p> If <code>sourceVersion</code> is specified at the build
+     * level, then that version takes precedence over this <code>sourceVersion</code>
+     * (at the project level). </p> <p> For more information, see <a
      * href="https://docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html">Source
      * Version Sample with CodeBuild</a> in the <i>AWS CodeBuild User Guide</i>. </p>
      */
@@ -736,138 +720,138 @@ namespace Model
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p> You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline const Aws::String& GetEncryptionKey() const{ return m_encryptionKey; }
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p> You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline bool EncryptionKeyHasBeenSet() const { return m_encryptionKeyHasBeenSet; }
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p> You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline void SetEncryptionKey(const Aws::String& value) { m_encryptionKeyHasBeenSet = true; m_encryptionKey = value; }
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p> You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline void SetEncryptionKey(Aws::String&& value) { m_encryptionKeyHasBeenSet = true; m_encryptionKey = std::move(value); }
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p> You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline void SetEncryptionKey(const char* value) { m_encryptionKeyHasBeenSet = true; m_encryptionKey.assign(value); }
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p> You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline UpdateProjectRequest& WithEncryptionKey(const Aws::String& value) { SetEncryptionKey(value); return *this;}
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p> You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline UpdateProjectRequest& WithEncryptionKey(Aws::String&& value) { SetEncryptionKey(std::move(value)); return *this;}
 
     /**
      * <p>The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used
-     * for encrypting the build output artifacts.</p> <note> <p> You can use a
+     * for encrypting the build output artifacts.</p>  <p> You can use a
      * cross-account KMS key to encrypt the build output artifacts if your service role
-     * has permission to that key. </p> </note> <p>You can specify either the Amazon
+     * has permission to that key. </p>  <p>You can specify either the Amazon
      * Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the
-     * format <code>alias/<i>alias-name</i> </code>).</p>
+     * format <code>alias/&lt;alias-name&gt;</code>). </p>
      */
     inline UpdateProjectRequest& WithEncryptionKey(const char* value) { SetEncryptionKey(value); return *this;}
 
 
     /**
-     * <p>The replacement set of tags for this build project.</p> <p>These tags are
-     * available for use by AWS services that support AWS CodeBuild build project
-     * tags.</p>
+     * <p>An updated list of tag key and value pairs associated with this build
+     * project.</p> <p>These tags are available for use by AWS services that support
+     * AWS CodeBuild build project tags.</p>
      */
     inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
 
     /**
-     * <p>The replacement set of tags for this build project.</p> <p>These tags are
-     * available for use by AWS services that support AWS CodeBuild build project
-     * tags.</p>
+     * <p>An updated list of tag key and value pairs associated with this build
+     * project.</p> <p>These tags are available for use by AWS services that support
+     * AWS CodeBuild build project tags.</p>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
     /**
-     * <p>The replacement set of tags for this build project.</p> <p>These tags are
-     * available for use by AWS services that support AWS CodeBuild build project
-     * tags.</p>
+     * <p>An updated list of tag key and value pairs associated with this build
+     * project.</p> <p>These tags are available for use by AWS services that support
+     * AWS CodeBuild build project tags.</p>
      */
     inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
     /**
-     * <p>The replacement set of tags for this build project.</p> <p>These tags are
-     * available for use by AWS services that support AWS CodeBuild build project
-     * tags.</p>
+     * <p>An updated list of tag key and value pairs associated with this build
+     * project.</p> <p>These tags are available for use by AWS services that support
+     * AWS CodeBuild build project tags.</p>
      */
     inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
     /**
-     * <p>The replacement set of tags for this build project.</p> <p>These tags are
-     * available for use by AWS services that support AWS CodeBuild build project
-     * tags.</p>
+     * <p>An updated list of tag key and value pairs associated with this build
+     * project.</p> <p>These tags are available for use by AWS services that support
+     * AWS CodeBuild build project tags.</p>
      */
     inline UpdateProjectRequest& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
 
     /**
-     * <p>The replacement set of tags for this build project.</p> <p>These tags are
-     * available for use by AWS services that support AWS CodeBuild build project
-     * tags.</p>
+     * <p>An updated list of tag key and value pairs associated with this build
+     * project.</p> <p>These tags are available for use by AWS services that support
+     * AWS CodeBuild build project tags.</p>
      */
     inline UpdateProjectRequest& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
 
     /**
-     * <p>The replacement set of tags for this build project.</p> <p>These tags are
-     * available for use by AWS services that support AWS CodeBuild build project
-     * tags.</p>
+     * <p>An updated list of tag key and value pairs associated with this build
+     * project.</p> <p>These tags are available for use by AWS services that support
+     * AWS CodeBuild build project tags.</p>
      */
     inline UpdateProjectRequest& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
 
     /**
-     * <p>The replacement set of tags for this build project.</p> <p>These tags are
-     * available for use by AWS services that support AWS CodeBuild build project
-     * tags.</p>
+     * <p>An updated list of tag key and value pairs associated with this build
+     * project.</p> <p>These tags are available for use by AWS services that support
+     * AWS CodeBuild build project tags.</p>
      */
     inline UpdateProjectRequest& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
@@ -964,6 +948,135 @@ namespace Model
      */
     inline UpdateProjectRequest& WithLogsConfig(LogsConfig&& value) { SetLogsConfig(std::move(value)); return *this;}
 
+
+    /**
+     * <p> An array of <code>ProjectFileSystemLocation</code> objects for a CodeBuild
+     * build project. A <code>ProjectFileSystemLocation</code> object specifies the
+     * <code>identifier</code>, <code>location</code>, <code>mountOptions</code>,
+     * <code>mountPoint</code>, and <code>type</code> of a file system created using
+     * Amazon Elastic File System. </p>
+     */
+    inline const Aws::Vector<ProjectFileSystemLocation>& GetFileSystemLocations() const{ return m_fileSystemLocations; }
+
+    /**
+     * <p> An array of <code>ProjectFileSystemLocation</code> objects for a CodeBuild
+     * build project. A <code>ProjectFileSystemLocation</code> object specifies the
+     * <code>identifier</code>, <code>location</code>, <code>mountOptions</code>,
+     * <code>mountPoint</code>, and <code>type</code> of a file system created using
+     * Amazon Elastic File System. </p>
+     */
+    inline bool FileSystemLocationsHasBeenSet() const { return m_fileSystemLocationsHasBeenSet; }
+
+    /**
+     * <p> An array of <code>ProjectFileSystemLocation</code> objects for a CodeBuild
+     * build project. A <code>ProjectFileSystemLocation</code> object specifies the
+     * <code>identifier</code>, <code>location</code>, <code>mountOptions</code>,
+     * <code>mountPoint</code>, and <code>type</code> of a file system created using
+     * Amazon Elastic File System. </p>
+     */
+    inline void SetFileSystemLocations(const Aws::Vector<ProjectFileSystemLocation>& value) { m_fileSystemLocationsHasBeenSet = true; m_fileSystemLocations = value; }
+
+    /**
+     * <p> An array of <code>ProjectFileSystemLocation</code> objects for a CodeBuild
+     * build project. A <code>ProjectFileSystemLocation</code> object specifies the
+     * <code>identifier</code>, <code>location</code>, <code>mountOptions</code>,
+     * <code>mountPoint</code>, and <code>type</code> of a file system created using
+     * Amazon Elastic File System. </p>
+     */
+    inline void SetFileSystemLocations(Aws::Vector<ProjectFileSystemLocation>&& value) { m_fileSystemLocationsHasBeenSet = true; m_fileSystemLocations = std::move(value); }
+
+    /**
+     * <p> An array of <code>ProjectFileSystemLocation</code> objects for a CodeBuild
+     * build project. A <code>ProjectFileSystemLocation</code> object specifies the
+     * <code>identifier</code>, <code>location</code>, <code>mountOptions</code>,
+     * <code>mountPoint</code>, and <code>type</code> of a file system created using
+     * Amazon Elastic File System. </p>
+     */
+    inline UpdateProjectRequest& WithFileSystemLocations(const Aws::Vector<ProjectFileSystemLocation>& value) { SetFileSystemLocations(value); return *this;}
+
+    /**
+     * <p> An array of <code>ProjectFileSystemLocation</code> objects for a CodeBuild
+     * build project. A <code>ProjectFileSystemLocation</code> object specifies the
+     * <code>identifier</code>, <code>location</code>, <code>mountOptions</code>,
+     * <code>mountPoint</code>, and <code>type</code> of a file system created using
+     * Amazon Elastic File System. </p>
+     */
+    inline UpdateProjectRequest& WithFileSystemLocations(Aws::Vector<ProjectFileSystemLocation>&& value) { SetFileSystemLocations(std::move(value)); return *this;}
+
+    /**
+     * <p> An array of <code>ProjectFileSystemLocation</code> objects for a CodeBuild
+     * build project. A <code>ProjectFileSystemLocation</code> object specifies the
+     * <code>identifier</code>, <code>location</code>, <code>mountOptions</code>,
+     * <code>mountPoint</code>, and <code>type</code> of a file system created using
+     * Amazon Elastic File System. </p>
+     */
+    inline UpdateProjectRequest& AddFileSystemLocations(const ProjectFileSystemLocation& value) { m_fileSystemLocationsHasBeenSet = true; m_fileSystemLocations.push_back(value); return *this; }
+
+    /**
+     * <p> An array of <code>ProjectFileSystemLocation</code> objects for a CodeBuild
+     * build project. A <code>ProjectFileSystemLocation</code> object specifies the
+     * <code>identifier</code>, <code>location</code>, <code>mountOptions</code>,
+     * <code>mountPoint</code>, and <code>type</code> of a file system created using
+     * Amazon Elastic File System. </p>
+     */
+    inline UpdateProjectRequest& AddFileSystemLocations(ProjectFileSystemLocation&& value) { m_fileSystemLocationsHasBeenSet = true; m_fileSystemLocations.push_back(std::move(value)); return *this; }
+
+
+    
+    inline const ProjectBuildBatchConfig& GetBuildBatchConfig() const{ return m_buildBatchConfig; }
+
+    
+    inline bool BuildBatchConfigHasBeenSet() const { return m_buildBatchConfigHasBeenSet; }
+
+    
+    inline void SetBuildBatchConfig(const ProjectBuildBatchConfig& value) { m_buildBatchConfigHasBeenSet = true; m_buildBatchConfig = value; }
+
+    
+    inline void SetBuildBatchConfig(ProjectBuildBatchConfig&& value) { m_buildBatchConfigHasBeenSet = true; m_buildBatchConfig = std::move(value); }
+
+    
+    inline UpdateProjectRequest& WithBuildBatchConfig(const ProjectBuildBatchConfig& value) { SetBuildBatchConfig(value); return *this;}
+
+    
+    inline UpdateProjectRequest& WithBuildBatchConfig(ProjectBuildBatchConfig&& value) { SetBuildBatchConfig(std::move(value)); return *this;}
+
+
+    /**
+     * <p>The maximum number of concurrent builds that are allowed for this
+     * project.</p> <p>New builds are only started if the current number of builds is
+     * less than or equal to this limit. If the current build count meets this limit,
+     * new builds are throttled and are not run.</p> <p>To remove this limit, set this
+     * value to -1.</p>
+     */
+    inline int GetConcurrentBuildLimit() const{ return m_concurrentBuildLimit; }
+
+    /**
+     * <p>The maximum number of concurrent builds that are allowed for this
+     * project.</p> <p>New builds are only started if the current number of builds is
+     * less than or equal to this limit. If the current build count meets this limit,
+     * new builds are throttled and are not run.</p> <p>To remove this limit, set this
+     * value to -1.</p>
+     */
+    inline bool ConcurrentBuildLimitHasBeenSet() const { return m_concurrentBuildLimitHasBeenSet; }
+
+    /**
+     * <p>The maximum number of concurrent builds that are allowed for this
+     * project.</p> <p>New builds are only started if the current number of builds is
+     * less than or equal to this limit. If the current build count meets this limit,
+     * new builds are throttled and are not run.</p> <p>To remove this limit, set this
+     * value to -1.</p>
+     */
+    inline void SetConcurrentBuildLimit(int value) { m_concurrentBuildLimitHasBeenSet = true; m_concurrentBuildLimit = value; }
+
+    /**
+     * <p>The maximum number of concurrent builds that are allowed for this
+     * project.</p> <p>New builds are only started if the current number of builds is
+     * less than or equal to this limit. If the current build count meets this limit,
+     * new builds are throttled and are not run.</p> <p>To remove this limit, set this
+     * value to -1.</p>
+     */
+    inline UpdateProjectRequest& WithConcurrentBuildLimit(int value) { SetConcurrentBuildLimit(value); return *this;}
+
   private:
 
     Aws::String m_name;
@@ -1019,6 +1132,15 @@ namespace Model
 
     LogsConfig m_logsConfig;
     bool m_logsConfigHasBeenSet;
+
+    Aws::Vector<ProjectFileSystemLocation> m_fileSystemLocations;
+    bool m_fileSystemLocationsHasBeenSet;
+
+    ProjectBuildBatchConfig m_buildBatchConfig;
+    bool m_buildBatchConfigHasBeenSet;
+
+    int m_concurrentBuildLimit;
+    bool m_concurrentBuildLimitHasBeenSet;
   };
 
 } // namespace Model
