@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/dynamodb/DynamoDB_EXPORTS.h>
@@ -21,6 +11,7 @@
 #include <aws/dynamodb/model/BillingMode.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/dynamodb/model/ProvisionedThroughput.h>
+#include <aws/dynamodb/model/SSESpecification.h>
 #include <aws/dynamodb/model/GlobalSecondaryIndex.h>
 #include <aws/dynamodb/model/LocalSecondaryIndex.h>
 #include <utility>
@@ -50,6 +41,55 @@ namespace Model
     Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;
 
 
+    /**
+     * <p>The DynamoDB table that will be restored. This value is an Amazon Resource
+     * Name (ARN).</p>
+     */
+    inline const Aws::String& GetSourceTableArn() const{ return m_sourceTableArn; }
+
+    /**
+     * <p>The DynamoDB table that will be restored. This value is an Amazon Resource
+     * Name (ARN).</p>
+     */
+    inline bool SourceTableArnHasBeenSet() const { return m_sourceTableArnHasBeenSet; }
+
+    /**
+     * <p>The DynamoDB table that will be restored. This value is an Amazon Resource
+     * Name (ARN).</p>
+     */
+    inline void SetSourceTableArn(const Aws::String& value) { m_sourceTableArnHasBeenSet = true; m_sourceTableArn = value; }
+
+    /**
+     * <p>The DynamoDB table that will be restored. This value is an Amazon Resource
+     * Name (ARN).</p>
+     */
+    inline void SetSourceTableArn(Aws::String&& value) { m_sourceTableArnHasBeenSet = true; m_sourceTableArn = std::move(value); }
+
+    /**
+     * <p>The DynamoDB table that will be restored. This value is an Amazon Resource
+     * Name (ARN).</p>
+     */
+    inline void SetSourceTableArn(const char* value) { m_sourceTableArnHasBeenSet = true; m_sourceTableArn.assign(value); }
+
+    /**
+     * <p>The DynamoDB table that will be restored. This value is an Amazon Resource
+     * Name (ARN).</p>
+     */
+    inline RestoreTableToPointInTimeRequest& WithSourceTableArn(const Aws::String& value) { SetSourceTableArn(value); return *this;}
+
+    /**
+     * <p>The DynamoDB table that will be restored. This value is an Amazon Resource
+     * Name (ARN).</p>
+     */
+    inline RestoreTableToPointInTimeRequest& WithSourceTableArn(Aws::String&& value) { SetSourceTableArn(std::move(value)); return *this;}
+
+    /**
+     * <p>The DynamoDB table that will be restored. This value is an Amazon Resource
+     * Name (ARN).</p>
+     */
+    inline RestoreTableToPointInTimeRequest& WithSourceTableArn(const char* value) { SetSourceTableArn(value); return *this;}
+
+
     /**
      * <p>Name of the source table that is being restored.</p>
      */
@@ -367,8 +407,42 @@ namespace Model
      */
     inline RestoreTableToPointInTimeRequest& WithProvisionedThroughputOverride(ProvisionedThroughput&& value) { SetProvisionedThroughputOverride(std::move(value)); return *this;}
 
+
+    /**
+     * <p>The new server-side encryption settings for the restored table.</p>
+     */
+    inline const SSESpecification& GetSSESpecificationOverride() const{ return m_sSESpecificationOverride; }
+
+    /**
+     * <p>The new server-side encryption settings for the restored table.</p>
+     */
+    inline bool SSESpecificationOverrideHasBeenSet() const { return m_sSESpecificationOverrideHasBeenSet; }
+
+    /**
+     * <p>The new server-side encryption settings for the restored table.</p>
+     */
+    inline void SetSSESpecificationOverride(const SSESpecification& value) { m_sSESpecificationOverrideHasBeenSet = true; m_sSESpecificationOverride = value; }
+
+    /**
+     * <p>The new server-side encryption settings for the restored table.</p>
+     */
+    inline void SetSSESpecificationOverride(SSESpecification&& value) { m_sSESpecificationOverrideHasBeenSet = true; m_sSESpecificationOverride = std::move(value); }
+
+    /**
+     * <p>The new server-side encryption settings for the restored table.</p>
+     */
+    inline RestoreTableToPointInTimeRequest& WithSSESpecificationOverride(const SSESpecification& value) { SetSSESpecificationOverride(value); return *this;}
+
+    /**
+     * <p>The new server-side encryption settings for the restored table.</p>
+     */
+    inline RestoreTableToPointInTimeRequest& WithSSESpecificationOverride(SSESpecification&& value) { SetSSESpecificationOverride(std::move(value)); return *this;}
+
   private:
 
+    Aws::String m_sourceTableArn;
+    bool m_sourceTableArnHasBeenSet;
+
     Aws::String m_sourceTableName;
     bool m_sourceTableNameHasBeenSet;
 
@@ -392,6 +466,9 @@ namespace Model
 
     ProvisionedThroughput m_provisionedThroughputOverride;
     bool m_provisionedThroughputOverrideHasBeenSet;
+
+    SSESpecification m_sSESpecificationOverride;
+    bool m_sSESpecificationOverrideHasBeenSet;
   };
 
 } // namespace Model
