@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/elasticache/ElastiCache_EXPORTS.h>
@@ -42,7 +32,14 @@ namespace Model
    * ElastiCache. Generally speaking, the current generation types provide more
    * memory and computational power at lower cost when compared to their equivalent
    * previous generation counterparts.</p> <ul> <li> <p>General purpose:</p> <ul>
-   * <li> <p>Current generation: </p> <p> <b>M5 node types:</b>
+   * <li> <p>Current generation: </p> <p> <b>M6g node types</b> (available only for
+   * Redis engine version 5.0.6 onward and for Memcached engine version 1.5.16
+   * onward).</p> <p> <code>cache.m6g.large</code>, <code>cache.m6g.xlarge</code>,
+   * <code>cache.m6g.2xlarge</code>, <code>cache.m6g.4xlarge</code>,
+   * <code>cache.m6g.8xlarge</code>, <code>cache.m6g.12xlarge</code>,
+   * <code>cache.m6g.16xlarge</code> </p>  <p>For region availability, see <a
+   * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/CacheNodes.SupportedTypes.html#CacheNodes.SupportedTypesByRegion">Supported
+   * Node Types</a> </p>  <p> <b>M5 node types:</b>
    * <code>cache.m5.large</code>, <code>cache.m5.xlarge</code>,
    * <code>cache.m5.2xlarge</code>, <code>cache.m5.4xlarge</code>,
    * <code>cache.m5.12xlarge</code>, <code>cache.m5.24xlarge</code> </p> <p> <b>M4
@@ -61,11 +58,18 @@ namespace Model
    * </li> <li> <p>Compute optimized:</p> <ul> <li> <p>Previous generation: (not
    * recommended)</p> <p> <b>C1 node types:</b> <code>cache.c1.xlarge</code> </p>
    * </li> </ul> </li> <li> <p>Memory optimized:</p> <ul> <li> <p>Current generation:
-   * </p> <p> <b>R5 node types:</b> <code>cache.r5.large</code>,
-   * <code>cache.r5.xlarge</code>, <code>cache.r5.2xlarge</code>,
-   * <code>cache.r5.4xlarge</code>, <code>cache.r5.12xlarge</code>,
-   * <code>cache.r5.24xlarge</code> </p> <p> <b>R4 node types:</b>
-   * <code>cache.r4.large</code>, <code>cache.r4.xlarge</code>,
+   * </p> <p> <b>R6g node types</b> (available only for Redis engine version 5.0.6
+   * onward and for Memcached engine version 1.5.16 onward).</p> <p>
+   * <code>cache.r6g.large</code>, <code>cache.r6g.xlarge</code>,
+   * <code>cache.r6g.2xlarge</code>, <code>cache.r6g.4xlarge</code>,
+   * <code>cache.r6g.8xlarge</code>, <code>cache.r6g.12xlarge</code>,
+   * <code>cache.r6g.16xlarge</code> </p>  <p>For region availability, see <a
+   * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/CacheNodes.SupportedTypes.html#CacheNodes.SupportedTypesByRegion">Supported
+   * Node Types</a> </p>  <p> <b>R5 node types:</b>
+   * <code>cache.r5.large</code>, <code>cache.r5.xlarge</code>,
+   * <code>cache.r5.2xlarge</code>, <code>cache.r5.4xlarge</code>,
+   * <code>cache.r5.12xlarge</code>, <code>cache.r5.24xlarge</code> </p> <p> <b>R4
+   * node types:</b> <code>cache.r4.large</code>, <code>cache.r4.xlarge</code>,
    * <code>cache.r4.2xlarge</code>, <code>cache.r4.4xlarge</code>,
    * <code>cache.r4.8xlarge</code>, <code>cache.r4.16xlarge</code> </p> </li> <li>
    * <p>Previous generation: (not recommended)</p> <p> <b>M2 node types:</b>
@@ -401,6 +405,47 @@ namespace Model
      */
     inline CacheNode& WithCustomerAvailabilityZone(const char* value) { SetCustomerAvailabilityZone(value); return *this;}
 
+
+    /**
+     * <p>The customer outpost ARN of the cache node.</p>
+     */
+    inline const Aws::String& GetCustomerOutpostArn() const{ return m_customerOutpostArn; }
+
+    /**
+     * <p>The customer outpost ARN of the cache node.</p>
+     */
+    inline bool CustomerOutpostArnHasBeenSet() const { return m_customerOutpostArnHasBeenSet; }
+
+    /**
+     * <p>The customer outpost ARN of the cache node.</p>
+     */
+    inline void SetCustomerOutpostArn(const Aws::String& value) { m_customerOutpostArnHasBeenSet = true; m_customerOutpostArn = value; }
+
+    /**
+     * <p>The customer outpost ARN of the cache node.</p>
+     */
+    inline void SetCustomerOutpostArn(Aws::String&& value) { m_customerOutpostArnHasBeenSet = true; m_customerOutpostArn = std::move(value); }
+
+    /**
+     * <p>The customer outpost ARN of the cache node.</p>
+     */
+    inline void SetCustomerOutpostArn(const char* value) { m_customerOutpostArnHasBeenSet = true; m_customerOutpostArn.assign(value); }
+
+    /**
+     * <p>The customer outpost ARN of the cache node.</p>
+     */
+    inline CacheNode& WithCustomerOutpostArn(const Aws::String& value) { SetCustomerOutpostArn(value); return *this;}
+
+    /**
+     * <p>The customer outpost ARN of the cache node.</p>
+     */
+    inline CacheNode& WithCustomerOutpostArn(Aws::String&& value) { SetCustomerOutpostArn(std::move(value)); return *this;}
+
+    /**
+     * <p>The customer outpost ARN of the cache node.</p>
+     */
+    inline CacheNode& WithCustomerOutpostArn(const char* value) { SetCustomerOutpostArn(value); return *this;}
+
   private:
 
     Aws::String m_cacheNodeId;
@@ -423,6 +468,9 @@ namespace Model
 
     Aws::String m_customerAvailabilityZone;
     bool m_customerAvailabilityZoneHasBeenSet;
+
+    Aws::String m_customerOutpostArn;
+    bool m_customerOutpostArnHasBeenSet;
   };
 
 } // namespace Model
