@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/elasticbeanstalk/ElasticBeanstalk_EXPORTS.h>
@@ -244,37 +234,37 @@ namespace Model
 
 
     /**
-     * <p>The ARN of the platform.</p>
+     * <p>The ARN of the platform version.</p>
      */
     inline const Aws::String& GetPlatformArn() const{ return m_platformArn; }
 
     /**
-     * <p>The ARN of the platform.</p>
+     * <p>The ARN of the platform version.</p>
      */
     inline void SetPlatformArn(const Aws::String& value) { m_platformArn = value; }
 
     /**
-     * <p>The ARN of the platform.</p>
+     * <p>The ARN of the platform version.</p>
      */
     inline void SetPlatformArn(Aws::String&& value) { m_platformArn = std::move(value); }
 
     /**
-     * <p>The ARN of the platform.</p>
+     * <p>The ARN of the platform version.</p>
      */
     inline void SetPlatformArn(const char* value) { m_platformArn.assign(value); }
 
     /**
-     * <p>The ARN of the platform.</p>
+     * <p>The ARN of the platform version.</p>
      */
     inline UpdateEnvironmentResult& WithPlatformArn(const Aws::String& value) { SetPlatformArn(value); return *this;}
 
     /**
-     * <p>The ARN of the platform.</p>
+     * <p>The ARN of the platform version.</p>
      */
     inline UpdateEnvironmentResult& WithPlatformArn(Aws::String&& value) { SetPlatformArn(std::move(value)); return *this;}
 
     /**
-     * <p>The ARN of the platform.</p>
+     * <p>The ARN of the platform version.</p>
      */
     inline UpdateEnvironmentResult& WithPlatformArn(const char* value) { SetPlatformArn(value); return *this;}
 
@@ -828,6 +818,63 @@ namespace Model
     inline UpdateEnvironmentResult& WithEnvironmentArn(const char* value) { SetEnvironmentArn(value); return *this;}
 
 
+    /**
+     * <p>The Amazon Resource Name (ARN) of the environment's operations role. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/iam-operationsrole.html">Operations
+     * roles</a> in the <i>AWS Elastic Beanstalk Developer Guide</i>.</p>
+     */
+    inline const Aws::String& GetOperationsRole() const{ return m_operationsRole; }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the environment's operations role. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/iam-operationsrole.html">Operations
+     * roles</a> in the <i>AWS Elastic Beanstalk Developer Guide</i>.</p>
+     */
+    inline void SetOperationsRole(const Aws::String& value) { m_operationsRole = value; }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the environment's operations role. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/iam-operationsrole.html">Operations
+     * roles</a> in the <i>AWS Elastic Beanstalk Developer Guide</i>.</p>
+     */
+    inline void SetOperationsRole(Aws::String&& value) { m_operationsRole = std::move(value); }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the environment's operations role. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/iam-operationsrole.html">Operations
+     * roles</a> in the <i>AWS Elastic Beanstalk Developer Guide</i>.</p>
+     */
+    inline void SetOperationsRole(const char* value) { m_operationsRole.assign(value); }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the environment's operations role. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/iam-operationsrole.html">Operations
+     * roles</a> in the <i>AWS Elastic Beanstalk Developer Guide</i>.</p>
+     */
+    inline UpdateEnvironmentResult& WithOperationsRole(const Aws::String& value) { SetOperationsRole(value); return *this;}
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the environment's operations role. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/iam-operationsrole.html">Operations
+     * roles</a> in the <i>AWS Elastic Beanstalk Developer Guide</i>.</p>
+     */
+    inline UpdateEnvironmentResult& WithOperationsRole(Aws::String&& value) { SetOperationsRole(std::move(value)); return *this;}
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the environment's operations role. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/iam-operationsrole.html">Operations
+     * roles</a> in the <i>AWS Elastic Beanstalk Developer Guide</i>.</p>
+     */
+    inline UpdateEnvironmentResult& WithOperationsRole(const char* value) { SetOperationsRole(value); return *this;}
+
+
     
     inline const ResponseMetadata& GetResponseMetadata() const{ return m_responseMetadata; }
 
@@ -885,6 +932,8 @@ namespace Model
 
     Aws::String m_environmentArn;
 
+    Aws::String m_operationsRole;
+
     ResponseMetadata m_responseMetadata;
   };
 
