@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/elasticfilesystem/EFS_EXPORTS.h>
@@ -305,111 +295,161 @@ namespace Model
 
 
     /**
-     * <p>The unique and consistent identifier of the Availability Zone (AZ) that the
-     * mount target resides in. For example, <code>use1-az1</code> is an AZ ID for the
+     * <p>The unique and consistent identifier of the Availability Zone that the mount
+     * target resides in. For example, <code>use1-az1</code> is an AZ ID for the
      * us-east-1 Region and it has the same location in every AWS account.</p>
      */
     inline const Aws::String& GetAvailabilityZoneId() const{ return m_availabilityZoneId; }
 
     /**
-     * <p>The unique and consistent identifier of the Availability Zone (AZ) that the
-     * mount target resides in. For example, <code>use1-az1</code> is an AZ ID for the
+     * <p>The unique and consistent identifier of the Availability Zone that the mount
+     * target resides in. For example, <code>use1-az1</code> is an AZ ID for the
      * us-east-1 Region and it has the same location in every AWS account.</p>
      */
     inline void SetAvailabilityZoneId(const Aws::String& value) { m_availabilityZoneId = value; }
 
     /**
-     * <p>The unique and consistent identifier of the Availability Zone (AZ) that the
-     * mount target resides in. For example, <code>use1-az1</code> is an AZ ID for the
+     * <p>The unique and consistent identifier of the Availability Zone that the mount
+     * target resides in. For example, <code>use1-az1</code> is an AZ ID for the
      * us-east-1 Region and it has the same location in every AWS account.</p>
      */
     inline void SetAvailabilityZoneId(Aws::String&& value) { m_availabilityZoneId = std::move(value); }
 
     /**
-     * <p>The unique and consistent identifier of the Availability Zone (AZ) that the
-     * mount target resides in. For example, <code>use1-az1</code> is an AZ ID for the
+     * <p>The unique and consistent identifier of the Availability Zone that the mount
+     * target resides in. For example, <code>use1-az1</code> is an AZ ID for the
      * us-east-1 Region and it has the same location in every AWS account.</p>
      */
     inline void SetAvailabilityZoneId(const char* value) { m_availabilityZoneId.assign(value); }
 
     /**
-     * <p>The unique and consistent identifier of the Availability Zone (AZ) that the
-     * mount target resides in. For example, <code>use1-az1</code> is an AZ ID for the
+     * <p>The unique and consistent identifier of the Availability Zone that the mount
+     * target resides in. For example, <code>use1-az1</code> is an AZ ID for the
      * us-east-1 Region and it has the same location in every AWS account.</p>
      */
     inline CreateMountTargetResult& WithAvailabilityZoneId(const Aws::String& value) { SetAvailabilityZoneId(value); return *this;}
 
     /**
-     * <p>The unique and consistent identifier of the Availability Zone (AZ) that the
-     * mount target resides in. For example, <code>use1-az1</code> is an AZ ID for the
+     * <p>The unique and consistent identifier of the Availability Zone that the mount
+     * target resides in. For example, <code>use1-az1</code> is an AZ ID for the
      * us-east-1 Region and it has the same location in every AWS account.</p>
      */
     inline CreateMountTargetResult& WithAvailabilityZoneId(Aws::String&& value) { SetAvailabilityZoneId(std::move(value)); return *this;}
 
     /**
-     * <p>The unique and consistent identifier of the Availability Zone (AZ) that the
-     * mount target resides in. For example, <code>use1-az1</code> is an AZ ID for the
+     * <p>The unique and consistent identifier of the Availability Zone that the mount
+     * target resides in. For example, <code>use1-az1</code> is an AZ ID for the
      * us-east-1 Region and it has the same location in every AWS account.</p>
      */
     inline CreateMountTargetResult& WithAvailabilityZoneId(const char* value) { SetAvailabilityZoneId(value); return *this;}
 
 
     /**
-     * <p>The name of the Availability Zone (AZ) that the mount target resides in. AZs
-     * are independently mapped to names for each AWS account. For example, the
-     * Availability Zone <code>us-east-1a</code> for your AWS account might not be the
-     * same location as <code>us-east-1a</code> for another AWS account.</p>
+     * <p>The name of the Availability Zone in which the mount target is located.
+     * Availability Zones are independently mapped to names for each AWS account. For
+     * example, the Availability Zone <code>us-east-1a</code> for your AWS account
+     * might not be the same location as <code>us-east-1a</code> for another AWS
+     * account.</p>
      */
     inline const Aws::String& GetAvailabilityZoneName() const{ return m_availabilityZoneName; }
 
     /**
-     * <p>The name of the Availability Zone (AZ) that the mount target resides in. AZs
-     * are independently mapped to names for each AWS account. For example, the
-     * Availability Zone <code>us-east-1a</code> for your AWS account might not be the
-     * same location as <code>us-east-1a</code> for another AWS account.</p>
+     * <p>The name of the Availability Zone in which the mount target is located.
+     * Availability Zones are independently mapped to names for each AWS account. For
+     * example, the Availability Zone <code>us-east-1a</code> for your AWS account
+     * might not be the same location as <code>us-east-1a</code> for another AWS
+     * account.</p>
      */
     inline void SetAvailabilityZoneName(const Aws::String& value) { m_availabilityZoneName = value; }
 
     /**
-     * <p>The name of the Availability Zone (AZ) that the mount target resides in. AZs
-     * are independently mapped to names for each AWS account. For example, the
-     * Availability Zone <code>us-east-1a</code> for your AWS account might not be the
-     * same location as <code>us-east-1a</code> for another AWS account.</p>
+     * <p>The name of the Availability Zone in which the mount target is located.
+     * Availability Zones are independently mapped to names for each AWS account. For
+     * example, the Availability Zone <code>us-east-1a</code> for your AWS account
+     * might not be the same location as <code>us-east-1a</code> for another AWS
+     * account.</p>
      */
     inline void SetAvailabilityZoneName(Aws::String&& value) { m_availabilityZoneName = std::move(value); }
 
     /**
-     * <p>The name of the Availability Zone (AZ) that the mount target resides in. AZs
-     * are independently mapped to names for each AWS account. For example, the
-     * Availability Zone <code>us-east-1a</code> for your AWS account might not be the
-     * same location as <code>us-east-1a</code> for another AWS account.</p>
+     * <p>The name of the Availability Zone in which the mount target is located.
+     * Availability Zones are independently mapped to names for each AWS account. For
+     * example, the Availability Zone <code>us-east-1a</code> for your AWS account
+     * might not be the same location as <code>us-east-1a</code> for another AWS
+     * account.</p>
      */
     inline void SetAvailabilityZoneName(const char* value) { m_availabilityZoneName.assign(value); }
 
     /**
-     * <p>The name of the Availability Zone (AZ) that the mount target resides in. AZs
-     * are independently mapped to names for each AWS account. For example, the
-     * Availability Zone <code>us-east-1a</code> for your AWS account might not be the
-     * same location as <code>us-east-1a</code> for another AWS account.</p>
+     * <p>The name of the Availability Zone in which the mount target is located.
+     * Availability Zones are independently mapped to names for each AWS account. For
+     * example, the Availability Zone <code>us-east-1a</code> for your AWS account
+     * might not be the same location as <code>us-east-1a</code> for another AWS
+     * account.</p>
      */
     inline CreateMountTargetResult& WithAvailabilityZoneName(const Aws::String& value) { SetAvailabilityZoneName(value); return *this;}
 
     /**
-     * <p>The name of the Availability Zone (AZ) that the mount target resides in. AZs
-     * are independently mapped to names for each AWS account. For example, the
-     * Availability Zone <code>us-east-1a</code> for your AWS account might not be the
-     * same location as <code>us-east-1a</code> for another AWS account.</p>
+     * <p>The name of the Availability Zone in which the mount target is located.
+     * Availability Zones are independently mapped to names for each AWS account. For
+     * example, the Availability Zone <code>us-east-1a</code> for your AWS account
+     * might not be the same location as <code>us-east-1a</code> for another AWS
+     * account.</p>
      */
     inline CreateMountTargetResult& WithAvailabilityZoneName(Aws::String&& value) { SetAvailabilityZoneName(std::move(value)); return *this;}
 
     /**
-     * <p>The name of the Availability Zone (AZ) that the mount target resides in. AZs
-     * are independently mapped to names for each AWS account. For example, the
-     * Availability Zone <code>us-east-1a</code> for your AWS account might not be the
-     * same location as <code>us-east-1a</code> for another AWS account.</p>
+     * <p>The name of the Availability Zone in which the mount target is located.
+     * Availability Zones are independently mapped to names for each AWS account. For
+     * example, the Availability Zone <code>us-east-1a</code> for your AWS account
+     * might not be the same location as <code>us-east-1a</code> for another AWS
+     * account.</p>
      */
     inline CreateMountTargetResult& WithAvailabilityZoneName(const char* value) { SetAvailabilityZoneName(value); return *this;}
 
+
+    /**
+     * <p>The virtual private cloud (VPC) ID that the mount target is configured
+     * in.</p>
+     */
+    inline const Aws::String& GetVpcId() const{ return m_vpcId; }
+
+    /**
+     * <p>The virtual private cloud (VPC) ID that the mount target is configured
+     * in.</p>
+     */
+    inline void SetVpcId(const Aws::String& value) { m_vpcId = value; }
+
+    /**
+     * <p>The virtual private cloud (VPC) ID that the mount target is configured
+     * in.</p>
+     */
+    inline void SetVpcId(Aws::String&& value) { m_vpcId = std::move(value); }
+
+    /**
+     * <p>The virtual private cloud (VPC) ID that the mount target is configured
+     * in.</p>
+     */
+    inline void SetVpcId(const char* value) { m_vpcId.assign(value); }
+
+    /**
+     * <p>The virtual private cloud (VPC) ID that the mount target is configured
+     * in.</p>
+     */
+    inline CreateMountTargetResult& WithVpcId(const Aws::String& value) { SetVpcId(value); return *this;}
+
+    /**
+     * <p>The virtual private cloud (VPC) ID that the mount target is configured
+     * in.</p>
+     */
+    inline CreateMountTargetResult& WithVpcId(Aws::String&& value) { SetVpcId(std::move(value)); return *this;}
+
+    /**
+     * <p>The virtual private cloud (VPC) ID that the mount target is configured
+     * in.</p>
+     */
+    inline CreateMountTargetResult& WithVpcId(const char* value) { SetVpcId(value); return *this;}
+
   private:
 
     Aws::String m_ownerId;
@@ -429,6 +469,8 @@ namespace Model
     Aws::String m_availabilityZoneId;
 
     Aws::String m_availabilityZoneName;
+
+    Aws::String m_vpcId;
   };
 
 } // namespace Model
