@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/es/ElasticsearchService_EXPORTS.h>
@@ -27,6 +17,8 @@
 #include <aws/es/model/AdvancedOptionsStatus.h>
 #include <aws/es/model/LogPublishingOptionsStatus.h>
 #include <aws/es/model/DomainEndpointOptionsStatus.h>
+#include <aws/es/model/AdvancedSecurityOptionsStatus.h>
+#include <aws/es/model/AutoTuneOptionsStatus.h>
 #include <utility>
 
 namespace Aws
@@ -501,6 +493,68 @@ namespace Model
      */
     inline ElasticsearchDomainConfig& WithDomainEndpointOptions(DomainEndpointOptionsStatus&& value) { SetDomainEndpointOptions(std::move(value)); return *this;}
 
+
+    /**
+     * <p>Specifies <code>AdvancedSecurityOptions</code> for the domain. </p>
+     */
+    inline const AdvancedSecurityOptionsStatus& GetAdvancedSecurityOptions() const{ return m_advancedSecurityOptions; }
+
+    /**
+     * <p>Specifies <code>AdvancedSecurityOptions</code> for the domain. </p>
+     */
+    inline bool AdvancedSecurityOptionsHasBeenSet() const { return m_advancedSecurityOptionsHasBeenSet; }
+
+    /**
+     * <p>Specifies <code>AdvancedSecurityOptions</code> for the domain. </p>
+     */
+    inline void SetAdvancedSecurityOptions(const AdvancedSecurityOptionsStatus& value) { m_advancedSecurityOptionsHasBeenSet = true; m_advancedSecurityOptions = value; }
+
+    /**
+     * <p>Specifies <code>AdvancedSecurityOptions</code> for the domain. </p>
+     */
+    inline void SetAdvancedSecurityOptions(AdvancedSecurityOptionsStatus&& value) { m_advancedSecurityOptionsHasBeenSet = true; m_advancedSecurityOptions = std::move(value); }
+
+    /**
+     * <p>Specifies <code>AdvancedSecurityOptions</code> for the domain. </p>
+     */
+    inline ElasticsearchDomainConfig& WithAdvancedSecurityOptions(const AdvancedSecurityOptionsStatus& value) { SetAdvancedSecurityOptions(value); return *this;}
+
+    /**
+     * <p>Specifies <code>AdvancedSecurityOptions</code> for the domain. </p>
+     */
+    inline ElasticsearchDomainConfig& WithAdvancedSecurityOptions(AdvancedSecurityOptionsStatus&& value) { SetAdvancedSecurityOptions(std::move(value)); return *this;}
+
+
+    /**
+     * <p>Specifies <code>AutoTuneOptions</code> for the domain. </p>
+     */
+    inline const AutoTuneOptionsStatus& GetAutoTuneOptions() const{ return m_autoTuneOptions; }
+
+    /**
+     * <p>Specifies <code>AutoTuneOptions</code> for the domain. </p>
+     */
+    inline bool AutoTuneOptionsHasBeenSet() const { return m_autoTuneOptionsHasBeenSet; }
+
+    /**
+     * <p>Specifies <code>AutoTuneOptions</code> for the domain. </p>
+     */
+    inline void SetAutoTuneOptions(const AutoTuneOptionsStatus& value) { m_autoTuneOptionsHasBeenSet = true; m_autoTuneOptions = value; }
+
+    /**
+     * <p>Specifies <code>AutoTuneOptions</code> for the domain. </p>
+     */
+    inline void SetAutoTuneOptions(AutoTuneOptionsStatus&& value) { m_autoTuneOptionsHasBeenSet = true; m_autoTuneOptions = std::move(value); }
+
+    /**
+     * <p>Specifies <code>AutoTuneOptions</code> for the domain. </p>
+     */
+    inline ElasticsearchDomainConfig& WithAutoTuneOptions(const AutoTuneOptionsStatus& value) { SetAutoTuneOptions(value); return *this;}
+
+    /**
+     * <p>Specifies <code>AutoTuneOptions</code> for the domain. </p>
+     */
+    inline ElasticsearchDomainConfig& WithAutoTuneOptions(AutoTuneOptionsStatus&& value) { SetAutoTuneOptions(std::move(value)); return *this;}
+
   private:
 
     ElasticsearchVersionStatus m_elasticsearchVersion;
@@ -538,6 +592,12 @@ namespace Model
 
     DomainEndpointOptionsStatus m_domainEndpointOptions;
     bool m_domainEndpointOptionsHasBeenSet;
+
+    AdvancedSecurityOptionsStatus m_advancedSecurityOptions;
+    bool m_advancedSecurityOptionsHasBeenSet;
+
+    AutoTuneOptionsStatus m_autoTuneOptions;
+    bool m_autoTuneOptionsHasBeenSet;
   };
 
 } // namespace Model
