@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/events/CloudWatchEvents_EXPORTS.h>
@@ -287,53 +277,134 @@ namespace Model
 
 
     /**
-     * <p>The event bus that will receive the event. Only the rules that are associated
-     * with this event bus will be able to match the event.</p>
+     * <p>The name or ARN of the event bus to receive the event. Only the rules that
+     * are associated with this event bus are used to match the event. If you omit
+     * this, the default event bus is used.</p>
      */
     inline const Aws::String& GetEventBusName() const{ return m_eventBusName; }
 
     /**
-     * <p>The event bus that will receive the event. Only the rules that are associated
-     * with this event bus will be able to match the event.</p>
+     * <p>The name or ARN of the event bus to receive the event. Only the rules that
+     * are associated with this event bus are used to match the event. If you omit
+     * this, the default event bus is used.</p>
      */
     inline bool EventBusNameHasBeenSet() const { return m_eventBusNameHasBeenSet; }
 
     /**
-     * <p>The event bus that will receive the event. Only the rules that are associated
-     * with this event bus will be able to match the event.</p>
+     * <p>The name or ARN of the event bus to receive the event. Only the rules that
+     * are associated with this event bus are used to match the event. If you omit
+     * this, the default event bus is used.</p>
      */
     inline void SetEventBusName(const Aws::String& value) { m_eventBusNameHasBeenSet = true; m_eventBusName = value; }
 
     /**
-     * <p>The event bus that will receive the event. Only the rules that are associated
-     * with this event bus will be able to match the event.</p>
+     * <p>The name or ARN of the event bus to receive the event. Only the rules that
+     * are associated with this event bus are used to match the event. If you omit
+     * this, the default event bus is used.</p>
      */
     inline void SetEventBusName(Aws::String&& value) { m_eventBusNameHasBeenSet = true; m_eventBusName = std::move(value); }
 
     /**
-     * <p>The event bus that will receive the event. Only the rules that are associated
-     * with this event bus will be able to match the event.</p>
+     * <p>The name or ARN of the event bus to receive the event. Only the rules that
+     * are associated with this event bus are used to match the event. If you omit
+     * this, the default event bus is used.</p>
      */
     inline void SetEventBusName(const char* value) { m_eventBusNameHasBeenSet = true; m_eventBusName.assign(value); }
 
     /**
-     * <p>The event bus that will receive the event. Only the rules that are associated
-     * with this event bus will be able to match the event.</p>
+     * <p>The name or ARN of the event bus to receive the event. Only the rules that
+     * are associated with this event bus are used to match the event. If you omit
+     * this, the default event bus is used.</p>
      */
     inline PutEventsRequestEntry& WithEventBusName(const Aws::String& value) { SetEventBusName(value); return *this;}
 
     /**
-     * <p>The event bus that will receive the event. Only the rules that are associated
-     * with this event bus will be able to match the event.</p>
+     * <p>The name or ARN of the event bus to receive the event. Only the rules that
+     * are associated with this event bus are used to match the event. If you omit
+     * this, the default event bus is used.</p>
      */
     inline PutEventsRequestEntry& WithEventBusName(Aws::String&& value) { SetEventBusName(std::move(value)); return *this;}
 
     /**
-     * <p>The event bus that will receive the event. Only the rules that are associated
-     * with this event bus will be able to match the event.</p>
+     * <p>The name or ARN of the event bus to receive the event. Only the rules that
+     * are associated with this event bus are used to match the event. If you omit
+     * this, the default event bus is used.</p>
      */
     inline PutEventsRequestEntry& WithEventBusName(const char* value) { SetEventBusName(value); return *this;}
 
+
+    /**
+     * <p>An AWS X-Ray trade header, which is an http header (X-Amzn-Trace-Id) that
+     * contains the trace-id associated with the event.</p> <p>To learn more about
+     * X-Ray trace headers, see <a
+     * href="https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader">Tracing
+     * header</a> in the AWS X-Ray Developer Guide.</p>
+     */
+    inline const Aws::String& GetTraceHeader() const{ return m_traceHeader; }
+
+    /**
+     * <p>An AWS X-Ray trade header, which is an http header (X-Amzn-Trace-Id) that
+     * contains the trace-id associated with the event.</p> <p>To learn more about
+     * X-Ray trace headers, see <a
+     * href="https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader">Tracing
+     * header</a> in the AWS X-Ray Developer Guide.</p>
+     */
+    inline bool TraceHeaderHasBeenSet() const { return m_traceHeaderHasBeenSet; }
+
+    /**
+     * <p>An AWS X-Ray trade header, which is an http header (X-Amzn-Trace-Id) that
+     * contains the trace-id associated with the event.</p> <p>To learn more about
+     * X-Ray trace headers, see <a
+     * href="https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader">Tracing
+     * header</a> in the AWS X-Ray Developer Guide.</p>
+     */
+    inline void SetTraceHeader(const Aws::String& value) { m_traceHeaderHasBeenSet = true; m_traceHeader = value; }
+
+    /**
+     * <p>An AWS X-Ray trade header, which is an http header (X-Amzn-Trace-Id) that
+     * contains the trace-id associated with the event.</p> <p>To learn more about
+     * X-Ray trace headers, see <a
+     * href="https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader">Tracing
+     * header</a> in the AWS X-Ray Developer Guide.</p>
+     */
+    inline void SetTraceHeader(Aws::String&& value) { m_traceHeaderHasBeenSet = true; m_traceHeader = std::move(value); }
+
+    /**
+     * <p>An AWS X-Ray trade header, which is an http header (X-Amzn-Trace-Id) that
+     * contains the trace-id associated with the event.</p> <p>To learn more about
+     * X-Ray trace headers, see <a
+     * href="https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader">Tracing
+     * header</a> in the AWS X-Ray Developer Guide.</p>
+     */
+    inline void SetTraceHeader(const char* value) { m_traceHeaderHasBeenSet = true; m_traceHeader.assign(value); }
+
+    /**
+     * <p>An AWS X-Ray trade header, which is an http header (X-Amzn-Trace-Id) that
+     * contains the trace-id associated with the event.</p> <p>To learn more about
+     * X-Ray trace headers, see <a
+     * href="https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader">Tracing
+     * header</a> in the AWS X-Ray Developer Guide.</p>
+     */
+    inline PutEventsRequestEntry& WithTraceHeader(const Aws::String& value) { SetTraceHeader(value); return *this;}
+
+    /**
+     * <p>An AWS X-Ray trade header, which is an http header (X-Amzn-Trace-Id) that
+     * contains the trace-id associated with the event.</p> <p>To learn more about
+     * X-Ray trace headers, see <a
+     * href="https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader">Tracing
+     * header</a> in the AWS X-Ray Developer Guide.</p>
+     */
+    inline PutEventsRequestEntry& WithTraceHeader(Aws::String&& value) { SetTraceHeader(std::move(value)); return *this;}
+
+    /**
+     * <p>An AWS X-Ray trade header, which is an http header (X-Amzn-Trace-Id) that
+     * contains the trace-id associated with the event.</p> <p>To learn more about
+     * X-Ray trace headers, see <a
+     * href="https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-tracingheader">Tracing
+     * header</a> in the AWS X-Ray Developer Guide.</p>
+     */
+    inline PutEventsRequestEntry& WithTraceHeader(const char* value) { SetTraceHeader(value); return *this;}
+
   private:
 
     Aws::Utils::DateTime m_time;
@@ -353,6 +424,9 @@ namespace Model
 
     Aws::String m_eventBusName;
     bool m_eventBusNameHasBeenSet;
+
+    Aws::String m_traceHeader;
+    bool m_traceHeaderHasBeenSet;
   };
 
 } // namespace Model
