@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/glue/Glue_EXPORTS.h>
@@ -20,6 +10,8 @@
 #include <aws/glue/model/CrawlerTargets.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/glue/model/SchemaChangePolicy.h>
+#include <aws/glue/model/RecrawlPolicy.h>
+#include <aws/glue/model/LineageConfiguration.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <utility>
 
@@ -260,74 +252,66 @@ namespace Model
 
 
     /**
-     * <p>A <code>cron</code> expression used to specify the schedule. For more
-     * information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
+     * <p>A <code>cron</code> expression used to specify the schedule (see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
      * Schedules for Jobs and Crawlers</a>. For example, to run something every day at
-     * 12:15 UTC, specify <code>cron(15 12 * * ? *)</code>.</p>
+     * 12:15 UTC, you would specify: <code>cron(15 12 * * ? *)</code>.</p>
      */
     inline const Aws::String& GetSchedule() const{ return m_schedule; }
 
     /**
-     * <p>A <code>cron</code> expression used to specify the schedule. For more
-     * information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
+     * <p>A <code>cron</code> expression used to specify the schedule (see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
      * Schedules for Jobs and Crawlers</a>. For example, to run something every day at
-     * 12:15 UTC, specify <code>cron(15 12 * * ? *)</code>.</p>
+     * 12:15 UTC, you would specify: <code>cron(15 12 * * ? *)</code>.</p>
      */
     inline bool ScheduleHasBeenSet() const { return m_scheduleHasBeenSet; }
 
     /**
-     * <p>A <code>cron</code> expression used to specify the schedule. For more
-     * information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
+     * <p>A <code>cron</code> expression used to specify the schedule (see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
      * Schedules for Jobs and Crawlers</a>. For example, to run something every day at
-     * 12:15 UTC, specify <code>cron(15 12 * * ? *)</code>.</p>
+     * 12:15 UTC, you would specify: <code>cron(15 12 * * ? *)</code>.</p>
      */
     inline void SetSchedule(const Aws::String& value) { m_scheduleHasBeenSet = true; m_schedule = value; }
 
     /**
-     * <p>A <code>cron</code> expression used to specify the schedule. For more
-     * information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
+     * <p>A <code>cron</code> expression used to specify the schedule (see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
      * Schedules for Jobs and Crawlers</a>. For example, to run something every day at
-     * 12:15 UTC, specify <code>cron(15 12 * * ? *)</code>.</p>
+     * 12:15 UTC, you would specify: <code>cron(15 12 * * ? *)</code>.</p>
      */
     inline void SetSchedule(Aws::String&& value) { m_scheduleHasBeenSet = true; m_schedule = std::move(value); }
 
     /**
-     * <p>A <code>cron</code> expression used to specify the schedule. For more
-     * information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
+     * <p>A <code>cron</code> expression used to specify the schedule (see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
      * Schedules for Jobs and Crawlers</a>. For example, to run something every day at
-     * 12:15 UTC, specify <code>cron(15 12 * * ? *)</code>.</p>
+     * 12:15 UTC, you would specify: <code>cron(15 12 * * ? *)</code>.</p>
      */
     inline void SetSchedule(const char* value) { m_scheduleHasBeenSet = true; m_schedule.assign(value); }
 
     /**
-     * <p>A <code>cron</code> expression used to specify the schedule. For more
-     * information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
+     * <p>A <code>cron</code> expression used to specify the schedule (see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
      * Schedules for Jobs and Crawlers</a>. For example, to run something every day at
-     * 12:15 UTC, specify <code>cron(15 12 * * ? *)</code>.</p>
+     * 12:15 UTC, you would specify: <code>cron(15 12 * * ? *)</code>.</p>
      */
     inline CreateCrawlerRequest& WithSchedule(const Aws::String& value) { SetSchedule(value); return *this;}
 
     /**
-     * <p>A <code>cron</code> expression used to specify the schedule. For more
-     * information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
+     * <p>A <code>cron</code> expression used to specify the schedule (see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
      * Schedules for Jobs and Crawlers</a>. For example, to run something every day at
-     * 12:15 UTC, specify <code>cron(15 12 * * ? *)</code>.</p>
+     * 12:15 UTC, you would specify: <code>cron(15 12 * * ? *)</code>.</p>
      */
     inline CreateCrawlerRequest& WithSchedule(Aws::String&& value) { SetSchedule(std::move(value)); return *this;}
 
     /**
-     * <p>A <code>cron</code> expression used to specify the schedule. For more
-     * information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
+     * <p>A <code>cron</code> expression used to specify the schedule (see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html">Time-Based
      * Schedules for Jobs and Crawlers</a>. For example, to run something every day at
-     * 12:15 UTC, specify <code>cron(15 12 * * ? *)</code>.</p>
+     * 12:15 UTC, you would specify: <code>cron(15 12 * * ? *)</code>.</p>
      */
     inline CreateCrawlerRequest& WithSchedule(const char* value) { SetSchedule(value); return *this;}
 
@@ -469,65 +453,133 @@ namespace Model
 
 
     /**
-     * <p>The crawler configuration information. This versioned JSON string allows
-     * users to specify aspects of a crawler's behavior. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
+     * <p>A policy that specifies whether to crawl the entire dataset again, or to
+     * crawl only folders that were added since the last crawler run.</p>
+     */
+    inline const RecrawlPolicy& GetRecrawlPolicy() const{ return m_recrawlPolicy; }
+
+    /**
+     * <p>A policy that specifies whether to crawl the entire dataset again, or to
+     * crawl only folders that were added since the last crawler run.</p>
+     */
+    inline bool RecrawlPolicyHasBeenSet() const { return m_recrawlPolicyHasBeenSet; }
+
+    /**
+     * <p>A policy that specifies whether to crawl the entire dataset again, or to
+     * crawl only folders that were added since the last crawler run.</p>
+     */
+    inline void SetRecrawlPolicy(const RecrawlPolicy& value) { m_recrawlPolicyHasBeenSet = true; m_recrawlPolicy = value; }
+
+    /**
+     * <p>A policy that specifies whether to crawl the entire dataset again, or to
+     * crawl only folders that were added since the last crawler run.</p>
+     */
+    inline void SetRecrawlPolicy(RecrawlPolicy&& value) { m_recrawlPolicyHasBeenSet = true; m_recrawlPolicy = std::move(value); }
+
+    /**
+     * <p>A policy that specifies whether to crawl the entire dataset again, or to
+     * crawl only folders that were added since the last crawler run.</p>
+     */
+    inline CreateCrawlerRequest& WithRecrawlPolicy(const RecrawlPolicy& value) { SetRecrawlPolicy(value); return *this;}
+
+    /**
+     * <p>A policy that specifies whether to crawl the entire dataset again, or to
+     * crawl only folders that were added since the last crawler run.</p>
+     */
+    inline CreateCrawlerRequest& WithRecrawlPolicy(RecrawlPolicy&& value) { SetRecrawlPolicy(std::move(value)); return *this;}
+
+
+    /**
+     * <p>Specifies data lineage configuration settings for the crawler.</p>
+     */
+    inline const LineageConfiguration& GetLineageConfiguration() const{ return m_lineageConfiguration; }
+
+    /**
+     * <p>Specifies data lineage configuration settings for the crawler.</p>
+     */
+    inline bool LineageConfigurationHasBeenSet() const { return m_lineageConfigurationHasBeenSet; }
+
+    /**
+     * <p>Specifies data lineage configuration settings for the crawler.</p>
+     */
+    inline void SetLineageConfiguration(const LineageConfiguration& value) { m_lineageConfigurationHasBeenSet = true; m_lineageConfiguration = value; }
+
+    /**
+     * <p>Specifies data lineage configuration settings for the crawler.</p>
+     */
+    inline void SetLineageConfiguration(LineageConfiguration&& value) { m_lineageConfigurationHasBeenSet = true; m_lineageConfiguration = std::move(value); }
+
+    /**
+     * <p>Specifies data lineage configuration settings for the crawler.</p>
+     */
+    inline CreateCrawlerRequest& WithLineageConfiguration(const LineageConfiguration& value) { SetLineageConfiguration(value); return *this;}
+
+    /**
+     * <p>Specifies data lineage configuration settings for the crawler.</p>
+     */
+    inline CreateCrawlerRequest& WithLineageConfiguration(LineageConfiguration&& value) { SetLineageConfiguration(std::move(value)); return *this;}
+
+
+    /**
+     * <p>Crawler configuration information. This versioned JSON string allows users to
+     * specify aspects of a crawler's behavior. For more information, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
      * a Crawler</a>.</p>
      */
     inline const Aws::String& GetConfiguration() const{ return m_configuration; }
 
     /**
-     * <p>The crawler configuration information. This versioned JSON string allows
-     * users to specify aspects of a crawler's behavior. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
+     * <p>Crawler configuration information. This versioned JSON string allows users to
+     * specify aspects of a crawler's behavior. For more information, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
      * a Crawler</a>.</p>
      */
     inline bool ConfigurationHasBeenSet() const { return m_configurationHasBeenSet; }
 
     /**
-     * <p>The crawler configuration information. This versioned JSON string allows
-     * users to specify aspects of a crawler's behavior. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
+     * <p>Crawler configuration information. This versioned JSON string allows users to
+     * specify aspects of a crawler's behavior. For more information, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
      * a Crawler</a>.</p>
      */
     inline void SetConfiguration(const Aws::String& value) { m_configurationHasBeenSet = true; m_configuration = value; }
 
     /**
-     * <p>The crawler configuration information. This versioned JSON string allows
-     * users to specify aspects of a crawler's behavior. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
+     * <p>Crawler configuration information. This versioned JSON string allows users to
+     * specify aspects of a crawler's behavior. For more information, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
      * a Crawler</a>.</p>
      */
     inline void SetConfiguration(Aws::String&& value) { m_configurationHasBeenSet = true; m_configuration = std::move(value); }
 
     /**
-     * <p>The crawler configuration information. This versioned JSON string allows
-     * users to specify aspects of a crawler's behavior. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
+     * <p>Crawler configuration information. This versioned JSON string allows users to
+     * specify aspects of a crawler's behavior. For more information, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
      * a Crawler</a>.</p>
      */
     inline void SetConfiguration(const char* value) { m_configurationHasBeenSet = true; m_configuration.assign(value); }
 
     /**
-     * <p>The crawler configuration information. This versioned JSON string allows
-     * users to specify aspects of a crawler's behavior. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
+     * <p>Crawler configuration information. This versioned JSON string allows users to
+     * specify aspects of a crawler's behavior. For more information, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
      * a Crawler</a>.</p>
      */
     inline CreateCrawlerRequest& WithConfiguration(const Aws::String& value) { SetConfiguration(value); return *this;}
 
     /**
-     * <p>The crawler configuration information. This versioned JSON string allows
-     * users to specify aspects of a crawler's behavior. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
+     * <p>Crawler configuration information. This versioned JSON string allows users to
+     * specify aspects of a crawler's behavior. For more information, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
      * a Crawler</a>.</p>
      */
     inline CreateCrawlerRequest& WithConfiguration(Aws::String&& value) { SetConfiguration(std::move(value)); return *this;}
 
     /**
-     * <p>The crawler configuration information. This versioned JSON string allows
-     * users to specify aspects of a crawler's behavior. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
+     * <p>Crawler configuration information. This versioned JSON string allows users to
+     * specify aspects of a crawler's behavior. For more information, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html">Configuring
      * a Crawler</a>.</p>
      */
     inline CreateCrawlerRequest& WithConfiguration(const char* value) { SetConfiguration(value); return *this;}
@@ -583,106 +635,106 @@ namespace Model
 
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline const Aws::Map<Aws::String, Aws::String>& GetTags() const{ return m_tags; }
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline void SetTags(const Aws::Map<Aws::String, Aws::String>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline void SetTags(Aws::Map<Aws::String, Aws::String>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline CreateCrawlerRequest& WithTags(const Aws::Map<Aws::String, Aws::String>& value) { SetTags(value); return *this;}
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline CreateCrawlerRequest& WithTags(Aws::Map<Aws::String, Aws::String>&& value) { SetTags(std::move(value)); return *this;}
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline CreateCrawlerRequest& AddTags(const Aws::String& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline CreateCrawlerRequest& AddTags(Aws::String&& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline CreateCrawlerRequest& AddTags(const Aws::String& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline CreateCrawlerRequest& AddTags(Aws::String&& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline CreateCrawlerRequest& AddTags(const char* key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline CreateCrawlerRequest& AddTags(Aws::String&& key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>The tags to use with this crawler request. You can use tags to limit access
-     * to the crawler. For more information, see <a
-     * href="http://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
-     * AWS Glue</a>.</p>
+     * <p>The tags to use with this crawler request. You may use tags to limit access
+     * to the crawler. For more information about tags in AWS Glue, see <a
+     * href="https://docs.aws.amazon.com/glue/latest/dg/monitor-tags.html">AWS Tags in
+     * AWS Glue</a> in the developer guide.</p>
      */
     inline CreateCrawlerRequest& AddTags(const char* key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
 
@@ -715,6 +767,12 @@ namespace Model
     SchemaChangePolicy m_schemaChangePolicy;
     bool m_schemaChangePolicyHasBeenSet;
 
+    RecrawlPolicy m_recrawlPolicy;
+    bool m_recrawlPolicyHasBeenSet;
+
+    LineageConfiguration m_lineageConfiguration;
+    bool m_lineageConfigurationHasBeenSet;
+
     Aws::String m_configuration;
     bool m_configurationHasBeenSet;
 
