@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/iotanalytics/IoTAnalytics_EXPORTS.h>
@@ -24,6 +14,7 @@
 #include <aws/iotanalytics/model/DatasetTrigger.h>
 #include <aws/iotanalytics/model/DatasetContentDeliveryRule.h>
 #include <aws/iotanalytics/model/Tag.h>
+#include <aws/iotanalytics/model/LateDataRule.h>
 #include <utility>
 
 namespace Aws
@@ -134,7 +125,7 @@ namespace Model
     /**
      * <p>A list of triggers. A trigger causes data set contents to be populated at a
      * specified time interval or when another data set's contents are created. The
-     * list of triggers can be empty or contain up to five <b>DataSetTrigger</b>
+     * list of triggers can be empty or contain up to five <code>DataSetTrigger</code>
      * objects.</p>
      */
     inline const Aws::Vector<DatasetTrigger>& GetTriggers() const{ return m_triggers; }
@@ -142,7 +133,7 @@ namespace Model
     /**
      * <p>A list of triggers. A trigger causes data set contents to be populated at a
      * specified time interval or when another data set's contents are created. The
-     * list of triggers can be empty or contain up to five <b>DataSetTrigger</b>
+     * list of triggers can be empty or contain up to five <code>DataSetTrigger</code>
      * objects.</p>
      */
     inline bool TriggersHasBeenSet() const { return m_triggersHasBeenSet; }
@@ -150,7 +141,7 @@ namespace Model
     /**
      * <p>A list of triggers. A trigger causes data set contents to be populated at a
      * specified time interval or when another data set's contents are created. The
-     * list of triggers can be empty or contain up to five <b>DataSetTrigger</b>
+     * list of triggers can be empty or contain up to five <code>DataSetTrigger</code>
      * objects.</p>
      */
     inline void SetTriggers(const Aws::Vector<DatasetTrigger>& value) { m_triggersHasBeenSet = true; m_triggers = value; }
@@ -158,7 +149,7 @@ namespace Model
     /**
      * <p>A list of triggers. A trigger causes data set contents to be populated at a
      * specified time interval or when another data set's contents are created. The
-     * list of triggers can be empty or contain up to five <b>DataSetTrigger</b>
+     * list of triggers can be empty or contain up to five <code>DataSetTrigger</code>
      * objects.</p>
      */
     inline void SetTriggers(Aws::Vector<DatasetTrigger>&& value) { m_triggersHasBeenSet = true; m_triggers = std::move(value); }
@@ -166,7 +157,7 @@ namespace Model
     /**
      * <p>A list of triggers. A trigger causes data set contents to be populated at a
      * specified time interval or when another data set's contents are created. The
-     * list of triggers can be empty or contain up to five <b>DataSetTrigger</b>
+     * list of triggers can be empty or contain up to five <code>DataSetTrigger</code>
      * objects.</p>
      */
     inline CreateDatasetRequest& WithTriggers(const Aws::Vector<DatasetTrigger>& value) { SetTriggers(value); return *this;}
@@ -174,7 +165,7 @@ namespace Model
     /**
      * <p>A list of triggers. A trigger causes data set contents to be populated at a
      * specified time interval or when another data set's contents are created. The
-     * list of triggers can be empty or contain up to five <b>DataSetTrigger</b>
+     * list of triggers can be empty or contain up to five <code>DataSetTrigger</code>
      * objects.</p>
      */
     inline CreateDatasetRequest& WithTriggers(Aws::Vector<DatasetTrigger>&& value) { SetTriggers(std::move(value)); return *this;}
@@ -182,7 +173,7 @@ namespace Model
     /**
      * <p>A list of triggers. A trigger causes data set contents to be populated at a
      * specified time interval or when another data set's contents are created. The
-     * list of triggers can be empty or contain up to five <b>DataSetTrigger</b>
+     * list of triggers can be empty or contain up to five <code>DataSetTrigger</code>
      * objects.</p>
      */
     inline CreateDatasetRequest& AddTriggers(const DatasetTrigger& value) { m_triggersHasBeenSet = true; m_triggers.push_back(value); return *this; }
@@ -190,173 +181,197 @@ namespace Model
     /**
      * <p>A list of triggers. A trigger causes data set contents to be populated at a
      * specified time interval or when another data set's contents are created. The
-     * list of triggers can be empty or contain up to five <b>DataSetTrigger</b>
+     * list of triggers can be empty or contain up to five <code>DataSetTrigger</code>
      * objects.</p>
      */
     inline CreateDatasetRequest& AddTriggers(DatasetTrigger&& value) { m_triggersHasBeenSet = true; m_triggers.push_back(std::move(value)); return *this; }
 
 
     /**
-     * <p>When data set contents are created they are delivered to destinations
+     * <p>When dataset contents are created, they are delivered to destinations
      * specified here.</p>
      */
     inline const Aws::Vector<DatasetContentDeliveryRule>& GetContentDeliveryRules() const{ return m_contentDeliveryRules; }
 
     /**
-     * <p>When data set contents are created they are delivered to destinations
+     * <p>When dataset contents are created, they are delivered to destinations
      * specified here.</p>
      */
     inline bool ContentDeliveryRulesHasBeenSet() const { return m_contentDeliveryRulesHasBeenSet; }
 
     /**
-     * <p>When data set contents are created they are delivered to destinations
+     * <p>When dataset contents are created, they are delivered to destinations
      * specified here.</p>
      */
     inline void SetContentDeliveryRules(const Aws::Vector<DatasetContentDeliveryRule>& value) { m_contentDeliveryRulesHasBeenSet = true; m_contentDeliveryRules = value; }
 
     /**
-     * <p>When data set contents are created they are delivered to destinations
+     * <p>When dataset contents are created, they are delivered to destinations
      * specified here.</p>
      */
     inline void SetContentDeliveryRules(Aws::Vector<DatasetContentDeliveryRule>&& value) { m_contentDeliveryRulesHasBeenSet = true; m_contentDeliveryRules = std::move(value); }
 
     /**
-     * <p>When data set contents are created they are delivered to destinations
+     * <p>When dataset contents are created, they are delivered to destinations
      * specified here.</p>
      */
     inline CreateDatasetRequest& WithContentDeliveryRules(const Aws::Vector<DatasetContentDeliveryRule>& value) { SetContentDeliveryRules(value); return *this;}
 
     /**
-     * <p>When data set contents are created they are delivered to destinations
+     * <p>When dataset contents are created, they are delivered to destinations
      * specified here.</p>
      */
     inline CreateDatasetRequest& WithContentDeliveryRules(Aws::Vector<DatasetContentDeliveryRule>&& value) { SetContentDeliveryRules(std::move(value)); return *this;}
 
     /**
-     * <p>When data set contents are created they are delivered to destinations
+     * <p>When dataset contents are created, they are delivered to destinations
      * specified here.</p>
      */
     inline CreateDatasetRequest& AddContentDeliveryRules(const DatasetContentDeliveryRule& value) { m_contentDeliveryRulesHasBeenSet = true; m_contentDeliveryRules.push_back(value); return *this; }
 
     /**
-     * <p>When data set contents are created they are delivered to destinations
+     * <p>When dataset contents are created, they are delivered to destinations
      * specified here.</p>
      */
     inline CreateDatasetRequest& AddContentDeliveryRules(DatasetContentDeliveryRule&& value) { m_contentDeliveryRulesHasBeenSet = true; m_contentDeliveryRules.push_back(std::move(value)); return *this; }
 
 
     /**
-     * <p>[Optional] How long, in days, versions of data set contents are kept for the
-     * data set. If not specified or set to null, versions of data set contents are
-     * retained for at most 90 days. The number of versions of data set contents
-     * retained is determined by the <code>versioningConfiguration</code> parameter.
-     * (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How long, in days, versions of dataset contents are kept for the
+     * dataset. If not specified or set to <code>null</code>, versions of dataset
+     * contents are retained for at most 90 days. The number of versions of dataset
+     * contents retained is determined by the <code>versioningConfiguration</code>
+     * parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline const RetentionPeriod& GetRetentionPeriod() const{ return m_retentionPeriod; }
 
     /**
-     * <p>[Optional] How long, in days, versions of data set contents are kept for the
-     * data set. If not specified or set to null, versions of data set contents are
-     * retained for at most 90 days. The number of versions of data set contents
-     * retained is determined by the <code>versioningConfiguration</code> parameter.
-     * (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How long, in days, versions of dataset contents are kept for the
+     * dataset. If not specified or set to <code>null</code>, versions of dataset
+     * contents are retained for at most 90 days. The number of versions of dataset
+     * contents retained is determined by the <code>versioningConfiguration</code>
+     * parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline bool RetentionPeriodHasBeenSet() const { return m_retentionPeriodHasBeenSet; }
 
     /**
-     * <p>[Optional] How long, in days, versions of data set contents are kept for the
-     * data set. If not specified or set to null, versions of data set contents are
-     * retained for at most 90 days. The number of versions of data set contents
-     * retained is determined by the <code>versioningConfiguration</code> parameter.
-     * (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How long, in days, versions of dataset contents are kept for the
+     * dataset. If not specified or set to <code>null</code>, versions of dataset
+     * contents are retained for at most 90 days. The number of versions of dataset
+     * contents retained is determined by the <code>versioningConfiguration</code>
+     * parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline void SetRetentionPeriod(const RetentionPeriod& value) { m_retentionPeriodHasBeenSet = true; m_retentionPeriod = value; }
 
     /**
-     * <p>[Optional] How long, in days, versions of data set contents are kept for the
-     * data set. If not specified or set to null, versions of data set contents are
-     * retained for at most 90 days. The number of versions of data set contents
-     * retained is determined by the <code>versioningConfiguration</code> parameter.
-     * (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How long, in days, versions of dataset contents are kept for the
+     * dataset. If not specified or set to <code>null</code>, versions of dataset
+     * contents are retained for at most 90 days. The number of versions of dataset
+     * contents retained is determined by the <code>versioningConfiguration</code>
+     * parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline void SetRetentionPeriod(RetentionPeriod&& value) { m_retentionPeriodHasBeenSet = true; m_retentionPeriod = std::move(value); }
 
     /**
-     * <p>[Optional] How long, in days, versions of data set contents are kept for the
-     * data set. If not specified or set to null, versions of data set contents are
-     * retained for at most 90 days. The number of versions of data set contents
-     * retained is determined by the <code>versioningConfiguration</code> parameter.
-     * (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How long, in days, versions of dataset contents are kept for the
+     * dataset. If not specified or set to <code>null</code>, versions of dataset
+     * contents are retained for at most 90 days. The number of versions of dataset
+     * contents retained is determined by the <code>versioningConfiguration</code>
+     * parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline CreateDatasetRequest& WithRetentionPeriod(const RetentionPeriod& value) { SetRetentionPeriod(value); return *this;}
 
     /**
-     * <p>[Optional] How long, in days, versions of data set contents are kept for the
-     * data set. If not specified or set to null, versions of data set contents are
-     * retained for at most 90 days. The number of versions of data set contents
-     * retained is determined by the <code>versioningConfiguration</code> parameter.
-     * (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How long, in days, versions of dataset contents are kept for the
+     * dataset. If not specified or set to <code>null</code>, versions of dataset
+     * contents are retained for at most 90 days. The number of versions of dataset
+     * contents retained is determined by the <code>versioningConfiguration</code>
+     * parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline CreateDatasetRequest& WithRetentionPeriod(RetentionPeriod&& value) { SetRetentionPeriod(std::move(value)); return *this;}
 
 
     /**
-     * <p>[Optional] How many versions of data set contents are kept. If not specified
-     * or set to null, only the latest version plus the latest succeeded version (if
-     * they are different) are kept for the time period specified by the
-     * "retentionPeriod" parameter. (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How many versions of dataset contents are kept. If not specified or
+     * set to null, only the latest version plus the latest succeeded version (if they
+     * are different) are kept for the time period specified by the
+     * <code>retentionPeriod</code> parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline const VersioningConfiguration& GetVersioningConfiguration() const{ return m_versioningConfiguration; }
 
     /**
-     * <p>[Optional] How many versions of data set contents are kept. If not specified
-     * or set to null, only the latest version plus the latest succeeded version (if
-     * they are different) are kept for the time period specified by the
-     * "retentionPeriod" parameter. (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How many versions of dataset contents are kept. If not specified or
+     * set to null, only the latest version plus the latest succeeded version (if they
+     * are different) are kept for the time period specified by the
+     * <code>retentionPeriod</code> parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline bool VersioningConfigurationHasBeenSet() const { return m_versioningConfigurationHasBeenSet; }
 
     /**
-     * <p>[Optional] How many versions of data set contents are kept. If not specified
-     * or set to null, only the latest version plus the latest succeeded version (if
-     * they are different) are kept for the time period specified by the
-     * "retentionPeriod" parameter. (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How many versions of dataset contents are kept. If not specified or
+     * set to null, only the latest version plus the latest succeeded version (if they
+     * are different) are kept for the time period specified by the
+     * <code>retentionPeriod</code> parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline void SetVersioningConfiguration(const VersioningConfiguration& value) { m_versioningConfigurationHasBeenSet = true; m_versioningConfiguration = value; }
 
     /**
-     * <p>[Optional] How many versions of data set contents are kept. If not specified
-     * or set to null, only the latest version plus the latest succeeded version (if
-     * they are different) are kept for the time period specified by the
-     * "retentionPeriod" parameter. (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How many versions of dataset contents are kept. If not specified or
+     * set to null, only the latest version plus the latest succeeded version (if they
+     * are different) are kept for the time period specified by the
+     * <code>retentionPeriod</code> parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline void SetVersioningConfiguration(VersioningConfiguration&& value) { m_versioningConfigurationHasBeenSet = true; m_versioningConfiguration = std::move(value); }
 
     /**
-     * <p>[Optional] How many versions of data set contents are kept. If not specified
-     * or set to null, only the latest version plus the latest succeeded version (if
-     * they are different) are kept for the time period specified by the
-     * "retentionPeriod" parameter. (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How many versions of dataset contents are kept. If not specified or
+     * set to null, only the latest version plus the latest succeeded version (if they
+     * are different) are kept for the time period specified by the
+     * <code>retentionPeriod</code> parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline CreateDatasetRequest& WithVersioningConfiguration(const VersioningConfiguration& value) { SetVersioningConfiguration(value); return *this;}
 
     /**
-     * <p>[Optional] How many versions of data set contents are kept. If not specified
-     * or set to null, only the latest version plus the latest succeeded version (if
-     * they are different) are kept for the time period specified by the
-     * "retentionPeriod" parameter. (For more information, see
-     * https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions)</p>
+     * <p>Optional. How many versions of dataset contents are kept. If not specified or
+     * set to null, only the latest version plus the latest succeeded version (if they
+     * are different) are kept for the time period specified by the
+     * <code>retentionPeriod</code> parameter. For more information, see <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/userguide/getting-started.html#aws-iot-analytics-dataset-versions">Keeping
+     * Multiple Versions of AWS IoT Analytics Data Sets</a> in the <i>AWS IoT Analytics
+     * User Guide</i>.</p>
      */
     inline CreateDatasetRequest& WithVersioningConfiguration(VersioningConfiguration&& value) { SetVersioningConfiguration(std::move(value)); return *this;}
 
@@ -401,6 +416,71 @@ namespace Model
      */
     inline CreateDatasetRequest& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
+
+    /**
+     * <p>A list of data rules that send notifications to Amazon CloudWatch, when data
+     * arrives late. To specify <code>lateDataRules</code>, the dataset must use a <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeltaTime.html">DeltaTimer</a>
+     * filter.</p>
+     */
+    inline const Aws::Vector<LateDataRule>& GetLateDataRules() const{ return m_lateDataRules; }
+
+    /**
+     * <p>A list of data rules that send notifications to Amazon CloudWatch, when data
+     * arrives late. To specify <code>lateDataRules</code>, the dataset must use a <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeltaTime.html">DeltaTimer</a>
+     * filter.</p>
+     */
+    inline bool LateDataRulesHasBeenSet() const { return m_lateDataRulesHasBeenSet; }
+
+    /**
+     * <p>A list of data rules that send notifications to Amazon CloudWatch, when data
+     * arrives late. To specify <code>lateDataRules</code>, the dataset must use a <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeltaTime.html">DeltaTimer</a>
+     * filter.</p>
+     */
+    inline void SetLateDataRules(const Aws::Vector<LateDataRule>& value) { m_lateDataRulesHasBeenSet = true; m_lateDataRules = value; }
+
+    /**
+     * <p>A list of data rules that send notifications to Amazon CloudWatch, when data
+     * arrives late. To specify <code>lateDataRules</code>, the dataset must use a <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeltaTime.html">DeltaTimer</a>
+     * filter.</p>
+     */
+    inline void SetLateDataRules(Aws::Vector<LateDataRule>&& value) { m_lateDataRulesHasBeenSet = true; m_lateDataRules = std::move(value); }
+
+    /**
+     * <p>A list of data rules that send notifications to Amazon CloudWatch, when data
+     * arrives late. To specify <code>lateDataRules</code>, the dataset must use a <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeltaTime.html">DeltaTimer</a>
+     * filter.</p>
+     */
+    inline CreateDatasetRequest& WithLateDataRules(const Aws::Vector<LateDataRule>& value) { SetLateDataRules(value); return *this;}
+
+    /**
+     * <p>A list of data rules that send notifications to Amazon CloudWatch, when data
+     * arrives late. To specify <code>lateDataRules</code>, the dataset must use a <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeltaTime.html">DeltaTimer</a>
+     * filter.</p>
+     */
+    inline CreateDatasetRequest& WithLateDataRules(Aws::Vector<LateDataRule>&& value) { SetLateDataRules(std::move(value)); return *this;}
+
+    /**
+     * <p>A list of data rules that send notifications to Amazon CloudWatch, when data
+     * arrives late. To specify <code>lateDataRules</code>, the dataset must use a <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeltaTime.html">DeltaTimer</a>
+     * filter.</p>
+     */
+    inline CreateDatasetRequest& AddLateDataRules(const LateDataRule& value) { m_lateDataRulesHasBeenSet = true; m_lateDataRules.push_back(value); return *this; }
+
+    /**
+     * <p>A list of data rules that send notifications to Amazon CloudWatch, when data
+     * arrives late. To specify <code>lateDataRules</code>, the dataset must use a <a
+     * href="https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeltaTime.html">DeltaTimer</a>
+     * filter.</p>
+     */
+    inline CreateDatasetRequest& AddLateDataRules(LateDataRule&& value) { m_lateDataRulesHasBeenSet = true; m_lateDataRules.push_back(std::move(value)); return *this; }
+
   private:
 
     Aws::String m_datasetName;
@@ -423,6 +503,9 @@ namespace Model
 
     Aws::Vector<Tag> m_tags;
     bool m_tagsHasBeenSet;
+
+    Aws::Vector<LateDataRule> m_lateDataRules;
+    bool m_lateDataRulesHasBeenSet;
   };
 
 } // namespace Model
