@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/lakeformation/LakeFormation_EXPORTS.h>
@@ -87,19 +77,19 @@ namespace Model
         class RevokePermissionsRequest;
         class UpdateResourceRequest;
 
-        typedef Aws::Utils::Outcome<BatchGrantPermissionsResult, Aws::Client::AWSError<LakeFormationErrors>> BatchGrantPermissionsOutcome;
-        typedef Aws::Utils::Outcome<BatchRevokePermissionsResult, Aws::Client::AWSError<LakeFormationErrors>> BatchRevokePermissionsOutcome;
-        typedef Aws::Utils::Outcome<DeregisterResourceResult, Aws::Client::AWSError<LakeFormationErrors>> DeregisterResourceOutcome;
-        typedef Aws::Utils::Outcome<DescribeResourceResult, Aws::Client::AWSError<LakeFormationErrors>> DescribeResourceOutcome;
-        typedef Aws::Utils::Outcome<GetDataLakeSettingsResult, Aws::Client::AWSError<LakeFormationErrors>> GetDataLakeSettingsOutcome;
-        typedef Aws::Utils::Outcome<GetEffectivePermissionsForPathResult, Aws::Client::AWSError<LakeFormationErrors>> GetEffectivePermissionsForPathOutcome;
-        typedef Aws::Utils::Outcome<GrantPermissionsResult, Aws::Client::AWSError<LakeFormationErrors>> GrantPermissionsOutcome;
-        typedef Aws::Utils::Outcome<ListPermissionsResult, Aws::Client::AWSError<LakeFormationErrors>> ListPermissionsOutcome;
-        typedef Aws::Utils::Outcome<ListResourcesResult, Aws::Client::AWSError<LakeFormationErrors>> ListResourcesOutcome;
-        typedef Aws::Utils::Outcome<PutDataLakeSettingsResult, Aws::Client::AWSError<LakeFormationErrors>> PutDataLakeSettingsOutcome;
-        typedef Aws::Utils::Outcome<RegisterResourceResult, Aws::Client::AWSError<LakeFormationErrors>> RegisterResourceOutcome;
-        typedef Aws::Utils::Outcome<RevokePermissionsResult, Aws::Client::AWSError<LakeFormationErrors>> RevokePermissionsOutcome;
-        typedef Aws::Utils::Outcome<UpdateResourceResult, Aws::Client::AWSError<LakeFormationErrors>> UpdateResourceOutcome;
+        typedef Aws::Utils::Outcome<BatchGrantPermissionsResult, LakeFormationError> BatchGrantPermissionsOutcome;
+        typedef Aws::Utils::Outcome<BatchRevokePermissionsResult, LakeFormationError> BatchRevokePermissionsOutcome;
+        typedef Aws::Utils::Outcome<DeregisterResourceResult, LakeFormationError> DeregisterResourceOutcome;
+        typedef Aws::Utils::Outcome<DescribeResourceResult, LakeFormationError> DescribeResourceOutcome;
+        typedef Aws::Utils::Outcome<GetDataLakeSettingsResult, LakeFormationError> GetDataLakeSettingsOutcome;
+        typedef Aws::Utils::Outcome<GetEffectivePermissionsForPathResult, LakeFormationError> GetEffectivePermissionsForPathOutcome;
+        typedef Aws::Utils::Outcome<GrantPermissionsResult, LakeFormationError> GrantPermissionsOutcome;
+        typedef Aws::Utils::Outcome<ListPermissionsResult, LakeFormationError> ListPermissionsOutcome;
+        typedef Aws::Utils::Outcome<ListResourcesResult, LakeFormationError> ListResourcesOutcome;
+        typedef Aws::Utils::Outcome<PutDataLakeSettingsResult, LakeFormationError> PutDataLakeSettingsOutcome;
+        typedef Aws::Utils::Outcome<RegisterResourceResult, LakeFormationError> RegisterResourceOutcome;
+        typedef Aws::Utils::Outcome<RevokePermissionsResult, LakeFormationError> RevokePermissionsOutcome;
+        typedef Aws::Utils::Outcome<UpdateResourceResult, LakeFormationError> UpdateResourceOutcome;
 
         typedef std::future<BatchGrantPermissionsOutcome> BatchGrantPermissionsOutcomeCallable;
         typedef std::future<BatchRevokePermissionsOutcome> BatchRevokePermissionsOutcomeCallable;
@@ -162,8 +152,6 @@ namespace Model
 
         virtual ~LakeFormationClient();
 
-        inline virtual const char* GetServiceClientName() const override { return "LakeFormation"; }
-
 
         /**
          * <p>Batch operation to grant permissions to the principal.</p><p><h3>See
@@ -281,14 +269,16 @@ namespace Model
         virtual void DescribeResourceAsync(const Model::DescribeResourceRequest& request, const DescribeResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
         /**
-         * <p>The AWS Lake Formation principal.</p><p><h3>See Also:</h3>   <a
+         * <p>Retrieves the list of the data lake administrators of a Lake
+         * Formation-managed data lake. </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/GetDataLakeSettings">AWS
          * API Reference</a></p>
          */
         virtual Model::GetDataLakeSettingsOutcome GetDataLakeSettings(const Model::GetDataLakeSettingsRequest& request) const;
 
         /**
-         * <p>The AWS Lake Formation principal.</p><p><h3>See Also:</h3>   <a
+         * <p>Retrieves the list of the data lake administrators of a Lake
+         * Formation-managed data lake. </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/GetDataLakeSettings">AWS
          * API Reference</a></p>
          *
@@ -297,7 +287,8 @@ namespace Model
         virtual Model::GetDataLakeSettingsOutcomeCallable GetDataLakeSettingsCallable(const Model::GetDataLakeSettingsRequest& request) const;
 
         /**
-         * <p>The AWS Lake Formation principal.</p><p><h3>See Also:</h3>   <a
+         * <p>Retrieves the list of the data lake administrators of a Lake
+         * Formation-managed data lake. </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/GetDataLakeSettings">AWS
          * API Reference</a></p>
          *
@@ -306,16 +297,20 @@ namespace Model
         virtual void GetDataLakeSettingsAsync(const Model::GetDataLakeSettingsRequest& request, const GetDataLakeSettingsResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
         /**
-         * <p>Returns the permissions for a specified table or database resource located at
-         * a path in Amazon S3.</p><p><h3>See Also:</h3>   <a
+         * <p>Returns the Lake Formation permissions for a specified table or database
+         * resource located at a path in Amazon S3.
+         * <code>GetEffectivePermissionsForPath</code> will not return databases and tables
+         * if the catalog is encrypted.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/GetEffectivePermissionsForPath">AWS
          * API Reference</a></p>
          */
         virtual Model::GetEffectivePermissionsForPathOutcome GetEffectivePermissionsForPath(const Model::GetEffectivePermissionsForPathRequest& request) const;
 
         /**
-         * <p>Returns the permissions for a specified table or database resource located at
-         * a path in Amazon S3.</p><p><h3>See Also:</h3>   <a
+         * <p>Returns the Lake Formation permissions for a specified table or database
+         * resource located at a path in Amazon S3.
+         * <code>GetEffectivePermissionsForPath</code> will not return databases and tables
+         * if the catalog is encrypted.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/GetEffectivePermissionsForPath">AWS
          * API Reference</a></p>
          *
@@ -324,8 +319,10 @@ namespace Model
         virtual Model::GetEffectivePermissionsForPathOutcomeCallable GetEffectivePermissionsForPathCallable(const Model::GetEffectivePermissionsForPathRequest& request) const;
 
         /**
-         * <p>Returns the permissions for a specified table or database resource located at
-         * a path in Amazon S3.</p><p><h3>See Also:</h3>   <a
+         * <p>Returns the Lake Formation permissions for a specified table or database
+         * resource located at a path in Amazon S3.
+         * <code>GetEffectivePermissionsForPath</code> will not return databases and tables
+         * if the catalog is encrypted.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/GetEffectivePermissionsForPath">AWS
          * API Reference</a></p>
          *
@@ -337,7 +334,7 @@ namespace Model
          * <p>Grants permissions to the principal to access metadata in the Data Catalog
          * and data organized in underlying data storage such as Amazon S3.</p> <p>For
          * information about permissions, see <a
-         * href="https://docs-aws.amazon.com/michigan/latest/dg/security-data-access.html">Security
+         * href="https://docs-aws.amazon.com/lake-formation/latest/dg/security-data-access.html">Security
          * and Access Control to Metadata and Data</a>.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/GrantPermissions">AWS
          * API Reference</a></p>
@@ -348,7 +345,7 @@ namespace Model
          * <p>Grants permissions to the principal to access metadata in the Data Catalog
          * and data organized in underlying data storage such as Amazon S3.</p> <p>For
          * information about permissions, see <a
-         * href="https://docs-aws.amazon.com/michigan/latest/dg/security-data-access.html">Security
+         * href="https://docs-aws.amazon.com/lake-formation/latest/dg/security-data-access.html">Security
          * and Access Control to Metadata and Data</a>.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/GrantPermissions">AWS
          * API Reference</a></p>
@@ -361,7 +358,7 @@ namespace Model
          * <p>Grants permissions to the principal to access metadata in the Data Catalog
          * and data organized in underlying data storage such as Amazon S3.</p> <p>For
          * information about permissions, see <a
-         * href="https://docs-aws.amazon.com/michigan/latest/dg/security-data-access.html">Security
+         * href="https://docs-aws.amazon.com/lake-formation/latest/dg/security-data-access.html">Security
          * and Access Control to Metadata and Data</a>.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/GrantPermissions">AWS
          * API Reference</a></p>
@@ -376,7 +373,7 @@ namespace Model
          * you are able to see only the principal permissions for ALTER.</p> <p>This
          * operation returns only those permissions that have been explicitly granted.</p>
          * <p>For information about permissions, see <a
-         * href="https://docs-aws.amazon.com/michigan/latest/dg/security-data-access.html">Security
+         * href="https://docs-aws.amazon.com/lake-formation/latest/dg/security-data-access.html">Security
          * and Access Control to Metadata and Data</a>.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/ListPermissions">AWS
          * API Reference</a></p>
@@ -389,7 +386,7 @@ namespace Model
          * you are able to see only the principal permissions for ALTER.</p> <p>This
          * operation returns only those permissions that have been explicitly granted.</p>
          * <p>For information about permissions, see <a
-         * href="https://docs-aws.amazon.com/michigan/latest/dg/security-data-access.html">Security
+         * href="https://docs-aws.amazon.com/lake-formation/latest/dg/security-data-access.html">Security
          * and Access Control to Metadata and Data</a>.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/ListPermissions">AWS
          * API Reference</a></p>
@@ -404,7 +401,7 @@ namespace Model
          * you are able to see only the principal permissions for ALTER.</p> <p>This
          * operation returns only those permissions that have been explicitly granted.</p>
          * <p>For information about permissions, see <a
-         * href="https://docs-aws.amazon.com/michigan/latest/dg/security-data-access.html">Security
+         * href="https://docs-aws.amazon.com/lake-formation/latest/dg/security-data-access.html">Security
          * and Access Control to Metadata and Data</a>.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/ListPermissions">AWS
          * API Reference</a></p>
@@ -442,14 +439,28 @@ namespace Model
         virtual void ListResourcesAsync(const Model::ListResourcesRequest& request, const ListResourcesResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
         /**
-         * <p>The AWS Lake Formation principal.</p><p><h3>See Also:</h3>   <a
+         * <p>Sets the list of data lake administrators who have admin privileges on all
+         * resources managed by Lake Formation. For more information on admin privileges,
+         * see <a
+         * href="https://docs.aws.amazon.com/lake-formation/latest/dg/lake-formation-permissions.html">Granting
+         * Lake Formation Permissions</a>.</p> <p>This API replaces the current list of
+         * data lake admins with the new list being passed. To add an admin, fetch the
+         * current list and add the new admin to that list and pass that list in this
+         * API.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/PutDataLakeSettings">AWS
          * API Reference</a></p>
          */
         virtual Model::PutDataLakeSettingsOutcome PutDataLakeSettings(const Model::PutDataLakeSettingsRequest& request) const;
 
         /**
-         * <p>The AWS Lake Formation principal.</p><p><h3>See Also:</h3>   <a
+         * <p>Sets the list of data lake administrators who have admin privileges on all
+         * resources managed by Lake Formation. For more information on admin privileges,
+         * see <a
+         * href="https://docs.aws.amazon.com/lake-formation/latest/dg/lake-formation-permissions.html">Granting
+         * Lake Formation Permissions</a>.</p> <p>This API replaces the current list of
+         * data lake admins with the new list being passed. To add an admin, fetch the
+         * current list and add the new admin to that list and pass that list in this
+         * API.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/PutDataLakeSettings">AWS
          * API Reference</a></p>
          *
@@ -458,7 +469,14 @@ namespace Model
         virtual Model::PutDataLakeSettingsOutcomeCallable PutDataLakeSettingsCallable(const Model::PutDataLakeSettingsRequest& request) const;
 
         /**
-         * <p>The AWS Lake Formation principal.</p><p><h3>See Also:</h3>   <a
+         * <p>Sets the list of data lake administrators who have admin privileges on all
+         * resources managed by Lake Formation. For more information on admin privileges,
+         * see <a
+         * href="https://docs.aws.amazon.com/lake-formation/latest/dg/lake-formation-permissions.html">Granting
+         * Lake Formation Permissions</a>.</p> <p>This API replaces the current list of
+         * data lake admins with the new list being passed. To add an admin, fetch the
+         * current list and add the new admin to that list and pass that list in this
+         * API.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/PutDataLakeSettings">AWS
          * API Reference</a></p>
          *
@@ -474,8 +492,14 @@ namespace Model
          * the first Amazon S3 path, the service-linked role and a new inline policy are
          * created on your behalf. Lake Formation adds the first path to the inline policy
          * and attaches it to the service-linked role. When you register subsequent paths,
-         * Lake Formation adds the path to the existing policy.</p><p><h3>See Also:</h3>  
-         * <a
+         * Lake Formation adds the path to the existing policy.</p> <p>The following
+         * request registers a new location and gives AWS Lake Formation permission to use
+         * the service-linked role to access that location.</p> <p> <code>ResourceArn =
+         * arn:aws:s3:::my-bucket UseServiceLinkedRole = true</code> </p> <p>If
+         * <code>UseServiceLinkedRole</code> is not set to true, you must provide or set
+         * the <code>RoleArn</code>:</p> <p>
+         * <code>arn:aws:iam::12345:role/my-data-access-role</code> </p><p><h3>See
+         * Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/RegisterResource">AWS
          * API Reference</a></p>
          */
@@ -489,8 +513,14 @@ namespace Model
          * the first Amazon S3 path, the service-linked role and a new inline policy are
          * created on your behalf. Lake Formation adds the first path to the inline policy
          * and attaches it to the service-linked role. When you register subsequent paths,
-         * Lake Formation adds the path to the existing policy.</p><p><h3>See Also:</h3>  
-         * <a
+         * Lake Formation adds the path to the existing policy.</p> <p>The following
+         * request registers a new location and gives AWS Lake Formation permission to use
+         * the service-linked role to access that location.</p> <p> <code>ResourceArn =
+         * arn:aws:s3:::my-bucket UseServiceLinkedRole = true</code> </p> <p>If
+         * <code>UseServiceLinkedRole</code> is not set to true, you must provide or set
+         * the <code>RoleArn</code>:</p> <p>
+         * <code>arn:aws:iam::12345:role/my-data-access-role</code> </p><p><h3>See
+         * Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/RegisterResource">AWS
          * API Reference</a></p>
          *
@@ -506,8 +536,14 @@ namespace Model
          * the first Amazon S3 path, the service-linked role and a new inline policy are
          * created on your behalf. Lake Formation adds the first path to the inline policy
          * and attaches it to the service-linked role. When you register subsequent paths,
-         * Lake Formation adds the path to the existing policy.</p><p><h3>See Also:</h3>  
-         * <a
+         * Lake Formation adds the path to the existing policy.</p> <p>The following
+         * request registers a new location and gives AWS Lake Formation permission to use
+         * the service-linked role to access that location.</p> <p> <code>ResourceArn =
+         * arn:aws:s3:::my-bucket UseServiceLinkedRole = true</code> </p> <p>If
+         * <code>UseServiceLinkedRole</code> is not set to true, you must provide or set
+         * the <code>RoleArn</code>:</p> <p>
+         * <code>arn:aws:iam::12345:role/my-data-access-role</code> </p><p><h3>See
+         * Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/lakeformation-2017-03-31/RegisterResource">AWS
          * API Reference</a></p>
          *
