@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/lambda/Lambda_EXPORTS.h>
@@ -20,6 +10,10 @@
 #include <aws/lambda/model/EventSourcePosition.h>
 #include <aws/core/utils/DateTime.h>
 #include <aws/lambda/model/DestinationConfig.h>
+#include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/lambda/model/SelfManagedEventSource.h>
+#include <aws/lambda/model/SourceAccessConfiguration.h>
+#include <aws/lambda/model/FunctionResponseType.h>
 #include <utility>
 
 namespace Aws
@@ -50,7 +44,8 @@ namespace Model
      * <b>Amazon Kinesis</b> - The ARN of the data stream or a stream consumer.</p>
      * </li> <li> <p> <b>Amazon DynamoDB Streams</b> - The ARN of the stream.</p> </li>
      * <li> <p> <b>Amazon Simple Queue Service</b> - The ARN of the queue.</p> </li>
-     * </ul>
+     * <li> <p> <b>Amazon Managed Streaming for Apache Kafka</b> - The ARN of the
+     * cluster.</p> </li> </ul>
      */
     inline const Aws::String& GetEventSourceArn() const{ return m_eventSourceArn; }
 
@@ -59,7 +54,8 @@ namespace Model
      * <b>Amazon Kinesis</b> - The ARN of the data stream or a stream consumer.</p>
      * </li> <li> <p> <b>Amazon DynamoDB Streams</b> - The ARN of the stream.</p> </li>
      * <li> <p> <b>Amazon Simple Queue Service</b> - The ARN of the queue.</p> </li>
-     * </ul>
+     * <li> <p> <b>Amazon Managed Streaming for Apache Kafka</b> - The ARN of the
+     * cluster.</p> </li> </ul>
      */
     inline bool EventSourceArnHasBeenSet() const { return m_eventSourceArnHasBeenSet; }
 
@@ -68,7 +64,8 @@ namespace Model
      * <b>Amazon Kinesis</b> - The ARN of the data stream or a stream consumer.</p>
      * </li> <li> <p> <b>Amazon DynamoDB Streams</b> - The ARN of the stream.</p> </li>
      * <li> <p> <b>Amazon Simple Queue Service</b> - The ARN of the queue.</p> </li>
-     * </ul>
+     * <li> <p> <b>Amazon Managed Streaming for Apache Kafka</b> - The ARN of the
+     * cluster.</p> </li> </ul>
      */
     inline void SetEventSourceArn(const Aws::String& value) { m_eventSourceArnHasBeenSet = true; m_eventSourceArn = value; }
 
@@ -77,7 +74,8 @@ namespace Model
      * <b>Amazon Kinesis</b> - The ARN of the data stream or a stream consumer.</p>
      * </li> <li> <p> <b>Amazon DynamoDB Streams</b> - The ARN of the stream.</p> </li>
      * <li> <p> <b>Amazon Simple Queue Service</b> - The ARN of the queue.</p> </li>
-     * </ul>
+     * <li> <p> <b>Amazon Managed Streaming for Apache Kafka</b> - The ARN of the
+     * cluster.</p> </li> </ul>
      */
     inline void SetEventSourceArn(Aws::String&& value) { m_eventSourceArnHasBeenSet = true; m_eventSourceArn = std::move(value); }
 
@@ -86,7 +84,8 @@ namespace Model
      * <b>Amazon Kinesis</b> - The ARN of the data stream or a stream consumer.</p>
      * </li> <li> <p> <b>Amazon DynamoDB Streams</b> - The ARN of the stream.</p> </li>
      * <li> <p> <b>Amazon Simple Queue Service</b> - The ARN of the queue.</p> </li>
-     * </ul>
+     * <li> <p> <b>Amazon Managed Streaming for Apache Kafka</b> - The ARN of the
+     * cluster.</p> </li> </ul>
      */
     inline void SetEventSourceArn(const char* value) { m_eventSourceArnHasBeenSet = true; m_eventSourceArn.assign(value); }
 
@@ -95,7 +94,8 @@ namespace Model
      * <b>Amazon Kinesis</b> - The ARN of the data stream or a stream consumer.</p>
      * </li> <li> <p> <b>Amazon DynamoDB Streams</b> - The ARN of the stream.</p> </li>
      * <li> <p> <b>Amazon Simple Queue Service</b> - The ARN of the queue.</p> </li>
-     * </ul>
+     * <li> <p> <b>Amazon Managed Streaming for Apache Kafka</b> - The ARN of the
+     * cluster.</p> </li> </ul>
      */
     inline CreateEventSourceMappingRequest& WithEventSourceArn(const Aws::String& value) { SetEventSourceArn(value); return *this;}
 
@@ -104,7 +104,8 @@ namespace Model
      * <b>Amazon Kinesis</b> - The ARN of the data stream or a stream consumer.</p>
      * </li> <li> <p> <b>Amazon DynamoDB Streams</b> - The ARN of the stream.</p> </li>
      * <li> <p> <b>Amazon Simple Queue Service</b> - The ARN of the queue.</p> </li>
-     * </ul>
+     * <li> <p> <b>Amazon Managed Streaming for Apache Kafka</b> - The ARN of the
+     * cluster.</p> </li> </ul>
      */
     inline CreateEventSourceMappingRequest& WithEventSourceArn(Aws::String&& value) { SetEventSourceArn(std::move(value)); return *this;}
 
@@ -113,7 +114,8 @@ namespace Model
      * <b>Amazon Kinesis</b> - The ARN of the data stream or a stream consumer.</p>
      * </li> <li> <p> <b>Amazon DynamoDB Streams</b> - The ARN of the stream.</p> </li>
      * <li> <p> <b>Amazon Simple Queue Service</b> - The ARN of the queue.</p> </li>
-     * </ul>
+     * <li> <p> <b>Amazon Managed Streaming for Apache Kafka</b> - The ARN of the
+     * cluster.</p> </li> </ul>
      */
     inline CreateEventSourceMappingRequest& WithEventSourceArn(const char* value) { SetEventSourceArn(value); return *this;}
 
@@ -232,22 +234,26 @@ namespace Model
 
 
     /**
-     * <p>Disables the event source mapping to pause polling and invocation.</p>
+     * <p>If true, the event source mapping is active. Set to false to pause polling
+     * and invocation.</p>
      */
     inline bool GetEnabled() const{ return m_enabled; }
 
     /**
-     * <p>Disables the event source mapping to pause polling and invocation.</p>
+     * <p>If true, the event source mapping is active. Set to false to pause polling
+     * and invocation.</p>
      */
     inline bool EnabledHasBeenSet() const { return m_enabledHasBeenSet; }
 
     /**
-     * <p>Disables the event source mapping to pause polling and invocation.</p>
+     * <p>If true, the event source mapping is active. Set to false to pause polling
+     * and invocation.</p>
      */
     inline void SetEnabled(bool value) { m_enabledHasBeenSet = true; m_enabled = value; }
 
     /**
-     * <p>Disables the event source mapping to pause polling and invocation.</p>
+     * <p>If true, the event source mapping is active. Set to false to pause polling
+     * and invocation.</p>
      */
     inline CreateEventSourceMappingRequest& WithEnabled(bool value) { SetEnabled(value); return *this;}
 
@@ -256,7 +262,10 @@ namespace Model
      * <p>The maximum number of items to retrieve in a single batch.</p> <ul> <li> <p>
      * <b>Amazon Kinesis</b> - Default 100. Max 10,000.</p> </li> <li> <p> <b>Amazon
      * DynamoDB Streams</b> - Default 100. Max 1,000.</p> </li> <li> <p> <b>Amazon
-     * Simple Queue Service</b> - Default 10. Max 10.</p> </li> </ul>
+     * Simple Queue Service</b> - Default 10. For standard queues the max is 10,000.
+     * For FIFO queues the max is 10.</p> </li> <li> <p> <b>Amazon Managed Streaming
+     * for Apache Kafka</b> - Default 100. Max 10,000.</p> </li> <li> <p>
+     * <b>Self-Managed Apache Kafka</b> - Default 100. Max 10,000.</p> </li> </ul>
      */
     inline int GetBatchSize() const{ return m_batchSize; }
 
@@ -264,7 +273,10 @@ namespace Model
      * <p>The maximum number of items to retrieve in a single batch.</p> <ul> <li> <p>
      * <b>Amazon Kinesis</b> - Default 100. Max 10,000.</p> </li> <li> <p> <b>Amazon
      * DynamoDB Streams</b> - Default 100. Max 1,000.</p> </li> <li> <p> <b>Amazon
-     * Simple Queue Service</b> - Default 10. Max 10.</p> </li> </ul>
+     * Simple Queue Service</b> - Default 10. For standard queues the max is 10,000.
+     * For FIFO queues the max is 10.</p> </li> <li> <p> <b>Amazon Managed Streaming
+     * for Apache Kafka</b> - Default 100. Max 10,000.</p> </li> <li> <p>
+     * <b>Self-Managed Apache Kafka</b> - Default 100. Max 10,000.</p> </li> </ul>
      */
     inline bool BatchSizeHasBeenSet() const { return m_batchSizeHasBeenSet; }
 
@@ -272,7 +284,10 @@ namespace Model
      * <p>The maximum number of items to retrieve in a single batch.</p> <ul> <li> <p>
      * <b>Amazon Kinesis</b> - Default 100. Max 10,000.</p> </li> <li> <p> <b>Amazon
      * DynamoDB Streams</b> - Default 100. Max 1,000.</p> </li> <li> <p> <b>Amazon
-     * Simple Queue Service</b> - Default 10. Max 10.</p> </li> </ul>
+     * Simple Queue Service</b> - Default 10. For standard queues the max is 10,000.
+     * For FIFO queues the max is 10.</p> </li> <li> <p> <b>Amazon Managed Streaming
+     * for Apache Kafka</b> - Default 100. Max 10,000.</p> </li> <li> <p>
+     * <b>Self-Managed Apache Kafka</b> - Default 100. Max 10,000.</p> </li> </ul>
      */
     inline void SetBatchSize(int value) { m_batchSizeHasBeenSet = true; m_batchSize = value; }
 
@@ -280,32 +295,35 @@ namespace Model
      * <p>The maximum number of items to retrieve in a single batch.</p> <ul> <li> <p>
      * <b>Amazon Kinesis</b> - Default 100. Max 10,000.</p> </li> <li> <p> <b>Amazon
      * DynamoDB Streams</b> - Default 100. Max 1,000.</p> </li> <li> <p> <b>Amazon
-     * Simple Queue Service</b> - Default 10. Max 10.</p> </li> </ul>
+     * Simple Queue Service</b> - Default 10. For standard queues the max is 10,000.
+     * For FIFO queues the max is 10.</p> </li> <li> <p> <b>Amazon Managed Streaming
+     * for Apache Kafka</b> - Default 100. Max 10,000.</p> </li> <li> <p>
+     * <b>Self-Managed Apache Kafka</b> - Default 100. Max 10,000.</p> </li> </ul>
      */
     inline CreateEventSourceMappingRequest& WithBatchSize(int value) { SetBatchSize(value); return *this;}
 
 
     /**
-     * <p>The maximum amount of time to gather records before invoking the function, in
-     * seconds.</p>
+     * <p>(Streams and SQS standard queues) The maximum amount of time to gather
+     * records before invoking the function, in seconds.</p>
      */
     inline int GetMaximumBatchingWindowInSeconds() const{ return m_maximumBatchingWindowInSeconds; }
 
     /**
-     * <p>The maximum amount of time to gather records before invoking the function, in
-     * seconds.</p>
+     * <p>(Streams and SQS standard queues) The maximum amount of time to gather
+     * records before invoking the function, in seconds.</p>
      */
     inline bool MaximumBatchingWindowInSecondsHasBeenSet() const { return m_maximumBatchingWindowInSecondsHasBeenSet; }
 
     /**
-     * <p>The maximum amount of time to gather records before invoking the function, in
-     * seconds.</p>
+     * <p>(Streams and SQS standard queues) The maximum amount of time to gather
+     * records before invoking the function, in seconds.</p>
      */
     inline void SetMaximumBatchingWindowInSeconds(int value) { m_maximumBatchingWindowInSecondsHasBeenSet = true; m_maximumBatchingWindowInSeconds = value; }
 
     /**
-     * <p>The maximum amount of time to gather records before invoking the function, in
-     * seconds.</p>
+     * <p>(Streams and SQS standard queues) The maximum amount of time to gather
+     * records before invoking the function, in seconds.</p>
      */
     inline CreateEventSourceMappingRequest& WithMaximumBatchingWindowInSeconds(int value) { SetMaximumBatchingWindowInSeconds(value); return *this;}
 
@@ -333,43 +351,43 @@ namespace Model
 
     /**
      * <p>The position in a stream from which to start reading. Required for Amazon
-     * Kinesis and Amazon DynamoDB Streams sources. <code>AT_TIMESTAMP</code> is only
-     * supported for Amazon Kinesis streams.</p>
+     * Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
+     * <code>AT_TIMESTAMP</code> is only supported for Amazon Kinesis streams.</p>
      */
     inline const EventSourcePosition& GetStartingPosition() const{ return m_startingPosition; }
 
     /**
      * <p>The position in a stream from which to start reading. Required for Amazon
-     * Kinesis and Amazon DynamoDB Streams sources. <code>AT_TIMESTAMP</code> is only
-     * supported for Amazon Kinesis streams.</p>
+     * Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
+     * <code>AT_TIMESTAMP</code> is only supported for Amazon Kinesis streams.</p>
      */
     inline bool StartingPositionHasBeenSet() const { return m_startingPositionHasBeenSet; }
 
     /**
      * <p>The position in a stream from which to start reading. Required for Amazon
-     * Kinesis and Amazon DynamoDB Streams sources. <code>AT_TIMESTAMP</code> is only
-     * supported for Amazon Kinesis streams.</p>
+     * Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
+     * <code>AT_TIMESTAMP</code> is only supported for Amazon Kinesis streams.</p>
      */
     inline void SetStartingPosition(const EventSourcePosition& value) { m_startingPositionHasBeenSet = true; m_startingPosition = value; }
 
     /**
      * <p>The position in a stream from which to start reading. Required for Amazon
-     * Kinesis and Amazon DynamoDB Streams sources. <code>AT_TIMESTAMP</code> is only
-     * supported for Amazon Kinesis streams.</p>
+     * Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
+     * <code>AT_TIMESTAMP</code> is only supported for Amazon Kinesis streams.</p>
      */
     inline void SetStartingPosition(EventSourcePosition&& value) { m_startingPositionHasBeenSet = true; m_startingPosition = std::move(value); }
 
     /**
      * <p>The position in a stream from which to start reading. Required for Amazon
-     * Kinesis and Amazon DynamoDB Streams sources. <code>AT_TIMESTAMP</code> is only
-     * supported for Amazon Kinesis streams.</p>
+     * Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
+     * <code>AT_TIMESTAMP</code> is only supported for Amazon Kinesis streams.</p>
      */
     inline CreateEventSourceMappingRequest& WithStartingPosition(const EventSourcePosition& value) { SetStartingPosition(value); return *this;}
 
     /**
      * <p>The position in a stream from which to start reading. Required for Amazon
-     * Kinesis and Amazon DynamoDB Streams sources. <code>AT_TIMESTAMP</code> is only
-     * supported for Amazon Kinesis streams.</p>
+     * Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
+     * <code>AT_TIMESTAMP</code> is only supported for Amazon Kinesis streams.</p>
      */
     inline CreateEventSourceMappingRequest& WithStartingPosition(EventSourcePosition&& value) { SetStartingPosition(std::move(value)); return *this;}
 
@@ -449,26 +467,26 @@ namespace Model
 
 
     /**
-     * <p>(Streams) The maximum age of a record that Lambda sends to a function for
-     * processing.</p>
+     * <p>(Streams) Discard records older than the specified age. The default value is
+     * infinite (-1).</p>
      */
     inline int GetMaximumRecordAgeInSeconds() const{ return m_maximumRecordAgeInSeconds; }
 
     /**
-     * <p>(Streams) The maximum age of a record that Lambda sends to a function for
-     * processing.</p>
+     * <p>(Streams) Discard records older than the specified age. The default value is
+     * infinite (-1).</p>
      */
     inline bool MaximumRecordAgeInSecondsHasBeenSet() const { return m_maximumRecordAgeInSecondsHasBeenSet; }
 
     /**
-     * <p>(Streams) The maximum age of a record that Lambda sends to a function for
-     * processing.</p>
+     * <p>(Streams) Discard records older than the specified age. The default value is
+     * infinite (-1).</p>
      */
     inline void SetMaximumRecordAgeInSeconds(int value) { m_maximumRecordAgeInSecondsHasBeenSet = true; m_maximumRecordAgeInSeconds = value; }
 
     /**
-     * <p>(Streams) The maximum age of a record that Lambda sends to a function for
-     * processing.</p>
+     * <p>(Streams) Discard records older than the specified age. The default value is
+     * infinite (-1).</p>
      */
     inline CreateEventSourceMappingRequest& WithMaximumRecordAgeInSeconds(int value) { SetMaximumRecordAgeInSeconds(value); return *this;}
 
@@ -499,29 +517,279 @@ namespace Model
 
 
     /**
-     * <p>(Streams) The maximum number of times to retry when the function returns an
-     * error.</p>
+     * <p>(Streams) Discard records after the specified number of retries. The default
+     * value is infinite (-1). When set to infinite (-1), failed records will be
+     * retried until the record expires.</p>
      */
     inline int GetMaximumRetryAttempts() const{ return m_maximumRetryAttempts; }
 
     /**
-     * <p>(Streams) The maximum number of times to retry when the function returns an
-     * error.</p>
+     * <p>(Streams) Discard records after the specified number of retries. The default
+     * value is infinite (-1). When set to infinite (-1), failed records will be
+     * retried until the record expires.</p>
      */
     inline bool MaximumRetryAttemptsHasBeenSet() const { return m_maximumRetryAttemptsHasBeenSet; }
 
     /**
-     * <p>(Streams) The maximum number of times to retry when the function returns an
-     * error.</p>
+     * <p>(Streams) Discard records after the specified number of retries. The default
+     * value is infinite (-1). When set to infinite (-1), failed records will be
+     * retried until the record expires.</p>
      */
     inline void SetMaximumRetryAttempts(int value) { m_maximumRetryAttemptsHasBeenSet = true; m_maximumRetryAttempts = value; }
 
     /**
-     * <p>(Streams) The maximum number of times to retry when the function returns an
-     * error.</p>
+     * <p>(Streams) Discard records after the specified number of retries. The default
+     * value is infinite (-1). When set to infinite (-1), failed records will be
+     * retried until the record expires.</p>
      */
     inline CreateEventSourceMappingRequest& WithMaximumRetryAttempts(int value) { SetMaximumRetryAttempts(value); return *this;}
 
+
+    /**
+     * <p>(Streams) The duration in seconds of a processing window. The range is
+     * between 1 second up to 900 seconds.</p>
+     */
+    inline int GetTumblingWindowInSeconds() const{ return m_tumblingWindowInSeconds; }
+
+    /**
+     * <p>(Streams) The duration in seconds of a processing window. The range is
+     * between 1 second up to 900 seconds.</p>
+     */
+    inline bool TumblingWindowInSecondsHasBeenSet() const { return m_tumblingWindowInSecondsHasBeenSet; }
+
+    /**
+     * <p>(Streams) The duration in seconds of a processing window. The range is
+     * between 1 second up to 900 seconds.</p>
+     */
+    inline void SetTumblingWindowInSeconds(int value) { m_tumblingWindowInSecondsHasBeenSet = true; m_tumblingWindowInSeconds = value; }
+
+    /**
+     * <p>(Streams) The duration in seconds of a processing window. The range is
+     * between 1 second up to 900 seconds.</p>
+     */
+    inline CreateEventSourceMappingRequest& WithTumblingWindowInSeconds(int value) { SetTumblingWindowInSeconds(value); return *this;}
+
+
+    /**
+     * <p>The name of the Kafka topic.</p>
+     */
+    inline const Aws::Vector<Aws::String>& GetTopics() const{ return m_topics; }
+
+    /**
+     * <p>The name of the Kafka topic.</p>
+     */
+    inline bool TopicsHasBeenSet() const { return m_topicsHasBeenSet; }
+
+    /**
+     * <p>The name of the Kafka topic.</p>
+     */
+    inline void SetTopics(const Aws::Vector<Aws::String>& value) { m_topicsHasBeenSet = true; m_topics = value; }
+
+    /**
+     * <p>The name of the Kafka topic.</p>
+     */
+    inline void SetTopics(Aws::Vector<Aws::String>&& value) { m_topicsHasBeenSet = true; m_topics = std::move(value); }
+
+    /**
+     * <p>The name of the Kafka topic.</p>
+     */
+    inline CreateEventSourceMappingRequest& WithTopics(const Aws::Vector<Aws::String>& value) { SetTopics(value); return *this;}
+
+    /**
+     * <p>The name of the Kafka topic.</p>
+     */
+    inline CreateEventSourceMappingRequest& WithTopics(Aws::Vector<Aws::String>&& value) { SetTopics(std::move(value)); return *this;}
+
+    /**
+     * <p>The name of the Kafka topic.</p>
+     */
+    inline CreateEventSourceMappingRequest& AddTopics(const Aws::String& value) { m_topicsHasBeenSet = true; m_topics.push_back(value); return *this; }
+
+    /**
+     * <p>The name of the Kafka topic.</p>
+     */
+    inline CreateEventSourceMappingRequest& AddTopics(Aws::String&& value) { m_topicsHasBeenSet = true; m_topics.push_back(std::move(value)); return *this; }
+
+    /**
+     * <p>The name of the Kafka topic.</p>
+     */
+    inline CreateEventSourceMappingRequest& AddTopics(const char* value) { m_topicsHasBeenSet = true; m_topics.push_back(value); return *this; }
+
+
+    /**
+     * <p> (MQ) The name of the Amazon MQ broker destination queue to consume. </p>
+     */
+    inline const Aws::Vector<Aws::String>& GetQueues() const{ return m_queues; }
+
+    /**
+     * <p> (MQ) The name of the Amazon MQ broker destination queue to consume. </p>
+     */
+    inline bool QueuesHasBeenSet() const { return m_queuesHasBeenSet; }
+
+    /**
+     * <p> (MQ) The name of the Amazon MQ broker destination queue to consume. </p>
+     */
+    inline void SetQueues(const Aws::Vector<Aws::String>& value) { m_queuesHasBeenSet = true; m_queues = value; }
+
+    /**
+     * <p> (MQ) The name of the Amazon MQ broker destination queue to consume. </p>
+     */
+    inline void SetQueues(Aws::Vector<Aws::String>&& value) { m_queuesHasBeenSet = true; m_queues = std::move(value); }
+
+    /**
+     * <p> (MQ) The name of the Amazon MQ broker destination queue to consume. </p>
+     */
+    inline CreateEventSourceMappingRequest& WithQueues(const Aws::Vector<Aws::String>& value) { SetQueues(value); return *this;}
+
+    /**
+     * <p> (MQ) The name of the Amazon MQ broker destination queue to consume. </p>
+     */
+    inline CreateEventSourceMappingRequest& WithQueues(Aws::Vector<Aws::String>&& value) { SetQueues(std::move(value)); return *this;}
+
+    /**
+     * <p> (MQ) The name of the Amazon MQ broker destination queue to consume. </p>
+     */
+    inline CreateEventSourceMappingRequest& AddQueues(const Aws::String& value) { m_queuesHasBeenSet = true; m_queues.push_back(value); return *this; }
+
+    /**
+     * <p> (MQ) The name of the Amazon MQ broker destination queue to consume. </p>
+     */
+    inline CreateEventSourceMappingRequest& AddQueues(Aws::String&& value) { m_queuesHasBeenSet = true; m_queues.push_back(std::move(value)); return *this; }
+
+    /**
+     * <p> (MQ) The name of the Amazon MQ broker destination queue to consume. </p>
+     */
+    inline CreateEventSourceMappingRequest& AddQueues(const char* value) { m_queuesHasBeenSet = true; m_queues.push_back(value); return *this; }
+
+
+    /**
+     * <p>An array of the authentication protocol, or the VPC components to secure your
+     * event source.</p>
+     */
+    inline const Aws::Vector<SourceAccessConfiguration>& GetSourceAccessConfigurations() const{ return m_sourceAccessConfigurations; }
+
+    /**
+     * <p>An array of the authentication protocol, or the VPC components to secure your
+     * event source.</p>
+     */
+    inline bool SourceAccessConfigurationsHasBeenSet() const { return m_sourceAccessConfigurationsHasBeenSet; }
+
+    /**
+     * <p>An array of the authentication protocol, or the VPC components to secure your
+     * event source.</p>
+     */
+    inline void SetSourceAccessConfigurations(const Aws::Vector<SourceAccessConfiguration>& value) { m_sourceAccessConfigurationsHasBeenSet = true; m_sourceAccessConfigurations = value; }
+
+    /**
+     * <p>An array of the authentication protocol, or the VPC components to secure your
+     * event source.</p>
+     */
+    inline void SetSourceAccessConfigurations(Aws::Vector<SourceAccessConfiguration>&& value) { m_sourceAccessConfigurationsHasBeenSet = true; m_sourceAccessConfigurations = std::move(value); }
+
+    /**
+     * <p>An array of the authentication protocol, or the VPC components to secure your
+     * event source.</p>
+     */
+    inline CreateEventSourceMappingRequest& WithSourceAccessConfigurations(const Aws::Vector<SourceAccessConfiguration>& value) { SetSourceAccessConfigurations(value); return *this;}
+
+    /**
+     * <p>An array of the authentication protocol, or the VPC components to secure your
+     * event source.</p>
+     */
+    inline CreateEventSourceMappingRequest& WithSourceAccessConfigurations(Aws::Vector<SourceAccessConfiguration>&& value) { SetSourceAccessConfigurations(std::move(value)); return *this;}
+
+    /**
+     * <p>An array of the authentication protocol, or the VPC components to secure your
+     * event source.</p>
+     */
+    inline CreateEventSourceMappingRequest& AddSourceAccessConfigurations(const SourceAccessConfiguration& value) { m_sourceAccessConfigurationsHasBeenSet = true; m_sourceAccessConfigurations.push_back(value); return *this; }
+
+    /**
+     * <p>An array of the authentication protocol, or the VPC components to secure your
+     * event source.</p>
+     */
+    inline CreateEventSourceMappingRequest& AddSourceAccessConfigurations(SourceAccessConfiguration&& value) { m_sourceAccessConfigurationsHasBeenSet = true; m_sourceAccessConfigurations.push_back(std::move(value)); return *this; }
+
+
+    /**
+     * <p>The Self-Managed Apache Kafka cluster to send records.</p>
+     */
+    inline const SelfManagedEventSource& GetSelfManagedEventSource() const{ return m_selfManagedEventSource; }
+
+    /**
+     * <p>The Self-Managed Apache Kafka cluster to send records.</p>
+     */
+    inline bool SelfManagedEventSourceHasBeenSet() const { return m_selfManagedEventSourceHasBeenSet; }
+
+    /**
+     * <p>The Self-Managed Apache Kafka cluster to send records.</p>
+     */
+    inline void SetSelfManagedEventSource(const SelfManagedEventSource& value) { m_selfManagedEventSourceHasBeenSet = true; m_selfManagedEventSource = value; }
+
+    /**
+     * <p>The Self-Managed Apache Kafka cluster to send records.</p>
+     */
+    inline void SetSelfManagedEventSource(SelfManagedEventSource&& value) { m_selfManagedEventSourceHasBeenSet = true; m_selfManagedEventSource = std::move(value); }
+
+    /**
+     * <p>The Self-Managed Apache Kafka cluster to send records.</p>
+     */
+    inline CreateEventSourceMappingRequest& WithSelfManagedEventSource(const SelfManagedEventSource& value) { SetSelfManagedEventSource(value); return *this;}
+
+    /**
+     * <p>The Self-Managed Apache Kafka cluster to send records.</p>
+     */
+    inline CreateEventSourceMappingRequest& WithSelfManagedEventSource(SelfManagedEventSource&& value) { SetSelfManagedEventSource(std::move(value)); return *this;}
+
+
+    /**
+     * <p>(Streams) A list of current response type enums applied to the event source
+     * mapping.</p>
+     */
+    inline const Aws::Vector<FunctionResponseType>& GetFunctionResponseTypes() const{ return m_functionResponseTypes; }
+
+    /**
+     * <p>(Streams) A list of current response type enums applied to the event source
+     * mapping.</p>
+     */
+    inline bool FunctionResponseTypesHasBeenSet() const { return m_functionResponseTypesHasBeenSet; }
+
+    /**
+     * <p>(Streams) A list of current response type enums applied to the event source
+     * mapping.</p>
+     */
+    inline void SetFunctionResponseTypes(const Aws::Vector<FunctionResponseType>& value) { m_functionResponseTypesHasBeenSet = true; m_functionResponseTypes = value; }
+
+    /**
+     * <p>(Streams) A list of current response type enums applied to the event source
+     * mapping.</p>
+     */
+    inline void SetFunctionResponseTypes(Aws::Vector<FunctionResponseType>&& value) { m_functionResponseTypesHasBeenSet = true; m_functionResponseTypes = std::move(value); }
+
+    /**
+     * <p>(Streams) A list of current response type enums applied to the event source
+     * mapping.</p>
+     */
+    inline CreateEventSourceMappingRequest& WithFunctionResponseTypes(const Aws::Vector<FunctionResponseType>& value) { SetFunctionResponseTypes(value); return *this;}
+
+    /**
+     * <p>(Streams) A list of current response type enums applied to the event source
+     * mapping.</p>
+     */
+    inline CreateEventSourceMappingRequest& WithFunctionResponseTypes(Aws::Vector<FunctionResponseType>&& value) { SetFunctionResponseTypes(std::move(value)); return *this;}
+
+    /**
+     * <p>(Streams) A list of current response type enums applied to the event source
+     * mapping.</p>
+     */
+    inline CreateEventSourceMappingRequest& AddFunctionResponseTypes(const FunctionResponseType& value) { m_functionResponseTypesHasBeenSet = true; m_functionResponseTypes.push_back(value); return *this; }
+
+    /**
+     * <p>(Streams) A list of current response type enums applied to the event source
+     * mapping.</p>
+     */
+    inline CreateEventSourceMappingRequest& AddFunctionResponseTypes(FunctionResponseType&& value) { m_functionResponseTypesHasBeenSet = true; m_functionResponseTypes.push_back(std::move(value)); return *this; }
+
   private:
 
     Aws::String m_eventSourceArn;
@@ -559,6 +827,24 @@ namespace Model
 
     int m_maximumRetryAttempts;
     bool m_maximumRetryAttemptsHasBeenSet;
+
+    int m_tumblingWindowInSeconds;
+    bool m_tumblingWindowInSecondsHasBeenSet;
+
+    Aws::Vector<Aws::String> m_topics;
+    bool m_topicsHasBeenSet;
+
+    Aws::Vector<Aws::String> m_queues;
+    bool m_queuesHasBeenSet;
+
+    Aws::Vector<SourceAccessConfiguration> m_sourceAccessConfigurations;
+    bool m_sourceAccessConfigurationsHasBeenSet;
+
+    SelfManagedEventSource m_selfManagedEventSource;
+    bool m_selfManagedEventSourceHasBeenSet;
+
+    Aws::Vector<FunctionResponseType> m_functionResponseTypes;
+    bool m_functionResponseTypesHasBeenSet;
   };
 
 } // namespace Model
