@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/lightsail/Lightsail_EXPORTS.h>
@@ -20,6 +10,7 @@
 #include <aws/lightsail/model/ResourceLocation.h>
 #include <aws/lightsail/model/ResourceType.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/lightsail/model/IpAddressType.h>
 #include <aws/lightsail/model/InstanceHardware.h>
 #include <aws/lightsail/model/InstanceNetworking.h>
 #include <aws/lightsail/model/InstanceState.h>
@@ -214,37 +205,37 @@ namespace Model
 
     /**
      * <p>The timestamp when the instance was created (e.g.,
-     * <code>1479734909.17</code>).</p>
+     * <code>1479734909.17</code>) in Unix time format.</p>
      */
     inline const Aws::Utils::DateTime& GetCreatedAt() const{ return m_createdAt; }
 
     /**
      * <p>The timestamp when the instance was created (e.g.,
-     * <code>1479734909.17</code>).</p>
+     * <code>1479734909.17</code>) in Unix time format.</p>
      */
     inline bool CreatedAtHasBeenSet() const { return m_createdAtHasBeenSet; }
 
     /**
      * <p>The timestamp when the instance was created (e.g.,
-     * <code>1479734909.17</code>).</p>
+     * <code>1479734909.17</code>) in Unix time format.</p>
      */
     inline void SetCreatedAt(const Aws::Utils::DateTime& value) { m_createdAtHasBeenSet = true; m_createdAt = value; }
 
     /**
      * <p>The timestamp when the instance was created (e.g.,
-     * <code>1479734909.17</code>).</p>
+     * <code>1479734909.17</code>) in Unix time format.</p>
      */
     inline void SetCreatedAt(Aws::Utils::DateTime&& value) { m_createdAtHasBeenSet = true; m_createdAt = std::move(value); }
 
     /**
      * <p>The timestamp when the instance was created (e.g.,
-     * <code>1479734909.17</code>).</p>
+     * <code>1479734909.17</code>) in Unix time format.</p>
      */
     inline Instance& WithCreatedAt(const Aws::Utils::DateTime& value) { SetCreatedAt(value); return *this;}
 
     /**
      * <p>The timestamp when the instance was created (e.g.,
-     * <code>1479734909.17</code>).</p>
+     * <code>1479734909.17</code>) in Unix time format.</p>
      */
     inline Instance& WithCreatedAt(Aws::Utils::DateTime&& value) { SetCreatedAt(std::move(value)); return *this;}
 
@@ -648,44 +639,92 @@ namespace Model
 
 
     /**
-     * <p>The IPv6 address of the instance.</p>
+     * <p>The IPv6 addresses of the instance.</p>
      */
-    inline const Aws::String& GetIpv6Address() const{ return m_ipv6Address; }
+    inline const Aws::Vector<Aws::String>& GetIpv6Addresses() const{ return m_ipv6Addresses; }
 
     /**
-     * <p>The IPv6 address of the instance.</p>
+     * <p>The IPv6 addresses of the instance.</p>
      */
-    inline bool Ipv6AddressHasBeenSet() const { return m_ipv6AddressHasBeenSet; }
+    inline bool Ipv6AddressesHasBeenSet() const { return m_ipv6AddressesHasBeenSet; }
 
     /**
-     * <p>The IPv6 address of the instance.</p>
+     * <p>The IPv6 addresses of the instance.</p>
      */
-    inline void SetIpv6Address(const Aws::String& value) { m_ipv6AddressHasBeenSet = true; m_ipv6Address = value; }
+    inline void SetIpv6Addresses(const Aws::Vector<Aws::String>& value) { m_ipv6AddressesHasBeenSet = true; m_ipv6Addresses = value; }
 
     /**
-     * <p>The IPv6 address of the instance.</p>
+     * <p>The IPv6 addresses of the instance.</p>
      */
-    inline void SetIpv6Address(Aws::String&& value) { m_ipv6AddressHasBeenSet = true; m_ipv6Address = std::move(value); }
+    inline void SetIpv6Addresses(Aws::Vector<Aws::String>&& value) { m_ipv6AddressesHasBeenSet = true; m_ipv6Addresses = std::move(value); }
 
     /**
-     * <p>The IPv6 address of the instance.</p>
+     * <p>The IPv6 addresses of the instance.</p>
      */
-    inline void SetIpv6Address(const char* value) { m_ipv6AddressHasBeenSet = true; m_ipv6Address.assign(value); }
+    inline Instance& WithIpv6Addresses(const Aws::Vector<Aws::String>& value) { SetIpv6Addresses(value); return *this;}
 
     /**
-     * <p>The IPv6 address of the instance.</p>
+     * <p>The IPv6 addresses of the instance.</p>
      */
-    inline Instance& WithIpv6Address(const Aws::String& value) { SetIpv6Address(value); return *this;}
+    inline Instance& WithIpv6Addresses(Aws::Vector<Aws::String>&& value) { SetIpv6Addresses(std::move(value)); return *this;}
 
     /**
-     * <p>The IPv6 address of the instance.</p>
+     * <p>The IPv6 addresses of the instance.</p>
      */
-    inline Instance& WithIpv6Address(Aws::String&& value) { SetIpv6Address(std::move(value)); return *this;}
+    inline Instance& AddIpv6Addresses(const Aws::String& value) { m_ipv6AddressesHasBeenSet = true; m_ipv6Addresses.push_back(value); return *this; }
 
     /**
-     * <p>The IPv6 address of the instance.</p>
+     * <p>The IPv6 addresses of the instance.</p>
      */
-    inline Instance& WithIpv6Address(const char* value) { SetIpv6Address(value); return *this;}
+    inline Instance& AddIpv6Addresses(Aws::String&& value) { m_ipv6AddressesHasBeenSet = true; m_ipv6Addresses.push_back(std::move(value)); return *this; }
+
+    /**
+     * <p>The IPv6 addresses of the instance.</p>
+     */
+    inline Instance& AddIpv6Addresses(const char* value) { m_ipv6AddressesHasBeenSet = true; m_ipv6Addresses.push_back(value); return *this; }
+
+
+    /**
+     * <p>The IP address type of the instance.</p> <p>The possible values are
+     * <code>ipv4</code> for IPv4 only, and <code>dualstack</code> for IPv4 and
+     * IPv6.</p>
+     */
+    inline const IpAddressType& GetIpAddressType() const{ return m_ipAddressType; }
+
+    /**
+     * <p>The IP address type of the instance.</p> <p>The possible values are
+     * <code>ipv4</code> for IPv4 only, and <code>dualstack</code> for IPv4 and
+     * IPv6.</p>
+     */
+    inline bool IpAddressTypeHasBeenSet() const { return m_ipAddressTypeHasBeenSet; }
+
+    /**
+     * <p>The IP address type of the instance.</p> <p>The possible values are
+     * <code>ipv4</code> for IPv4 only, and <code>dualstack</code> for IPv4 and
+     * IPv6.</p>
+     */
+    inline void SetIpAddressType(const IpAddressType& value) { m_ipAddressTypeHasBeenSet = true; m_ipAddressType = value; }
+
+    /**
+     * <p>The IP address type of the instance.</p> <p>The possible values are
+     * <code>ipv4</code> for IPv4 only, and <code>dualstack</code> for IPv4 and
+     * IPv6.</p>
+     */
+    inline void SetIpAddressType(IpAddressType&& value) { m_ipAddressTypeHasBeenSet = true; m_ipAddressType = std::move(value); }
+
+    /**
+     * <p>The IP address type of the instance.</p> <p>The possible values are
+     * <code>ipv4</code> for IPv4 only, and <code>dualstack</code> for IPv4 and
+     * IPv6.</p>
+     */
+    inline Instance& WithIpAddressType(const IpAddressType& value) { SetIpAddressType(value); return *this;}
+
+    /**
+     * <p>The IP address type of the instance.</p> <p>The possible values are
+     * <code>ipv4</code> for IPv4 only, and <code>dualstack</code> for IPv4 and
+     * IPv6.</p>
+     */
+    inline Instance& WithIpAddressType(IpAddressType&& value) { SetIpAddressType(std::move(value)); return *this;}
 
 
     /**
@@ -934,8 +973,11 @@ namespace Model
     Aws::String m_publicIpAddress;
     bool m_publicIpAddressHasBeenSet;
 
-    Aws::String m_ipv6Address;
-    bool m_ipv6AddressHasBeenSet;
+    Aws::Vector<Aws::String> m_ipv6Addresses;
+    bool m_ipv6AddressesHasBeenSet;
+
+    IpAddressType m_ipAddressType;
+    bool m_ipAddressTypeHasBeenSet;
 
     InstanceHardware m_hardware;
     bool m_hardwareHasBeenSet;
