@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/mediaconnect/MediaConnect_EXPORTS.h>
@@ -19,6 +9,7 @@
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/mediaconnect/model/Encryption.h>
 #include <aws/mediaconnect/model/Protocol.h>
+#include <aws/mediaconnect/model/VpcInterfaceAttachment.h>
 #include <utility>
 
 namespace Aws
@@ -262,6 +253,43 @@ namespace Model
     inline AddOutputRequest& WithMaxLatency(int value) { SetMaxLatency(value); return *this;}
 
 
+    /**
+     * The minimum latency in milliseconds for SRT-based streams. In streams that use
+     * the SRT protocol, this value that you set on your MediaConnect source or output
+     * represents the minimal potential latency of that connection. The latency of the
+     * stream is set to the highest number between the sender’s minimum latency and the
+     * receiver’s minimum latency.
+     */
+    inline int GetMinLatency() const{ return m_minLatency; }
+
+    /**
+     * The minimum latency in milliseconds for SRT-based streams. In streams that use
+     * the SRT protocol, this value that you set on your MediaConnect source or output
+     * represents the minimal potential latency of that connection. The latency of the
+     * stream is set to the highest number between the sender’s minimum latency and the
+     * receiver’s minimum latency.
+     */
+    inline bool MinLatencyHasBeenSet() const { return m_minLatencyHasBeenSet; }
+
+    /**
+     * The minimum latency in milliseconds for SRT-based streams. In streams that use
+     * the SRT protocol, this value that you set on your MediaConnect source or output
+     * represents the minimal potential latency of that connection. The latency of the
+     * stream is set to the highest number between the sender’s minimum latency and the
+     * receiver’s minimum latency.
+     */
+    inline void SetMinLatency(int value) { m_minLatencyHasBeenSet = true; m_minLatency = value; }
+
+    /**
+     * The minimum latency in milliseconds for SRT-based streams. In streams that use
+     * the SRT protocol, this value that you set on your MediaConnect source or output
+     * represents the minimal potential latency of that connection. The latency of the
+     * stream is set to the highest number between the sender’s minimum latency and the
+     * receiver’s minimum latency.
+     */
+    inline AddOutputRequest& WithMinLatency(int value) { SetMinLatency(value); return *this;}
+
+
     /**
      * The name of the output. This value must be unique within the current flow.
      */
@@ -465,6 +493,37 @@ namespace Model
      */
     inline AddOutputRequest& WithStreamId(const char* value) { SetStreamId(value); return *this;}
 
+
+    /**
+     * The name of the VPC interface attachment to use for this output.
+     */
+    inline const VpcInterfaceAttachment& GetVpcInterfaceAttachment() const{ return m_vpcInterfaceAttachment; }
+
+    /**
+     * The name of the VPC interface attachment to use for this output.
+     */
+    inline bool VpcInterfaceAttachmentHasBeenSet() const { return m_vpcInterfaceAttachmentHasBeenSet; }
+
+    /**
+     * The name of the VPC interface attachment to use for this output.
+     */
+    inline void SetVpcInterfaceAttachment(const VpcInterfaceAttachment& value) { m_vpcInterfaceAttachmentHasBeenSet = true; m_vpcInterfaceAttachment = value; }
+
+    /**
+     * The name of the VPC interface attachment to use for this output.
+     */
+    inline void SetVpcInterfaceAttachment(VpcInterfaceAttachment&& value) { m_vpcInterfaceAttachmentHasBeenSet = true; m_vpcInterfaceAttachment = std::move(value); }
+
+    /**
+     * The name of the VPC interface attachment to use for this output.
+     */
+    inline AddOutputRequest& WithVpcInterfaceAttachment(const VpcInterfaceAttachment& value) { SetVpcInterfaceAttachment(value); return *this;}
+
+    /**
+     * The name of the VPC interface attachment to use for this output.
+     */
+    inline AddOutputRequest& WithVpcInterfaceAttachment(VpcInterfaceAttachment&& value) { SetVpcInterfaceAttachment(std::move(value)); return *this;}
+
   private:
 
     Aws::Vector<Aws::String> m_cidrAllowList;
@@ -482,6 +541,9 @@ namespace Model
     int m_maxLatency;
     bool m_maxLatencyHasBeenSet;
 
+    int m_minLatency;
+    bool m_minLatencyHasBeenSet;
+
     Aws::String m_name;
     bool m_nameHasBeenSet;
 
@@ -499,6 +561,9 @@ namespace Model
 
     Aws::String m_streamId;
     bool m_streamIdHasBeenSet;
+
+    VpcInterfaceAttachment m_vpcInterfaceAttachment;
+    bool m_vpcInterfaceAttachmentHasBeenSet;
   };
 
 } // namespace Model
