@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/mediaconvert/MediaConvert_EXPORTS.h>
@@ -24,6 +14,7 @@
 #include <aws/mediaconvert/model/CmafManifestCompression.h>
 #include <aws/mediaconvert/model/CmafManifestDurationFormat.h>
 #include <aws/mediaconvert/model/CmafMpdProfile.h>
+#include <aws/mediaconvert/model/CmafPtsOffsetHandlingForBFrames.h>
 #include <aws/mediaconvert/model/CmafSegmentControl.h>
 #include <aws/mediaconvert/model/CmafStreamInfResolution.h>
 #include <aws/mediaconvert/model/CmafWriteDASHManifest.h>
@@ -202,38 +193,44 @@ namespace Model
 
 
     /**
-     * When set to ENABLED, sets #EXT-X-ALLOW-CACHE:no tag, which prevents client from
-     * saving media segments for later replay.
+     * Disable this setting only when your workflow requires the #EXT-X-ALLOW-CACHE:no
+     * tag. Otherwise, keep the default value Enabled (ENABLED) and control caching in
+     * your video distribution set up. For example, use the Cache-Control http header.
      */
     inline const CmafClientCache& GetClientCache() const{ return m_clientCache; }
 
     /**
-     * When set to ENABLED, sets #EXT-X-ALLOW-CACHE:no tag, which prevents client from
-     * saving media segments for later replay.
+     * Disable this setting only when your workflow requires the #EXT-X-ALLOW-CACHE:no
+     * tag. Otherwise, keep the default value Enabled (ENABLED) and control caching in
+     * your video distribution set up. For example, use the Cache-Control http header.
      */
     inline bool ClientCacheHasBeenSet() const { return m_clientCacheHasBeenSet; }
 
     /**
-     * When set to ENABLED, sets #EXT-X-ALLOW-CACHE:no tag, which prevents client from
-     * saving media segments for later replay.
+     * Disable this setting only when your workflow requires the #EXT-X-ALLOW-CACHE:no
+     * tag. Otherwise, keep the default value Enabled (ENABLED) and control caching in
+     * your video distribution set up. For example, use the Cache-Control http header.
      */
     inline void SetClientCache(const CmafClientCache& value) { m_clientCacheHasBeenSet = true; m_clientCache = value; }
 
     /**
-     * When set to ENABLED, sets #EXT-X-ALLOW-CACHE:no tag, which prevents client from
-     * saving media segments for later replay.
+     * Disable this setting only when your workflow requires the #EXT-X-ALLOW-CACHE:no
+     * tag. Otherwise, keep the default value Enabled (ENABLED) and control caching in
+     * your video distribution set up. For example, use the Cache-Control http header.
      */
     inline void SetClientCache(CmafClientCache&& value) { m_clientCacheHasBeenSet = true; m_clientCache = std::move(value); }
 
     /**
-     * When set to ENABLED, sets #EXT-X-ALLOW-CACHE:no tag, which prevents client from
-     * saving media segments for later replay.
+     * Disable this setting only when your workflow requires the #EXT-X-ALLOW-CACHE:no
+     * tag. Otherwise, keep the default value Enabled (ENABLED) and control caching in
+     * your video distribution set up. For example, use the Cache-Control http header.
      */
     inline CmafGroupSettings& WithClientCache(const CmafClientCache& value) { SetClientCache(value); return *this;}
 
     /**
-     * When set to ENABLED, sets #EXT-X-ALLOW-CACHE:no tag, which prevents client from
-     * saving media segments for later replay.
+     * Disable this setting only when your workflow requires the #EXT-X-ALLOW-CACHE:no
+     * tag. Otherwise, keep the default value Enabled (ENABLED) and control caching in
+     * your video distribution set up. For example, use the Cache-Control http header.
      */
     inline CmafGroupSettings& WithClientCache(CmafClientCache&& value) { SetClientCache(std::move(value)); return *this;}
 
@@ -678,6 +675,85 @@ namespace Model
     inline CmafGroupSettings& WithMpdProfile(CmafMpdProfile&& value) { SetMpdProfile(std::move(value)); return *this;}
 
 
+    /**
+     * Use this setting only when your output video stream has B-frames, which causes
+     * the initial presentation time stamp (PTS) to be offset from the initial decode
+     * time stamp (DTS). Specify how MediaConvert handles PTS when writing time stamps
+     * in output DASH manifests. Choose Match initial PTS (MATCH_INITIAL_PTS) when you
+     * want MediaConvert to use the initial PTS as the first time stamp in the
+     * manifest. Choose Zero-based (ZERO_BASED) to have MediaConvert ignore the initial
+     * PTS in the video stream and instead write the initial time stamp as zero in the
+     * manifest. For outputs that don't have B-frames, the time stamps in your DASH
+     * manifests start at zero regardless of your choice here.
+     */
+    inline const CmafPtsOffsetHandlingForBFrames& GetPtsOffsetHandlingForBFrames() const{ return m_ptsOffsetHandlingForBFrames; }
+
+    /**
+     * Use this setting only when your output video stream has B-frames, which causes
+     * the initial presentation time stamp (PTS) to be offset from the initial decode
+     * time stamp (DTS). Specify how MediaConvert handles PTS when writing time stamps
+     * in output DASH manifests. Choose Match initial PTS (MATCH_INITIAL_PTS) when you
+     * want MediaConvert to use the initial PTS as the first time stamp in the
+     * manifest. Choose Zero-based (ZERO_BASED) to have MediaConvert ignore the initial
+     * PTS in the video stream and instead write the initial time stamp as zero in the
+     * manifest. For outputs that don't have B-frames, the time stamps in your DASH
+     * manifests start at zero regardless of your choice here.
+     */
+    inline bool PtsOffsetHandlingForBFramesHasBeenSet() const { return m_ptsOffsetHandlingForBFramesHasBeenSet; }
+
+    /**
+     * Use this setting only when your output video stream has B-frames, which causes
+     * the initial presentation time stamp (PTS) to be offset from the initial decode
+     * time stamp (DTS). Specify how MediaConvert handles PTS when writing time stamps
+     * in output DASH manifests. Choose Match initial PTS (MATCH_INITIAL_PTS) when you
+     * want MediaConvert to use the initial PTS as the first time stamp in the
+     * manifest. Choose Zero-based (ZERO_BASED) to have MediaConvert ignore the initial
+     * PTS in the video stream and instead write the initial time stamp as zero in the
+     * manifest. For outputs that don't have B-frames, the time stamps in your DASH
+     * manifests start at zero regardless of your choice here.
+     */
+    inline void SetPtsOffsetHandlingForBFrames(const CmafPtsOffsetHandlingForBFrames& value) { m_ptsOffsetHandlingForBFramesHasBeenSet = true; m_ptsOffsetHandlingForBFrames = value; }
+
+    /**
+     * Use this setting only when your output video stream has B-frames, which causes
+     * the initial presentation time stamp (PTS) to be offset from the initial decode
+     * time stamp (DTS). Specify how MediaConvert handles PTS when writing time stamps
+     * in output DASH manifests. Choose Match initial PTS (MATCH_INITIAL_PTS) when you
+     * want MediaConvert to use the initial PTS as the first time stamp in the
+     * manifest. Choose Zero-based (ZERO_BASED) to have MediaConvert ignore the initial
+     * PTS in the video stream and instead write the initial time stamp as zero in the
+     * manifest. For outputs that don't have B-frames, the time stamps in your DASH
+     * manifests start at zero regardless of your choice here.
+     */
+    inline void SetPtsOffsetHandlingForBFrames(CmafPtsOffsetHandlingForBFrames&& value) { m_ptsOffsetHandlingForBFramesHasBeenSet = true; m_ptsOffsetHandlingForBFrames = std::move(value); }
+
+    /**
+     * Use this setting only when your output video stream has B-frames, which causes
+     * the initial presentation time stamp (PTS) to be offset from the initial decode
+     * time stamp (DTS). Specify how MediaConvert handles PTS when writing time stamps
+     * in output DASH manifests. Choose Match initial PTS (MATCH_INITIAL_PTS) when you
+     * want MediaConvert to use the initial PTS as the first time stamp in the
+     * manifest. Choose Zero-based (ZERO_BASED) to have MediaConvert ignore the initial
+     * PTS in the video stream and instead write the initial time stamp as zero in the
+     * manifest. For outputs that don't have B-frames, the time stamps in your DASH
+     * manifests start at zero regardless of your choice here.
+     */
+    inline CmafGroupSettings& WithPtsOffsetHandlingForBFrames(const CmafPtsOffsetHandlingForBFrames& value) { SetPtsOffsetHandlingForBFrames(value); return *this;}
+
+    /**
+     * Use this setting only when your output video stream has B-frames, which causes
+     * the initial presentation time stamp (PTS) to be offset from the initial decode
+     * time stamp (DTS). Specify how MediaConvert handles PTS when writing time stamps
+     * in output DASH manifests. Choose Match initial PTS (MATCH_INITIAL_PTS) when you
+     * want MediaConvert to use the initial PTS as the first time stamp in the
+     * manifest. Choose Zero-based (ZERO_BASED) to have MediaConvert ignore the initial
+     * PTS in the video stream and instead write the initial time stamp as zero in the
+     * manifest. For outputs that don't have B-frames, the time stamps in your DASH
+     * manifests start at zero regardless of your choice here.
+     */
+    inline CmafGroupSettings& WithPtsOffsetHandlingForBFrames(CmafPtsOffsetHandlingForBFrames&& value) { SetPtsOffsetHandlingForBFrames(std::move(value)); return *this;}
+
+
     /**
      * When set to SINGLE_FILE, a single output file is generated, which is internally
      * segmented using the Fragment Length and Segment Length. When set to
@@ -976,6 +1052,9 @@ namespace Model
     CmafMpdProfile m_mpdProfile;
     bool m_mpdProfileHasBeenSet;
 
+    CmafPtsOffsetHandlingForBFrames m_ptsOffsetHandlingForBFrames;
+    bool m_ptsOffsetHandlingForBFramesHasBeenSet;
+
     CmafSegmentControl m_segmentControl;
     bool m_segmentControlHasBeenSet;
 
