@@ -1,20 +1,11 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/mediaconvert/MediaConvert_EXPORTS.h>
+#include <aws/mediaconvert/model/M3u8AudioDuration.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/mediaconvert/model/M3u8NielsenId3.h>
 #include <aws/mediaconvert/model/M3u8PcrControl.h>
@@ -51,6 +42,109 @@ namespace Model
     Aws::Utils::Json::JsonValue Jsonize() const;
 
 
+    /**
+     * Specify this setting only when your output will be consumed by a downstream
+     * repackaging workflow that is sensitive to very small duration differences
+     * between video and audio. For this situation, choose Match video duration
+     * (MATCH_VIDEO_DURATION). In all other cases, keep the default value, Default
+     * codec duration (DEFAULT_CODEC_DURATION). When you choose Match video duration,
+     * MediaConvert pads the output audio streams with silence or trims them to ensure
+     * that the total duration of each audio stream is at least as long as the total
+     * duration of the video stream. After padding or trimming, the audio stream
+     * duration is no more than one frame longer than the video stream. MediaConvert
+     * applies audio padding or trimming only to the end of the last segment of the
+     * output. For unsegmented outputs, MediaConvert adds padding only to the end of
+     * the file. When you keep the default value, any minor discrepancies between audio
+     * and video duration will depend on your output audio codec.
+     */
+    inline const M3u8AudioDuration& GetAudioDuration() const{ return m_audioDuration; }
+
+    /**
+     * Specify this setting only when your output will be consumed by a downstream
+     * repackaging workflow that is sensitive to very small duration differences
+     * between video and audio. For this situation, choose Match video duration
+     * (MATCH_VIDEO_DURATION). In all other cases, keep the default value, Default
+     * codec duration (DEFAULT_CODEC_DURATION). When you choose Match video duration,
+     * MediaConvert pads the output audio streams with silence or trims them to ensure
+     * that the total duration of each audio stream is at least as long as the total
+     * duration of the video stream. After padding or trimming, the audio stream
+     * duration is no more than one frame longer than the video stream. MediaConvert
+     * applies audio padding or trimming only to the end of the last segment of the
+     * output. For unsegmented outputs, MediaConvert adds padding only to the end of
+     * the file. When you keep the default value, any minor discrepancies between audio
+     * and video duration will depend on your output audio codec.
+     */
+    inline bool AudioDurationHasBeenSet() const { return m_audioDurationHasBeenSet; }
+
+    /**
+     * Specify this setting only when your output will be consumed by a downstream
+     * repackaging workflow that is sensitive to very small duration differences
+     * between video and audio. For this situation, choose Match video duration
+     * (MATCH_VIDEO_DURATION). In all other cases, keep the default value, Default
+     * codec duration (DEFAULT_CODEC_DURATION). When you choose Match video duration,
+     * MediaConvert pads the output audio streams with silence or trims them to ensure
+     * that the total duration of each audio stream is at least as long as the total
+     * duration of the video stream. After padding or trimming, the audio stream
+     * duration is no more than one frame longer than the video stream. MediaConvert
+     * applies audio padding or trimming only to the end of the last segment of the
+     * output. For unsegmented outputs, MediaConvert adds padding only to the end of
+     * the file. When you keep the default value, any minor discrepancies between audio
+     * and video duration will depend on your output audio codec.
+     */
+    inline void SetAudioDuration(const M3u8AudioDuration& value) { m_audioDurationHasBeenSet = true; m_audioDuration = value; }
+
+    /**
+     * Specify this setting only when your output will be consumed by a downstream
+     * repackaging workflow that is sensitive to very small duration differences
+     * between video and audio. For this situation, choose Match video duration
+     * (MATCH_VIDEO_DURATION). In all other cases, keep the default value, Default
+     * codec duration (DEFAULT_CODEC_DURATION). When you choose Match video duration,
+     * MediaConvert pads the output audio streams with silence or trims them to ensure
+     * that the total duration of each audio stream is at least as long as the total
+     * duration of the video stream. After padding or trimming, the audio stream
+     * duration is no more than one frame longer than the video stream. MediaConvert
+     * applies audio padding or trimming only to the end of the last segment of the
+     * output. For unsegmented outputs, MediaConvert adds padding only to the end of
+     * the file. When you keep the default value, any minor discrepancies between audio
+     * and video duration will depend on your output audio codec.
+     */
+    inline void SetAudioDuration(M3u8AudioDuration&& value) { m_audioDurationHasBeenSet = true; m_audioDuration = std::move(value); }
+
+    /**
+     * Specify this setting only when your output will be consumed by a downstream
+     * repackaging workflow that is sensitive to very small duration differences
+     * between video and audio. For this situation, choose Match video duration
+     * (MATCH_VIDEO_DURATION). In all other cases, keep the default value, Default
+     * codec duration (DEFAULT_CODEC_DURATION). When you choose Match video duration,
+     * MediaConvert pads the output audio streams with silence or trims them to ensure
+     * that the total duration of each audio stream is at least as long as the total
+     * duration of the video stream. After padding or trimming, the audio stream
+     * duration is no more than one frame longer than the video stream. MediaConvert
+     * applies audio padding or trimming only to the end of the last segment of the
+     * output. For unsegmented outputs, MediaConvert adds padding only to the end of
+     * the file. When you keep the default value, any minor discrepancies between audio
+     * and video duration will depend on your output audio codec.
+     */
+    inline M3u8Settings& WithAudioDuration(const M3u8AudioDuration& value) { SetAudioDuration(value); return *this;}
+
+    /**
+     * Specify this setting only when your output will be consumed by a downstream
+     * repackaging workflow that is sensitive to very small duration differences
+     * between video and audio. For this situation, choose Match video duration
+     * (MATCH_VIDEO_DURATION). In all other cases, keep the default value, Default
+     * codec duration (DEFAULT_CODEC_DURATION). When you choose Match video duration,
+     * MediaConvert pads the output audio streams with silence or trims them to ensure
+     * that the total duration of each audio stream is at least as long as the total
+     * duration of the video stream. After padding or trimming, the audio stream
+     * duration is no more than one frame longer than the video stream. MediaConvert
+     * applies audio padding or trimming only to the end of the last segment of the
+     * output. For unsegmented outputs, MediaConvert adds padding only to the end of
+     * the file. When you keep the default value, any minor discrepancies between audio
+     * and video duration will depend on your output audio codec.
+     */
+    inline M3u8Settings& WithAudioDuration(M3u8AudioDuration&& value) { SetAudioDuration(std::move(value)); return *this;}
+
+
     /**
      * The number of audio frames to insert for each PES packet.
      */
@@ -539,6 +633,9 @@ namespace Model
 
   private:
 
+    M3u8AudioDuration m_audioDuration;
+    bool m_audioDurationHasBeenSet;
+
     int m_audioFramesPerPes;
     bool m_audioFramesPerPesHasBeenSet;
 
