@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/neptune/Neptune_EXPORTS.h>
@@ -163,50 +153,42 @@ namespace Model
 
 
     /**
-     * <p>If present, specifies the name of the character set that this cluster is
-     * associated with.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline const Aws::String& GetCharacterSetName() const{ return m_characterSetName; }
 
     /**
-     * <p>If present, specifies the name of the character set that this cluster is
-     * associated with.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline bool CharacterSetNameHasBeenSet() const { return m_characterSetNameHasBeenSet; }
 
     /**
-     * <p>If present, specifies the name of the character set that this cluster is
-     * associated with.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline void SetCharacterSetName(const Aws::String& value) { m_characterSetNameHasBeenSet = true; m_characterSetName = value; }
 
     /**
-     * <p>If present, specifies the name of the character set that this cluster is
-     * associated with.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline void SetCharacterSetName(Aws::String&& value) { m_characterSetNameHasBeenSet = true; m_characterSetName = std::move(value); }
 
     /**
-     * <p>If present, specifies the name of the character set that this cluster is
-     * associated with.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline void SetCharacterSetName(const char* value) { m_characterSetNameHasBeenSet = true; m_characterSetName.assign(value); }
 
     /**
-     * <p>If present, specifies the name of the character set that this cluster is
-     * associated with.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline DBCluster& WithCharacterSetName(const Aws::String& value) { SetCharacterSetName(value); return *this;}
 
     /**
-     * <p>If present, specifies the name of the character set that this cluster is
-     * associated with.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline DBCluster& WithCharacterSetName(Aws::String&& value) { SetCharacterSetName(std::move(value)); return *this;}
 
     /**
-     * <p>If present, specifies the name of the character set that this cluster is
-     * associated with.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline DBCluster& WithCharacterSetName(const char* value) { SetCharacterSetName(value); return *this;}
 
@@ -887,42 +869,42 @@ namespace Model
 
 
     /**
-     * <p>Provides the list of option group memberships for this DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline const Aws::Vector<DBClusterOptionGroupStatus>& GetDBClusterOptionGroupMemberships() const{ return m_dBClusterOptionGroupMemberships; }
 
     /**
-     * <p>Provides the list of option group memberships for this DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline bool DBClusterOptionGroupMembershipsHasBeenSet() const { return m_dBClusterOptionGroupMembershipsHasBeenSet; }
 
     /**
-     * <p>Provides the list of option group memberships for this DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline void SetDBClusterOptionGroupMemberships(const Aws::Vector<DBClusterOptionGroupStatus>& value) { m_dBClusterOptionGroupMembershipsHasBeenSet = true; m_dBClusterOptionGroupMemberships = value; }
 
     /**
-     * <p>Provides the list of option group memberships for this DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline void SetDBClusterOptionGroupMemberships(Aws::Vector<DBClusterOptionGroupStatus>&& value) { m_dBClusterOptionGroupMembershipsHasBeenSet = true; m_dBClusterOptionGroupMemberships = std::move(value); }
 
     /**
-     * <p>Provides the list of option group memberships for this DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline DBCluster& WithDBClusterOptionGroupMemberships(const Aws::Vector<DBClusterOptionGroupStatus>& value) { SetDBClusterOptionGroupMemberships(value); return *this;}
 
     /**
-     * <p>Provides the list of option group memberships for this DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline DBCluster& WithDBClusterOptionGroupMemberships(Aws::Vector<DBClusterOptionGroupStatus>&& value) { SetDBClusterOptionGroupMemberships(std::move(value)); return *this;}
 
     /**
-     * <p>Provides the list of option group memberships for this DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline DBCluster& AddDBClusterOptionGroupMemberships(const DBClusterOptionGroupStatus& value) { m_dBClusterOptionGroupMembershipsHasBeenSet = true; m_dBClusterOptionGroupMemberships.push_back(value); return *this; }
 
     /**
-     * <p>Provides the list of option group memberships for this DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline DBCluster& AddDBClusterOptionGroupMemberships(DBClusterOptionGroupStatus&& value) { m_dBClusterOptionGroupMembershipsHasBeenSet = true; m_dBClusterOptionGroupMemberships.push_back(std::move(value)); return *this; }
 
@@ -1650,6 +1632,31 @@ namespace Model
      */
     inline DBCluster& AddEnabledCloudwatchLogsExports(const char* value) { m_enabledCloudwatchLogsExportsHasBeenSet = true; m_enabledCloudwatchLogsExports.push_back(value); return *this; }
 
+
+    /**
+     * <p>Indicates whether or not the DB cluster has deletion protection enabled. The
+     * database can't be deleted when deletion protection is enabled.</p>
+     */
+    inline bool GetDeletionProtection() const{ return m_deletionProtection; }
+
+    /**
+     * <p>Indicates whether or not the DB cluster has deletion protection enabled. The
+     * database can't be deleted when deletion protection is enabled.</p>
+     */
+    inline bool DeletionProtectionHasBeenSet() const { return m_deletionProtectionHasBeenSet; }
+
+    /**
+     * <p>Indicates whether or not the DB cluster has deletion protection enabled. The
+     * database can't be deleted when deletion protection is enabled.</p>
+     */
+    inline void SetDeletionProtection(bool value) { m_deletionProtectionHasBeenSet = true; m_deletionProtection = value; }
+
+    /**
+     * <p>Indicates whether or not the DB cluster has deletion protection enabled. The
+     * database can't be deleted when deletion protection is enabled.</p>
+     */
+    inline DBCluster& WithDeletionProtection(bool value) { SetDeletionProtection(value); return *this;}
+
   private:
 
     int m_allocatedStorage;
@@ -1759,6 +1766,9 @@ namespace Model
 
     Aws::Vector<Aws::String> m_enabledCloudwatchLogsExports;
     bool m_enabledCloudwatchLogsExportsHasBeenSet;
+
+    bool m_deletionProtection;
+    bool m_deletionProtectionHasBeenSet;
   };
 
 } // namespace Model
