@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/quicksight/QuickSight_EXPORTS.h>
@@ -24,7 +14,9 @@
 #include <aws/quicksight/model/PhysicalTable.h>
 #include <aws/quicksight/model/LogicalTable.h>
 #include <aws/quicksight/model/ColumnGroup.h>
+#include <aws/quicksight/model/FieldFolder.h>
 #include <aws/quicksight/model/ResourcePermission.h>
+#include <aws/quicksight/model/ColumnLevelPermissionRule.h>
 #include <aws/quicksight/model/Tag.h>
 #include <utility>
 
@@ -408,6 +400,67 @@ namespace Model
     inline CreateDataSetRequest& AddColumnGroups(ColumnGroup&& value) { m_columnGroupsHasBeenSet = true; m_columnGroups.push_back(std::move(value)); return *this; }
 
 
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline const Aws::Map<Aws::String, FieldFolder>& GetFieldFolders() const{ return m_fieldFolders; }
+
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline bool FieldFoldersHasBeenSet() const { return m_fieldFoldersHasBeenSet; }
+
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline void SetFieldFolders(const Aws::Map<Aws::String, FieldFolder>& value) { m_fieldFoldersHasBeenSet = true; m_fieldFolders = value; }
+
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline void SetFieldFolders(Aws::Map<Aws::String, FieldFolder>&& value) { m_fieldFoldersHasBeenSet = true; m_fieldFolders = std::move(value); }
+
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline CreateDataSetRequest& WithFieldFolders(const Aws::Map<Aws::String, FieldFolder>& value) { SetFieldFolders(value); return *this;}
+
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline CreateDataSetRequest& WithFieldFolders(Aws::Map<Aws::String, FieldFolder>&& value) { SetFieldFolders(std::move(value)); return *this;}
+
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline CreateDataSetRequest& AddFieldFolders(const Aws::String& key, const FieldFolder& value) { m_fieldFoldersHasBeenSet = true; m_fieldFolders.emplace(key, value); return *this; }
+
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline CreateDataSetRequest& AddFieldFolders(Aws::String&& key, const FieldFolder& value) { m_fieldFoldersHasBeenSet = true; m_fieldFolders.emplace(std::move(key), value); return *this; }
+
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline CreateDataSetRequest& AddFieldFolders(const Aws::String& key, FieldFolder&& value) { m_fieldFoldersHasBeenSet = true; m_fieldFolders.emplace(key, std::move(value)); return *this; }
+
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline CreateDataSetRequest& AddFieldFolders(Aws::String&& key, FieldFolder&& value) { m_fieldFoldersHasBeenSet = true; m_fieldFolders.emplace(std::move(key), std::move(value)); return *this; }
+
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline CreateDataSetRequest& AddFieldFolders(const char* key, FieldFolder&& value) { m_fieldFoldersHasBeenSet = true; m_fieldFolders.emplace(key, std::move(value)); return *this; }
+
+    /**
+     * <p>The folder that contains fields and nested subfolders for your dataset.</p>
+     */
+    inline CreateDataSetRequest& AddFieldFolders(const char* key, const FieldFolder& value) { m_fieldFoldersHasBeenSet = true; m_fieldFolders.emplace(key, value); return *this; }
+
+
     /**
      * <p>A list of resource permissions on the dataset.</p>
      */
@@ -486,6 +539,55 @@ namespace Model
     inline CreateDataSetRequest& WithRowLevelPermissionDataSet(RowLevelPermissionDataSet&& value) { SetRowLevelPermissionDataSet(std::move(value)); return *this;}
 
 
+    /**
+     * <p>A set of one or more definitions of a <code> <a>ColumnLevelPermissionRule</a>
+     * </code>.</p>
+     */
+    inline const Aws::Vector<ColumnLevelPermissionRule>& GetColumnLevelPermissionRules() const{ return m_columnLevelPermissionRules; }
+
+    /**
+     * <p>A set of one or more definitions of a <code> <a>ColumnLevelPermissionRule</a>
+     * </code>.</p>
+     */
+    inline bool ColumnLevelPermissionRulesHasBeenSet() const { return m_columnLevelPermissionRulesHasBeenSet; }
+
+    /**
+     * <p>A set of one or more definitions of a <code> <a>ColumnLevelPermissionRule</a>
+     * </code>.</p>
+     */
+    inline void SetColumnLevelPermissionRules(const Aws::Vector<ColumnLevelPermissionRule>& value) { m_columnLevelPermissionRulesHasBeenSet = true; m_columnLevelPermissionRules = value; }
+
+    /**
+     * <p>A set of one or more definitions of a <code> <a>ColumnLevelPermissionRule</a>
+     * </code>.</p>
+     */
+    inline void SetColumnLevelPermissionRules(Aws::Vector<ColumnLevelPermissionRule>&& value) { m_columnLevelPermissionRulesHasBeenSet = true; m_columnLevelPermissionRules = std::move(value); }
+
+    /**
+     * <p>A set of one or more definitions of a <code> <a>ColumnLevelPermissionRule</a>
+     * </code>.</p>
+     */
+    inline CreateDataSetRequest& WithColumnLevelPermissionRules(const Aws::Vector<ColumnLevelPermissionRule>& value) { SetColumnLevelPermissionRules(value); return *this;}
+
+    /**
+     * <p>A set of one or more definitions of a <code> <a>ColumnLevelPermissionRule</a>
+     * </code>.</p>
+     */
+    inline CreateDataSetRequest& WithColumnLevelPermissionRules(Aws::Vector<ColumnLevelPermissionRule>&& value) { SetColumnLevelPermissionRules(std::move(value)); return *this;}
+
+    /**
+     * <p>A set of one or more definitions of a <code> <a>ColumnLevelPermissionRule</a>
+     * </code>.</p>
+     */
+    inline CreateDataSetRequest& AddColumnLevelPermissionRules(const ColumnLevelPermissionRule& value) { m_columnLevelPermissionRulesHasBeenSet = true; m_columnLevelPermissionRules.push_back(value); return *this; }
+
+    /**
+     * <p>A set of one or more definitions of a <code> <a>ColumnLevelPermissionRule</a>
+     * </code>.</p>
+     */
+    inline CreateDataSetRequest& AddColumnLevelPermissionRules(ColumnLevelPermissionRule&& value) { m_columnLevelPermissionRulesHasBeenSet = true; m_columnLevelPermissionRules.push_back(std::move(value)); return *this; }
+
+
     /**
      * <p>Contains a map of the key-value pairs for the resource tag or tags assigned
      * to the dataset.</p>
@@ -557,12 +659,18 @@ namespace Model
     Aws::Vector<ColumnGroup> m_columnGroups;
     bool m_columnGroupsHasBeenSet;
 
+    Aws::Map<Aws::String, FieldFolder> m_fieldFolders;
+    bool m_fieldFoldersHasBeenSet;
+
     Aws::Vector<ResourcePermission> m_permissions;
     bool m_permissionsHasBeenSet;
 
     RowLevelPermissionDataSet m_rowLevelPermissionDataSet;
     bool m_rowLevelPermissionDataSetHasBeenSet;
 
+    Aws::Vector<ColumnLevelPermissionRule> m_columnLevelPermissionRules;
+    bool m_columnLevelPermissionRulesHasBeenSet;
+
     Aws::Vector<Tag> m_tags;
     bool m_tagsHasBeenSet;
   };
