@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/sagemaker/SageMaker_EXPORTS.h>
@@ -27,9 +17,15 @@
 #include <aws/sagemaker/model/VpcConfig.h>
 #include <aws/sagemaker/model/StoppingCondition.h>
 #include <aws/core/utils/DateTime.h>
+#include <aws/sagemaker/model/CheckpointConfig.h>
+#include <aws/sagemaker/model/DebugHookConfig.h>
+#include <aws/sagemaker/model/ExperimentConfig.h>
+#include <aws/sagemaker/model/TensorBoardOutputConfig.h>
 #include <aws/sagemaker/model/Channel.h>
 #include <aws/sagemaker/model/SecondaryStatusTransition.h>
 #include <aws/sagemaker/model/MetricData.h>
+#include <aws/sagemaker/model/DebugRuleConfiguration.h>
+#include <aws/sagemaker/model/DebugRuleEvaluationStatus.h>
 #include <aws/sagemaker/model/Tag.h>
 #include <utility>
 
@@ -234,6 +230,47 @@ namespace Model
     inline TrainingJob& WithLabelingJobArn(const char* value) { SetLabelingJobArn(value); return *this;}
 
 
+    /**
+     * <p>The Amazon Resource Name (ARN) of the job.</p>
+     */
+    inline const Aws::String& GetAutoMLJobArn() const{ return m_autoMLJobArn; }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the job.</p>
+     */
+    inline bool AutoMLJobArnHasBeenSet() const { return m_autoMLJobArnHasBeenSet; }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the job.</p>
+     */
+    inline void SetAutoMLJobArn(const Aws::String& value) { m_autoMLJobArnHasBeenSet = true; m_autoMLJobArn = value; }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the job.</p>
+     */
+    inline void SetAutoMLJobArn(Aws::String&& value) { m_autoMLJobArnHasBeenSet = true; m_autoMLJobArn = std::move(value); }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the job.</p>
+     */
+    inline void SetAutoMLJobArn(const char* value) { m_autoMLJobArnHasBeenSet = true; m_autoMLJobArn.assign(value); }
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the job.</p>
+     */
+    inline TrainingJob& WithAutoMLJobArn(const Aws::String& value) { SetAutoMLJobArn(value); return *this;}
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the job.</p>
+     */
+    inline TrainingJob& WithAutoMLJobArn(Aws::String&& value) { SetAutoMLJobArn(std::move(value)); return *this;}
+
+    /**
+     * <p>The Amazon Resource Name (ARN) of the job.</p>
+     */
+    inline TrainingJob& WithAutoMLJobArn(const char* value) { SetAutoMLJobArn(value); return *this;}
+
+
     /**
      * <p>Information about the Amazon S3 location that is configured for storing model
      * artifacts.</p>
@@ -371,8 +408,8 @@ namespace Model
      * exceeded the maximum allowed runtime.</p> </li> <li> <p> <code>Stopped</code> -
      * The training job has stopped.</p> </li> </ul> </dd> <dt>Stopping</dt> <dd> <ul>
      * <li> <p> <code>Stopping</code> - Stopping the training job.</p> </li> </ul>
-     * </dd> </dl> <important> <p>Valid values for <code>SecondaryStatus</code> are
-     * subject to change. </p> </important> <p>We no longer support the following
+     * </dd> </dl>  <p>Valid values for <code>SecondaryStatus</code> are
+     * subject to change. </p>  <p>We no longer support the following
      * secondary statuses:</p> <ul> <li> <p> <code>LaunchingMLInstances</code> </p>
      * </li> <li> <p> <code>PreparingTrainingStack</code> </p> </li> <li> <p>
      * <code>DownloadingTrainingImage</code> </p> </li> </ul>
@@ -400,8 +437,8 @@ namespace Model
      * exceeded the maximum allowed runtime.</p> </li> <li> <p> <code>Stopped</code> -
      * The training job has stopped.</p> </li> </ul> </dd> <dt>Stopping</dt> <dd> <ul>
      * <li> <p> <code>Stopping</code> - Stopping the training job.</p> </li> </ul>
-     * </dd> </dl> <important> <p>Valid values for <code>SecondaryStatus</code> are
-     * subject to change. </p> </important> <p>We no longer support the following
+     * </dd> </dl>  <p>Valid values for <code>SecondaryStatus</code> are
+     * subject to change. </p>  <p>We no longer support the following
      * secondary statuses:</p> <ul> <li> <p> <code>LaunchingMLInstances</code> </p>
      * </li> <li> <p> <code>PreparingTrainingStack</code> </p> </li> <li> <p>
      * <code>DownloadingTrainingImage</code> </p> </li> </ul>
@@ -429,8 +466,8 @@ namespace Model
      * exceeded the maximum allowed runtime.</p> </li> <li> <p> <code>Stopped</code> -
      * The training job has stopped.</p> </li> </ul> </dd> <dt>Stopping</dt> <dd> <ul>
      * <li> <p> <code>Stopping</code> - Stopping the training job.</p> </li> </ul>
-     * </dd> </dl> <important> <p>Valid values for <code>SecondaryStatus</code> are
-     * subject to change. </p> </important> <p>We no longer support the following
+     * </dd> </dl>  <p>Valid values for <code>SecondaryStatus</code> are
+     * subject to change. </p>  <p>We no longer support the following
      * secondary statuses:</p> <ul> <li> <p> <code>LaunchingMLInstances</code> </p>
      * </li> <li> <p> <code>PreparingTrainingStack</code> </p> </li> <li> <p>
      * <code>DownloadingTrainingImage</code> </p> </li> </ul>
@@ -458,8 +495,8 @@ namespace Model
      * exceeded the maximum allowed runtime.</p> </li> <li> <p> <code>Stopped</code> -
      * The training job has stopped.</p> </li> </ul> </dd> <dt>Stopping</dt> <dd> <ul>
      * <li> <p> <code>Stopping</code> - Stopping the training job.</p> </li> </ul>
-     * </dd> </dl> <important> <p>Valid values for <code>SecondaryStatus</code> are
-     * subject to change. </p> </important> <p>We no longer support the following
+     * </dd> </dl>  <p>Valid values for <code>SecondaryStatus</code> are
+     * subject to change. </p>  <p>We no longer support the following
      * secondary statuses:</p> <ul> <li> <p> <code>LaunchingMLInstances</code> </p>
      * </li> <li> <p> <code>PreparingTrainingStack</code> </p> </li> <li> <p>
      * <code>DownloadingTrainingImage</code> </p> </li> </ul>
@@ -487,8 +524,8 @@ namespace Model
      * exceeded the maximum allowed runtime.</p> </li> <li> <p> <code>Stopped</code> -
      * The training job has stopped.</p> </li> </ul> </dd> <dt>Stopping</dt> <dd> <ul>
      * <li> <p> <code>Stopping</code> - Stopping the training job.</p> </li> </ul>
-     * </dd> </dl> <important> <p>Valid values for <code>SecondaryStatus</code> are
-     * subject to change. </p> </important> <p>We no longer support the following
+     * </dd> </dl>  <p>Valid values for <code>SecondaryStatus</code> are
+     * subject to change. </p>  <p>We no longer support the following
      * secondary statuses:</p> <ul> <li> <p> <code>LaunchingMLInstances</code> </p>
      * </li> <li> <p> <code>PreparingTrainingStack</code> </p> </li> <li> <p>
      * <code>DownloadingTrainingImage</code> </p> </li> </ul>
@@ -516,8 +553,8 @@ namespace Model
      * exceeded the maximum allowed runtime.</p> </li> <li> <p> <code>Stopped</code> -
      * The training job has stopped.</p> </li> </ul> </dd> <dt>Stopping</dt> <dd> <ul>
      * <li> <p> <code>Stopping</code> - Stopping the training job.</p> </li> </ul>
-     * </dd> </dl> <important> <p>Valid values for <code>SecondaryStatus</code> are
-     * subject to change. </p> </important> <p>We no longer support the following
+     * </dd> </dl>  <p>Valid values for <code>SecondaryStatus</code> are
+     * subject to change. </p>  <p>We no longer support the following
      * secondary statuses:</p> <ul> <li> <p> <code>LaunchingMLInstances</code> </p>
      * </li> <li> <p> <code>PreparingTrainingStack</code> </p> </li> <li> <p>
      * <code>DownloadingTrainingImage</code> </p> </li> </ul>
@@ -1294,66 +1331,381 @@ namespace Model
 
 
     /**
-     * <p>An array of key-value pairs. For more information, see <a
-     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what">Using
-     * Cost Allocation Tags</a> in the <i>AWS Billing and Cost Management User
-     * Guide</i>.</p>
+     * <p>When true, enables managed spot training using Amazon EC2 Spot instances to
+     * run training jobs instead of on-demand instances. For more information, see <a
+     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/model-managed-spot-training.html">Managed
+     * Spot Training</a>.</p>
+     */
+    inline bool GetEnableManagedSpotTraining() const{ return m_enableManagedSpotTraining; }
+
+    /**
+     * <p>When true, enables managed spot training using Amazon EC2 Spot instances to
+     * run training jobs instead of on-demand instances. For more information, see <a
+     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/model-managed-spot-training.html">Managed
+     * Spot Training</a>.</p>
+     */
+    inline bool EnableManagedSpotTrainingHasBeenSet() const { return m_enableManagedSpotTrainingHasBeenSet; }
+
+    /**
+     * <p>When true, enables managed spot training using Amazon EC2 Spot instances to
+     * run training jobs instead of on-demand instances. For more information, see <a
+     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/model-managed-spot-training.html">Managed
+     * Spot Training</a>.</p>
+     */
+    inline void SetEnableManagedSpotTraining(bool value) { m_enableManagedSpotTrainingHasBeenSet = true; m_enableManagedSpotTraining = value; }
+
+    /**
+     * <p>When true, enables managed spot training using Amazon EC2 Spot instances to
+     * run training jobs instead of on-demand instances. For more information, see <a
+     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/model-managed-spot-training.html">Managed
+     * Spot Training</a>.</p>
+     */
+    inline TrainingJob& WithEnableManagedSpotTraining(bool value) { SetEnableManagedSpotTraining(value); return *this;}
+
+
+    
+    inline const CheckpointConfig& GetCheckpointConfig() const{ return m_checkpointConfig; }
+
+    
+    inline bool CheckpointConfigHasBeenSet() const { return m_checkpointConfigHasBeenSet; }
+
+    
+    inline void SetCheckpointConfig(const CheckpointConfig& value) { m_checkpointConfigHasBeenSet = true; m_checkpointConfig = value; }
+
+    
+    inline void SetCheckpointConfig(CheckpointConfig&& value) { m_checkpointConfigHasBeenSet = true; m_checkpointConfig = std::move(value); }
+
+    
+    inline TrainingJob& WithCheckpointConfig(const CheckpointConfig& value) { SetCheckpointConfig(value); return *this;}
+
+    
+    inline TrainingJob& WithCheckpointConfig(CheckpointConfig&& value) { SetCheckpointConfig(std::move(value)); return *this;}
+
+
+    /**
+     * <p>The training time in seconds.</p>
+     */
+    inline int GetTrainingTimeInSeconds() const{ return m_trainingTimeInSeconds; }
+
+    /**
+     * <p>The training time in seconds.</p>
+     */
+    inline bool TrainingTimeInSecondsHasBeenSet() const { return m_trainingTimeInSecondsHasBeenSet; }
+
+    /**
+     * <p>The training time in seconds.</p>
+     */
+    inline void SetTrainingTimeInSeconds(int value) { m_trainingTimeInSecondsHasBeenSet = true; m_trainingTimeInSeconds = value; }
+
+    /**
+     * <p>The training time in seconds.</p>
+     */
+    inline TrainingJob& WithTrainingTimeInSeconds(int value) { SetTrainingTimeInSeconds(value); return *this;}
+
+
+    /**
+     * <p>The billable time in seconds.</p>
+     */
+    inline int GetBillableTimeInSeconds() const{ return m_billableTimeInSeconds; }
+
+    /**
+     * <p>The billable time in seconds.</p>
+     */
+    inline bool BillableTimeInSecondsHasBeenSet() const { return m_billableTimeInSecondsHasBeenSet; }
+
+    /**
+     * <p>The billable time in seconds.</p>
+     */
+    inline void SetBillableTimeInSeconds(int value) { m_billableTimeInSecondsHasBeenSet = true; m_billableTimeInSeconds = value; }
+
+    /**
+     * <p>The billable time in seconds.</p>
+     */
+    inline TrainingJob& WithBillableTimeInSeconds(int value) { SetBillableTimeInSeconds(value); return *this;}
+
+
+    
+    inline const DebugHookConfig& GetDebugHookConfig() const{ return m_debugHookConfig; }
+
+    
+    inline bool DebugHookConfigHasBeenSet() const { return m_debugHookConfigHasBeenSet; }
+
+    
+    inline void SetDebugHookConfig(const DebugHookConfig& value) { m_debugHookConfigHasBeenSet = true; m_debugHookConfig = value; }
+
+    
+    inline void SetDebugHookConfig(DebugHookConfig&& value) { m_debugHookConfigHasBeenSet = true; m_debugHookConfig = std::move(value); }
+
+    
+    inline TrainingJob& WithDebugHookConfig(const DebugHookConfig& value) { SetDebugHookConfig(value); return *this;}
+
+    
+    inline TrainingJob& WithDebugHookConfig(DebugHookConfig&& value) { SetDebugHookConfig(std::move(value)); return *this;}
+
+
+    
+    inline const ExperimentConfig& GetExperimentConfig() const{ return m_experimentConfig; }
+
+    
+    inline bool ExperimentConfigHasBeenSet() const { return m_experimentConfigHasBeenSet; }
+
+    
+    inline void SetExperimentConfig(const ExperimentConfig& value) { m_experimentConfigHasBeenSet = true; m_experimentConfig = value; }
+
+    
+    inline void SetExperimentConfig(ExperimentConfig&& value) { m_experimentConfigHasBeenSet = true; m_experimentConfig = std::move(value); }
+
+    
+    inline TrainingJob& WithExperimentConfig(const ExperimentConfig& value) { SetExperimentConfig(value); return *this;}
+
+    
+    inline TrainingJob& WithExperimentConfig(ExperimentConfig&& value) { SetExperimentConfig(std::move(value)); return *this;}
+
+
+    /**
+     * <p>Information about the debug rule configuration.</p>
+     */
+    inline const Aws::Vector<DebugRuleConfiguration>& GetDebugRuleConfigurations() const{ return m_debugRuleConfigurations; }
+
+    /**
+     * <p>Information about the debug rule configuration.</p>
+     */
+    inline bool DebugRuleConfigurationsHasBeenSet() const { return m_debugRuleConfigurationsHasBeenSet; }
+
+    /**
+     * <p>Information about the debug rule configuration.</p>
+     */
+    inline void SetDebugRuleConfigurations(const Aws::Vector<DebugRuleConfiguration>& value) { m_debugRuleConfigurationsHasBeenSet = true; m_debugRuleConfigurations = value; }
+
+    /**
+     * <p>Information about the debug rule configuration.</p>
+     */
+    inline void SetDebugRuleConfigurations(Aws::Vector<DebugRuleConfiguration>&& value) { m_debugRuleConfigurationsHasBeenSet = true; m_debugRuleConfigurations = std::move(value); }
+
+    /**
+     * <p>Information about the debug rule configuration.</p>
+     */
+    inline TrainingJob& WithDebugRuleConfigurations(const Aws::Vector<DebugRuleConfiguration>& value) { SetDebugRuleConfigurations(value); return *this;}
+
+    /**
+     * <p>Information about the debug rule configuration.</p>
+     */
+    inline TrainingJob& WithDebugRuleConfigurations(Aws::Vector<DebugRuleConfiguration>&& value) { SetDebugRuleConfigurations(std::move(value)); return *this;}
+
+    /**
+     * <p>Information about the debug rule configuration.</p>
+     */
+    inline TrainingJob& AddDebugRuleConfigurations(const DebugRuleConfiguration& value) { m_debugRuleConfigurationsHasBeenSet = true; m_debugRuleConfigurations.push_back(value); return *this; }
+
+    /**
+     * <p>Information about the debug rule configuration.</p>
+     */
+    inline TrainingJob& AddDebugRuleConfigurations(DebugRuleConfiguration&& value) { m_debugRuleConfigurationsHasBeenSet = true; m_debugRuleConfigurations.push_back(std::move(value)); return *this; }
+
+
+    
+    inline const TensorBoardOutputConfig& GetTensorBoardOutputConfig() const{ return m_tensorBoardOutputConfig; }
+
+    
+    inline bool TensorBoardOutputConfigHasBeenSet() const { return m_tensorBoardOutputConfigHasBeenSet; }
+
+    
+    inline void SetTensorBoardOutputConfig(const TensorBoardOutputConfig& value) { m_tensorBoardOutputConfigHasBeenSet = true; m_tensorBoardOutputConfig = value; }
+
+    
+    inline void SetTensorBoardOutputConfig(TensorBoardOutputConfig&& value) { m_tensorBoardOutputConfigHasBeenSet = true; m_tensorBoardOutputConfig = std::move(value); }
+
+    
+    inline TrainingJob& WithTensorBoardOutputConfig(const TensorBoardOutputConfig& value) { SetTensorBoardOutputConfig(value); return *this;}
+
+    
+    inline TrainingJob& WithTensorBoardOutputConfig(TensorBoardOutputConfig&& value) { SetTensorBoardOutputConfig(std::move(value)); return *this;}
+
+
+    /**
+     * <p>Information about the evaluation status of the rules for the training
+     * job.</p>
+     */
+    inline const Aws::Vector<DebugRuleEvaluationStatus>& GetDebugRuleEvaluationStatuses() const{ return m_debugRuleEvaluationStatuses; }
+
+    /**
+     * <p>Information about the evaluation status of the rules for the training
+     * job.</p>
+     */
+    inline bool DebugRuleEvaluationStatusesHasBeenSet() const { return m_debugRuleEvaluationStatusesHasBeenSet; }
+
+    /**
+     * <p>Information about the evaluation status of the rules for the training
+     * job.</p>
+     */
+    inline void SetDebugRuleEvaluationStatuses(const Aws::Vector<DebugRuleEvaluationStatus>& value) { m_debugRuleEvaluationStatusesHasBeenSet = true; m_debugRuleEvaluationStatuses = value; }
+
+    /**
+     * <p>Information about the evaluation status of the rules for the training
+     * job.</p>
+     */
+    inline void SetDebugRuleEvaluationStatuses(Aws::Vector<DebugRuleEvaluationStatus>&& value) { m_debugRuleEvaluationStatusesHasBeenSet = true; m_debugRuleEvaluationStatuses = std::move(value); }
+
+    /**
+     * <p>Information about the evaluation status of the rules for the training
+     * job.</p>
+     */
+    inline TrainingJob& WithDebugRuleEvaluationStatuses(const Aws::Vector<DebugRuleEvaluationStatus>& value) { SetDebugRuleEvaluationStatuses(value); return *this;}
+
+    /**
+     * <p>Information about the evaluation status of the rules for the training
+     * job.</p>
+     */
+    inline TrainingJob& WithDebugRuleEvaluationStatuses(Aws::Vector<DebugRuleEvaluationStatus>&& value) { SetDebugRuleEvaluationStatuses(std::move(value)); return *this;}
+
+    /**
+     * <p>Information about the evaluation status of the rules for the training
+     * job.</p>
+     */
+    inline TrainingJob& AddDebugRuleEvaluationStatuses(const DebugRuleEvaluationStatus& value) { m_debugRuleEvaluationStatusesHasBeenSet = true; m_debugRuleEvaluationStatuses.push_back(value); return *this; }
+
+    /**
+     * <p>Information about the evaluation status of the rules for the training
+     * job.</p>
+     */
+    inline TrainingJob& AddDebugRuleEvaluationStatuses(DebugRuleEvaluationStatus&& value) { m_debugRuleEvaluationStatusesHasBeenSet = true; m_debugRuleEvaluationStatuses.push_back(std::move(value)); return *this; }
+
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline const Aws::Map<Aws::String, Aws::String>& GetEnvironment() const{ return m_environment; }
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline bool EnvironmentHasBeenSet() const { return m_environmentHasBeenSet; }
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline void SetEnvironment(const Aws::Map<Aws::String, Aws::String>& value) { m_environmentHasBeenSet = true; m_environment = value; }
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline void SetEnvironment(Aws::Map<Aws::String, Aws::String>&& value) { m_environmentHasBeenSet = true; m_environment = std::move(value); }
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline TrainingJob& WithEnvironment(const Aws::Map<Aws::String, Aws::String>& value) { SetEnvironment(value); return *this;}
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline TrainingJob& WithEnvironment(Aws::Map<Aws::String, Aws::String>&& value) { SetEnvironment(std::move(value)); return *this;}
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline TrainingJob& AddEnvironment(const Aws::String& key, const Aws::String& value) { m_environmentHasBeenSet = true; m_environment.emplace(key, value); return *this; }
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline TrainingJob& AddEnvironment(Aws::String&& key, const Aws::String& value) { m_environmentHasBeenSet = true; m_environment.emplace(std::move(key), value); return *this; }
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline TrainingJob& AddEnvironment(const Aws::String& key, Aws::String&& value) { m_environmentHasBeenSet = true; m_environment.emplace(key, std::move(value)); return *this; }
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline TrainingJob& AddEnvironment(Aws::String&& key, Aws::String&& value) { m_environmentHasBeenSet = true; m_environment.emplace(std::move(key), std::move(value)); return *this; }
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline TrainingJob& AddEnvironment(const char* key, Aws::String&& value) { m_environmentHasBeenSet = true; m_environment.emplace(key, std::move(value)); return *this; }
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline TrainingJob& AddEnvironment(Aws::String&& key, const char* value) { m_environmentHasBeenSet = true; m_environment.emplace(std::move(key), value); return *this; }
+
+    /**
+     * <p>The environment variables to set in the Docker container.</p>
+     */
+    inline TrainingJob& AddEnvironment(const char* key, const char* value) { m_environmentHasBeenSet = true; m_environment.emplace(key, value); return *this; }
+
+
+    /**
+     * <p>An array of key-value pairs. You can use tags to categorize your AWS
+     * resources in different ways, for example, by purpose, owner, or environment. For
+     * more information, see <a
+     * href="https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html">Tagging
+     * AWS Resources</a>.</p>
      */
     inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
 
     /**
-     * <p>An array of key-value pairs. For more information, see <a
-     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what">Using
-     * Cost Allocation Tags</a> in the <i>AWS Billing and Cost Management User
-     * Guide</i>.</p>
+     * <p>An array of key-value pairs. You can use tags to categorize your AWS
+     * resources in different ways, for example, by purpose, owner, or environment. For
+     * more information, see <a
+     * href="https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html">Tagging
+     * AWS Resources</a>.</p>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
     /**
-     * <p>An array of key-value pairs. For more information, see <a
-     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what">Using
-     * Cost Allocation Tags</a> in the <i>AWS Billing and Cost Management User
-     * Guide</i>.</p>
+     * <p>An array of key-value pairs. You can use tags to categorize your AWS
+     * resources in different ways, for example, by purpose, owner, or environment. For
+     * more information, see <a
+     * href="https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html">Tagging
+     * AWS Resources</a>.</p>
      */
     inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
     /**
-     * <p>An array of key-value pairs. For more information, see <a
-     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what">Using
-     * Cost Allocation Tags</a> in the <i>AWS Billing and Cost Management User
-     * Guide</i>.</p>
+     * <p>An array of key-value pairs. You can use tags to categorize your AWS
+     * resources in different ways, for example, by purpose, owner, or environment. For
+     * more information, see <a
+     * href="https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html">Tagging
+     * AWS Resources</a>.</p>
      */
     inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
     /**
-     * <p>An array of key-value pairs. For more information, see <a
-     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what">Using
-     * Cost Allocation Tags</a> in the <i>AWS Billing and Cost Management User
-     * Guide</i>.</p>
+     * <p>An array of key-value pairs. You can use tags to categorize your AWS
+     * resources in different ways, for example, by purpose, owner, or environment. For
+     * more information, see <a
+     * href="https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html">Tagging
+     * AWS Resources</a>.</p>
      */
     inline TrainingJob& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
 
     /**
-     * <p>An array of key-value pairs. For more information, see <a
-     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what">Using
-     * Cost Allocation Tags</a> in the <i>AWS Billing and Cost Management User
-     * Guide</i>.</p>
+     * <p>An array of key-value pairs. You can use tags to categorize your AWS
+     * resources in different ways, for example, by purpose, owner, or environment. For
+     * more information, see <a
+     * href="https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html">Tagging
+     * AWS Resources</a>.</p>
      */
     inline TrainingJob& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
 
     /**
-     * <p>An array of key-value pairs. For more information, see <a
-     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what">Using
-     * Cost Allocation Tags</a> in the <i>AWS Billing and Cost Management User
-     * Guide</i>.</p>
+     * <p>An array of key-value pairs. You can use tags to categorize your AWS
+     * resources in different ways, for example, by purpose, owner, or environment. For
+     * more information, see <a
+     * href="https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html">Tagging
+     * AWS Resources</a>.</p>
      */
     inline TrainingJob& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
 
     /**
-     * <p>An array of key-value pairs. For more information, see <a
-     * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what">Using
-     * Cost Allocation Tags</a> in the <i>AWS Billing and Cost Management User
-     * Guide</i>.</p>
+     * <p>An array of key-value pairs. You can use tags to categorize your AWS
+     * resources in different ways, for example, by purpose, owner, or environment. For
+     * more information, see <a
+     * href="https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html">Tagging
+     * AWS Resources</a>.</p>
      */
     inline TrainingJob& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
@@ -1371,6 +1723,9 @@ namespace Model
     Aws::String m_labelingJobArn;
     bool m_labelingJobArnHasBeenSet;
 
+    Aws::String m_autoMLJobArn;
+    bool m_autoMLJobArnHasBeenSet;
+
     ModelArtifacts m_modelArtifacts;
     bool m_modelArtifactsHasBeenSet;
 
@@ -1431,6 +1786,36 @@ namespace Model
     bool m_enableInterContainerTrafficEncryption;
     bool m_enableInterContainerTrafficEncryptionHasBeenSet;
 
+    bool m_enableManagedSpotTraining;
+    bool m_enableManagedSpotTrainingHasBeenSet;
+
+    CheckpointConfig m_checkpointConfig;
+    bool m_checkpointConfigHasBeenSet;
+
+    int m_trainingTimeInSeconds;
+    bool m_trainingTimeInSecondsHasBeenSet;
+
+    int m_billableTimeInSeconds;
+    bool m_billableTimeInSecondsHasBeenSet;
+
+    DebugHookConfig m_debugHookConfig;
+    bool m_debugHookConfigHasBeenSet;
+
+    ExperimentConfig m_experimentConfig;
+    bool m_experimentConfigHasBeenSet;
+
+    Aws::Vector<DebugRuleConfiguration> m_debugRuleConfigurations;
+    bool m_debugRuleConfigurationsHasBeenSet;
+
+    TensorBoardOutputConfig m_tensorBoardOutputConfig;
+    bool m_tensorBoardOutputConfigHasBeenSet;
+
+    Aws::Vector<DebugRuleEvaluationStatus> m_debugRuleEvaluationStatuses;
+    bool m_debugRuleEvaluationStatusesHasBeenSet;
+
+    Aws::Map<Aws::String, Aws::String> m_environment;
+    bool m_environmentHasBeenSet;
+
     Aws::Vector<Tag> m_tags;
     bool m_tagsHasBeenSet;
   };
