@@ -1,23 +1,14 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/signer/Signer_EXPORTS.h>
 #include <aws/signer/SignerRequest.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/signer/model/SigningMaterial.h>
+#include <aws/signer/model/SignatureValidityPeriod.h>
 #include <aws/signer/model/SigningPlatformOverrides.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <utility>
@@ -123,6 +114,43 @@ namespace Model
     inline PutSigningProfileRequest& WithSigningMaterial(SigningMaterial&& value) { SetSigningMaterial(std::move(value)); return *this;}
 
 
+    /**
+     * <p>The default validity period override for any signature generated using this
+     * signing profile. If unspecified, the default is 135 months.</p>
+     */
+    inline const SignatureValidityPeriod& GetSignatureValidityPeriod() const{ return m_signatureValidityPeriod; }
+
+    /**
+     * <p>The default validity period override for any signature generated using this
+     * signing profile. If unspecified, the default is 135 months.</p>
+     */
+    inline bool SignatureValidityPeriodHasBeenSet() const { return m_signatureValidityPeriodHasBeenSet; }
+
+    /**
+     * <p>The default validity period override for any signature generated using this
+     * signing profile. If unspecified, the default is 135 months.</p>
+     */
+    inline void SetSignatureValidityPeriod(const SignatureValidityPeriod& value) { m_signatureValidityPeriodHasBeenSet = true; m_signatureValidityPeriod = value; }
+
+    /**
+     * <p>The default validity period override for any signature generated using this
+     * signing profile. If unspecified, the default is 135 months.</p>
+     */
+    inline void SetSignatureValidityPeriod(SignatureValidityPeriod&& value) { m_signatureValidityPeriodHasBeenSet = true; m_signatureValidityPeriod = std::move(value); }
+
+    /**
+     * <p>The default validity period override for any signature generated using this
+     * signing profile. If unspecified, the default is 135 months.</p>
+     */
+    inline PutSigningProfileRequest& WithSignatureValidityPeriod(const SignatureValidityPeriod& value) { SetSignatureValidityPeriod(value); return *this;}
+
+    /**
+     * <p>The default validity period override for any signature generated using this
+     * signing profile. If unspecified, the default is 135 months.</p>
+     */
+    inline PutSigningProfileRequest& WithSignatureValidityPeriod(SignatureValidityPeriod&& value) { SetSignatureValidityPeriod(std::move(value)); return *this;}
+
+
     /**
      * <p>The ID of the signing platform to be created.</p>
      */
@@ -359,6 +387,9 @@ namespace Model
     SigningMaterial m_signingMaterial;
     bool m_signingMaterialHasBeenSet;
 
+    SignatureValidityPeriod m_signatureValidityPeriod;
+    bool m_signatureValidityPeriodHasBeenSet;
+
     Aws::String m_platformId;
     bool m_platformIdHasBeenSet;
 
