@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/transcribe/TranscribeService_EXPORTS.h>
@@ -26,37 +16,42 @@ namespace Model
   enum class LanguageCode
   {
     NOT_SET,
-    en_US,
-    es_US,
-    en_AU,
-    fr_CA,
-    en_GB,
-    de_DE,
-    pt_BR,
-    fr_FR,
-    it_IT,
-    ko_KR,
-    es_ES,
-    en_IN,
-    hi_IN,
+    af_ZA,
+    ar_AE,
     ar_SA,
-    ru_RU,
-    zh_CN,
-    nl_NL,
-    id_ID,
-    ta_IN,
-    fa_IR,
-    en_IE,
+    cy_GB,
+    da_DK,
+    de_CH,
+    de_DE,
     en_AB,
+    en_AU,
+    en_GB,
+    en_IE,
+    en_IN,
+    en_US,
     en_WL,
+    es_ES,
+    es_US,
+    fa_IR,
+    fr_CA,
+    fr_FR,
+    ga_IE,
+    gd_GB,
+    he_IL,
+    hi_IN,
+    id_ID,
+    it_IT,
+    ja_JP,
+    ko_KR,
+    ms_MY,
+    nl_NL,
+    pt_BR,
     pt_PT,
+    ru_RU,
+    ta_IN,
     te_IN,
     tr_TR,
-    de_CH,
-    he_IL,
-    ms_MY,
-    ja_JP,
-    ar_AE
+    zh_CN
   };
 
 namespace LanguageCodeMapper
